# Generated by ANTLR 4.10.1
# encoding: utf-8
from antlr4 import *
from io import StringIO
import sys
if sys.version_info[1] > 5:
	from typing import TextIO
else:
	from typing.io import TextIO

def serializedATN():
    return [
        4,1,107,1356,2,0,7,0,2,1,7,1,2,2,7,2,2,3,7,3,2,4,7,4,2,5,7,5,2,6,
        7,6,2,7,7,7,2,8,7,8,2,9,7,9,2,10,7,10,2,11,7,11,2,12,7,12,2,13,7,
        13,2,14,7,14,2,15,7,15,2,16,7,16,2,17,7,17,2,18,7,18,2,19,7,19,2,
        20,7,20,2,21,7,21,2,22,7,22,2,23,7,23,2,24,7,24,2,25,7,25,2,26,7,
        26,2,27,7,27,2,28,7,28,2,29,7,29,2,30,7,30,2,31,7,31,2,32,7,32,2,
        33,7,33,2,34,7,34,2,35,7,35,2,36,7,36,2,37,7,37,2,38,7,38,2,39,7,
        39,2,40,7,40,2,41,7,41,2,42,7,42,2,43,7,43,2,44,7,44,2,45,7,45,2,
        46,7,46,2,47,7,47,2,48,7,48,2,49,7,49,2,50,7,50,2,51,7,51,2,52,7,
        52,2,53,7,53,2,54,7,54,2,55,7,55,2,56,7,56,2,57,7,57,2,58,7,58,2,
        59,7,59,2,60,7,60,2,61,7,61,2,62,7,62,2,63,7,63,2,64,7,64,2,65,7,
        65,2,66,7,66,2,67,7,67,2,68,7,68,2,69,7,69,2,70,7,70,2,71,7,71,2,
        72,7,72,2,73,7,73,2,74,7,74,2,75,7,75,2,76,7,76,2,77,7,77,2,78,7,
        78,2,79,7,79,2,80,7,80,2,81,7,81,2,82,7,82,2,83,7,83,2,84,7,84,2,
        85,7,85,2,86,7,86,2,87,7,87,2,88,7,88,2,89,7,89,2,90,7,90,2,91,7,
        91,2,92,7,92,2,93,7,93,2,94,7,94,2,95,7,95,2,96,7,96,2,97,7,97,2,
        98,7,98,2,99,7,99,2,100,7,100,2,101,7,101,2,102,7,102,2,103,7,103,
        2,104,7,104,2,105,7,105,1,0,3,0,214,8,0,1,0,5,0,217,8,0,10,0,12,
        0,220,9,0,1,0,5,0,223,8,0,10,0,12,0,226,9,0,1,0,1,0,1,1,5,1,231,
        8,1,10,1,12,1,234,9,1,1,1,1,1,1,1,1,1,1,2,1,2,3,2,242,8,2,1,2,1,
        2,1,2,3,2,247,8,2,1,2,1,2,1,3,5,3,252,8,3,10,3,12,3,255,9,3,1,3,
        1,3,5,3,259,8,3,10,3,12,3,262,9,3,1,3,1,3,5,3,266,8,3,10,3,12,3,
        269,9,3,1,3,1,3,5,3,273,8,3,10,3,12,3,276,9,3,1,3,1,3,3,3,280,8,
        3,1,4,1,4,3,4,284,8,4,1,5,1,5,3,5,288,8,5,1,6,1,6,3,6,292,8,6,1,
        7,1,7,1,7,3,7,297,8,7,1,7,1,7,3,7,301,8,7,1,7,1,7,3,7,305,8,7,1,
        7,1,7,1,8,1,8,1,8,1,8,5,8,313,8,8,10,8,12,8,316,9,8,1,8,1,8,1,9,
        5,9,321,8,9,10,9,12,9,324,9,9,1,9,1,9,1,9,3,9,329,8,9,1,10,1,10,
        1,10,5,10,334,8,10,10,10,12,10,337,9,10,1,11,1,11,1,11,1,11,3,11,
        343,8,11,1,11,1,11,3,11,347,8,11,1,11,3,11,350,8,11,1,11,3,11,353,
        8,11,1,11,1,11,1,12,1,12,1,12,5,12,360,8,12,10,12,12,12,363,9,12,
        1,13,5,13,366,8,13,10,13,12,13,369,9,13,1,13,1,13,3,13,373,8,13,
        1,13,3,13,376,8,13,1,14,1,14,5,14,380,8,14,10,14,12,14,383,9,14,
        1,15,1,15,1,15,3,15,388,8,15,1,15,1,15,3,15,392,8,15,1,15,1,15,1,
        16,1,16,1,16,5,16,399,8,16,10,16,12,16,402,9,16,1,17,1,17,5,17,406,
        8,17,10,17,12,17,409,9,17,1,17,1,17,1,18,1,18,5,18,415,8,18,10,18,
        12,18,418,9,18,1,18,1,18,1,19,1,19,3,19,424,8,19,1,19,1,19,5,19,
        428,8,19,10,19,12,19,431,9,19,1,19,3,19,434,8,19,1,20,1,20,1,20,
        1,20,1,20,1,20,1,20,1,20,1,20,3,20,445,8,20,1,21,1,21,3,21,449,8,
        21,1,21,1,21,1,21,1,21,5,21,455,8,21,10,21,12,21,458,9,21,1,21,1,
        21,3,21,462,8,21,1,21,1,21,3,21,466,8,21,1,22,1,22,1,22,1,23,1,23,
        1,23,1,23,3,23,475,8,23,1,23,1,23,1,24,1,24,1,24,1,25,1,25,1,25,
        1,25,1,26,5,26,487,8,26,10,26,12,26,490,9,26,1,26,1,26,3,26,494,
        8,26,1,27,1,27,1,27,1,27,1,27,1,27,1,27,3,27,503,8,27,1,28,1,28,
        1,28,1,28,5,28,509,8,28,10,28,12,28,512,9,28,1,28,1,28,1,29,1,29,
        1,29,5,29,519,8,29,10,29,12,29,522,9,29,1,29,1,29,1,29,1,30,1,30,
        3,30,529,8,30,1,30,1,30,1,30,1,30,5,30,535,8,30,10,30,12,30,538,
        9,30,1,30,1,30,3,30,542,8,30,1,30,1,30,1,30,1,30,3,30,548,8,30,1,
        30,3,30,551,8,30,1,31,1,31,1,31,1,32,1,32,1,32,5,32,559,8,32,10,
        32,12,32,562,9,32,1,33,1,33,1,33,3,33,567,8,33,1,34,1,34,1,34,5,
        34,572,8,34,10,34,12,34,575,9,34,1,35,1,35,3,35,579,8,35,1,36,1,
        36,1,36,1,36,5,36,585,8,36,10,36,12,36,588,9,36,1,36,3,36,591,8,
        36,3,36,593,8,36,1,36,1,36,1,37,1,37,1,38,1,38,1,38,5,38,602,8,38,
        10,38,12,38,605,9,38,1,38,1,38,1,38,5,38,610,8,38,10,38,12,38,613,
        9,38,3,38,615,8,38,1,39,1,39,3,39,619,8,39,1,39,1,39,1,39,3,39,624,
        8,39,5,39,626,8,39,10,39,12,39,629,9,39,1,40,1,40,1,41,1,41,1,41,
        1,41,5,41,637,8,41,10,41,12,41,640,9,41,1,41,1,41,1,42,3,42,645,
        8,42,1,42,1,42,1,43,1,43,1,43,1,43,3,43,653,8,43,3,43,655,8,43,1,
        44,1,44,1,44,5,44,660,8,44,10,44,12,44,663,9,44,1,45,1,45,3,45,667,
        8,45,1,45,1,45,1,46,1,46,1,46,5,46,674,8,46,10,46,12,46,677,9,46,
        1,46,1,46,3,46,681,8,46,1,46,3,46,684,8,46,1,47,5,47,687,8,47,10,
        47,12,47,690,9,47,1,47,1,47,1,47,1,48,5,48,696,8,48,10,48,12,48,
        699,9,48,1,48,1,48,1,48,1,48,1,49,1,49,1,50,1,50,1,51,1,51,1,51,
        5,51,712,8,51,10,51,12,51,715,9,51,1,52,1,52,1,53,1,53,1,53,1,53,
        1,53,3,53,724,8,53,1,53,3,53,727,8,53,1,54,1,54,1,55,1,55,1,55,5,
        55,734,8,55,10,55,12,55,737,9,55,1,56,1,56,1,56,1,56,1,57,1,57,1,
        57,3,57,746,8,57,1,58,1,58,1,58,1,58,5,58,752,8,58,10,58,12,58,755,
        9,58,3,58,757,8,58,1,58,3,58,760,8,58,1,58,1,58,1,59,1,59,1,59,1,
        59,1,59,1,60,1,60,5,60,771,8,60,10,60,12,60,774,9,60,1,60,1,60,1,
        61,5,61,779,8,61,10,61,12,61,782,9,61,1,61,1,61,3,61,786,8,61,1,
        62,1,62,1,62,1,62,1,62,1,62,3,62,794,8,62,1,62,1,62,3,62,798,8,62,
        1,62,1,62,3,62,802,8,62,1,62,1,62,3,62,806,8,62,3,62,808,8,62,1,
        63,1,63,3,63,812,8,63,1,64,1,64,1,64,1,64,3,64,818,8,64,1,65,1,65,
        1,66,1,66,1,66,1,67,1,67,5,67,827,8,67,10,67,12,67,830,9,67,1,67,
        1,67,1,68,1,68,1,68,3,68,837,8,68,1,69,1,69,1,69,1,70,5,70,843,8,
        70,10,70,12,70,846,9,70,1,70,1,70,1,70,1,71,1,71,1,71,1,71,1,71,
        3,71,856,8,71,1,71,1,71,1,71,1,71,1,71,1,71,1,71,3,71,865,8,71,1,
        71,1,71,1,71,1,71,1,71,1,71,1,71,1,71,1,71,1,71,1,71,1,71,1,71,1,
        71,1,71,1,71,1,71,1,71,1,71,4,71,886,8,71,11,71,12,71,887,1,71,3,
        71,891,8,71,1,71,3,71,894,8,71,1,71,1,71,1,71,1,71,5,71,900,8,71,
        10,71,12,71,903,9,71,1,71,3,71,906,8,71,1,71,1,71,1,71,1,71,5,71,
        912,8,71,10,71,12,71,915,9,71,1,71,5,71,918,8,71,10,71,12,71,921,
        9,71,1,71,1,71,1,71,1,71,1,71,1,71,1,71,1,71,3,71,931,8,71,1,71,
        1,71,1,71,1,71,1,71,1,71,1,71,3,71,940,8,71,1,71,1,71,1,71,3,71,
        945,8,71,1,71,1,71,1,71,1,71,1,71,1,71,1,71,1,71,3,71,955,8,71,1,
        72,1,72,1,72,5,72,960,8,72,10,72,12,72,963,9,72,1,72,1,72,1,72,1,
        72,1,72,1,73,1,73,1,73,5,73,973,8,73,10,73,12,73,976,9,73,1,74,1,
        74,1,74,1,75,1,75,1,75,3,75,984,8,75,1,75,1,75,1,76,1,76,1,76,5,
        76,991,8,76,10,76,12,76,994,9,76,1,77,5,77,997,8,77,10,77,12,77,
        1000,9,77,1,77,1,77,1,77,1,77,1,77,1,78,4,78,1008,8,78,11,78,12,
        78,1009,1,78,4,78,1013,8,78,11,78,12,78,1014,1,79,1,79,1,79,1,79,
        1,79,1,79,1,79,1,79,1,79,1,79,3,79,1027,8,79,1,80,1,80,3,80,1031,
        8,80,1,80,1,80,3,80,1035,8,80,1,80,1,80,3,80,1039,8,80,3,80,1041,
        8,80,1,81,1,81,3,81,1045,8,81,1,82,5,82,1048,8,82,10,82,12,82,1051,
        9,82,1,82,1,82,1,82,1,82,1,82,1,83,1,83,1,84,1,84,1,84,1,84,1,85,
        1,85,1,85,5,85,1067,8,85,10,85,12,85,1070,9,85,1,86,1,86,1,87,1,
        87,1,88,1,88,1,88,1,88,1,89,1,89,1,89,3,89,1083,8,89,1,89,1,89,1,
        89,1,89,1,89,3,89,1090,8,89,1,90,1,90,1,90,5,90,1095,8,90,10,90,
        12,90,1098,9,90,1,91,1,91,3,91,1102,8,91,1,92,1,92,1,92,1,92,1,92,
        1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,3,92,1118,8,92,1,92,
        1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,
        3,92,1134,8,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,
        1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,
        1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,
        1,92,1,92,1,92,1,92,1,92,3,92,1177,8,92,1,92,1,92,1,92,1,92,1,92,
        1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,3,92,1195,
        8,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,1,92,3,92,1206,8,92,
        1,92,1,92,1,92,1,92,3,92,1212,8,92,1,92,1,92,1,92,1,92,1,92,1,92,
        3,92,1220,8,92,1,92,5,92,1223,8,92,10,92,12,92,1226,9,92,1,93,1,
        93,1,93,1,93,1,93,1,93,1,93,1,93,1,93,1,93,1,93,1,93,1,93,1,93,1,
        93,1,93,1,93,1,93,1,93,3,93,1247,8,93,3,93,1249,8,93,1,94,1,94,1,
        94,1,94,1,94,1,94,1,94,3,94,1258,8,94,3,94,1260,8,94,1,95,1,95,3,
        95,1264,8,95,1,95,1,95,1,95,3,95,1269,8,95,5,95,1271,8,95,10,95,
        12,95,1274,9,95,1,95,3,95,1277,8,95,1,96,1,96,3,96,1281,8,96,1,96,
        1,96,1,97,1,97,1,97,1,97,5,97,1289,8,97,10,97,12,97,1292,9,97,1,
        97,1,97,1,97,1,97,1,97,1,97,1,97,5,97,1301,8,97,10,97,12,97,1304,
        9,97,1,97,1,97,5,97,1308,8,97,10,97,12,97,1311,9,97,3,97,1313,8,
        97,1,98,1,98,3,98,1317,8,98,1,99,1,99,1,99,1,100,1,100,1,100,1,100,
        1,101,1,101,1,101,3,101,1329,8,101,1,102,1,102,1,102,3,102,1334,
        8,102,1,103,1,103,1,103,1,103,3,103,1340,8,103,3,103,1342,8,103,
        1,104,1,104,1,104,1,104,3,104,1348,8,104,1,105,1,105,3,105,1352,
        8,105,1,105,1,105,1,105,0,1,184,106,0,2,4,6,8,10,12,14,16,18,20,
        22,24,26,28,30,32,34,36,38,40,42,44,46,48,50,52,54,56,58,60,62,64,
        66,68,70,72,74,76,78,80,82,84,86,88,90,92,94,96,98,100,102,104,106,
        108,110,112,114,116,118,120,122,124,126,128,130,132,134,136,138,
        140,142,144,146,148,150,152,154,156,158,160,162,164,166,168,170,
        172,174,176,178,180,182,184,186,188,190,192,194,196,198,200,202,
        204,206,208,210,0,14,4,0,32,32,44,44,48,48,51,51,4,0,3,3,20,20,35,
        37,40,41,2,0,14,14,40,40,8,0,5,5,7,7,10,10,16,16,22,22,29,29,31,
        31,39,39,2,0,19,19,42,42,1,0,53,58,1,0,81,84,1,0,71,72,2,0,85,86,
        90,90,1,0,83,84,2,0,69,70,76,77,2,0,75,75,78,78,2,0,68,68,91,101,
        1,0,81,82,1481,0,213,1,0,0,0,2,232,1,0,0,0,4,239,1,0,0,0,6,279,1,
        0,0,0,8,283,1,0,0,0,10,287,1,0,0,0,12,291,1,0,0,0,14,293,1,0,0,0,
        16,308,1,0,0,0,18,322,1,0,0,0,20,330,1,0,0,0,22,338,1,0,0,0,24,356,
        1,0,0,0,26,367,1,0,0,0,28,377,1,0,0,0,30,384,1,0,0,0,32,395,1,0,
        0,0,34,403,1,0,0,0,36,412,1,0,0,0,38,433,1,0,0,0,40,444,1,0,0,0,
        42,448,1,0,0,0,44,467,1,0,0,0,46,470,1,0,0,0,48,478,1,0,0,0,50,481,
        1,0,0,0,52,493,1,0,0,0,54,502,1,0,0,0,56,504,1,0,0,0,58,515,1,0,
        0,0,60,550,1,0,0,0,62,552,1,0,0,0,64,555,1,0,0,0,66,563,1,0,0,0,
        68,568,1,0,0,0,70,578,1,0,0,0,72,580,1,0,0,0,74,596,1,0,0,0,76,614,
        1,0,0,0,78,616,1,0,0,0,80,630,1,0,0,0,82,632,1,0,0,0,84,644,1,0,
        0,0,86,654,1,0,0,0,88,656,1,0,0,0,90,664,1,0,0,0,92,683,1,0,0,0,
        94,688,1,0,0,0,96,697,1,0,0,0,98,704,1,0,0,0,100,706,1,0,0,0,102,
        708,1,0,0,0,104,716,1,0,0,0,106,718,1,0,0,0,108,728,1,0,0,0,110,
        730,1,0,0,0,112,738,1,0,0,0,114,745,1,0,0,0,116,747,1,0,0,0,118,
        763,1,0,0,0,120,768,1,0,0,0,122,785,1,0,0,0,124,807,1,0,0,0,126,
        811,1,0,0,0,128,813,1,0,0,0,130,819,1,0,0,0,132,821,1,0,0,0,134,
        824,1,0,0,0,136,836,1,0,0,0,138,838,1,0,0,0,140,844,1,0,0,0,142,
        954,1,0,0,0,144,956,1,0,0,0,146,969,1,0,0,0,148,977,1,0,0,0,150,
        980,1,0,0,0,152,987,1,0,0,0,154,998,1,0,0,0,156,1007,1,0,0,0,158,
        1026,1,0,0,0,160,1040,1,0,0,0,162,1044,1,0,0,0,164,1049,1,0,0,0,
        166,1057,1,0,0,0,168,1059,1,0,0,0,170,1063,1,0,0,0,172,1071,1,0,
        0,0,174,1073,1,0,0,0,176,1075,1,0,0,0,178,1089,1,0,0,0,180,1091,
        1,0,0,0,182,1101,1,0,0,0,184,1117,1,0,0,0,186,1248,1,0,0,0,188,1259,
        1,0,0,0,190,1276,1,0,0,0,192,1278,1,0,0,0,194,1284,1,0,0,0,196,1314,
        1,0,0,0,198,1318,1,0,0,0,200,1321,1,0,0,0,202,1328,1,0,0,0,204,1333,
        1,0,0,0,206,1341,1,0,0,0,208,1347,1,0,0,0,210,1349,1,0,0,0,212,214,
        3,2,1,0,213,212,1,0,0,0,213,214,1,0,0,0,214,218,1,0,0,0,215,217,
        3,4,2,0,216,215,1,0,0,0,217,220,1,0,0,0,218,216,1,0,0,0,218,219,
        1,0,0,0,219,224,1,0,0,0,220,218,1,0,0,0,221,223,3,6,3,0,222,221,
        1,0,0,0,223,226,1,0,0,0,224,222,1,0,0,0,224,225,1,0,0,0,225,227,
        1,0,0,0,226,224,1,0,0,0,227,228,5,0,0,1,228,1,1,0,0,0,229,231,3,
        106,53,0,230,229,1,0,0,0,231,234,1,0,0,0,232,230,1,0,0,0,232,233,
        1,0,0,0,233,235,1,0,0,0,234,232,1,0,0,0,235,236,5,34,0,0,236,237,
        3,102,51,0,237,238,5,65,0,0,238,3,1,0,0,0,239,241,5,27,0,0,240,242,
        5,40,0,0,241,240,1,0,0,0,241,242,1,0,0,0,242,243,1,0,0,0,243,246,
        3,102,51,0,244,245,5,67,0,0,245,247,5,85,0,0,246,244,1,0,0,0,246,
        247,1,0,0,0,247,248,1,0,0,0,248,249,5,65,0,0,249,5,1,0,0,0,250,252,
        3,10,5,0,251,250,1,0,0,0,252,255,1,0,0,0,253,251,1,0,0,0,253,254,
        1,0,0,0,254,256,1,0,0,0,255,253,1,0,0,0,256,280,3,14,7,0,257,259,
        3,10,5,0,258,257,1,0,0,0,259,262,1,0,0,0,260,258,1,0,0,0,260,261,
        1,0,0,0,261,263,1,0,0,0,262,260,1,0,0,0,263,280,3,22,11,0,264,266,
        3,10,5,0,265,264,1,0,0,0,266,269,1,0,0,0,267,265,1,0,0,0,267,268,
        1,0,0,0,268,270,1,0,0,0,269,267,1,0,0,0,270,280,3,30,15,0,271,273,
        3,10,5,0,272,271,1,0,0,0,273,276,1,0,0,0,274,272,1,0,0,0,274,275,
        1,0,0,0,275,277,1,0,0,0,276,274,1,0,0,0,277,280,3,118,59,0,278,280,
        5,65,0,0,279,253,1,0,0,0,279,260,1,0,0,0,279,267,1,0,0,0,279,274,
        1,0,0,0,279,278,1,0,0,0,280,7,1,0,0,0,281,284,3,10,5,0,282,284,7,
        0,0,0,283,281,1,0,0,0,283,282,1,0,0,0,284,9,1,0,0,0,285,288,3,106,
        53,0,286,288,7,1,0,0,287,285,1,0,0,0,287,286,1,0,0,0,288,11,1,0,
        0,0,289,292,5,20,0,0,290,292,3,106,53,0,291,289,1,0,0,0,291,290,
        1,0,0,0,292,13,1,0,0,0,293,294,5,11,0,0,294,296,5,102,0,0,295,297,
        3,16,8,0,296,295,1,0,0,0,296,297,1,0,0,0,297,300,1,0,0,0,298,299,
        5,19,0,0,299,301,3,76,38,0,300,298,1,0,0,0,300,301,1,0,0,0,301,304,
        1,0,0,0,302,303,5,26,0,0,303,305,3,32,16,0,304,302,1,0,0,0,304,305,
        1,0,0,0,305,306,1,0,0,0,306,307,3,34,17,0,307,15,1,0,0,0,308,309,
        5,70,0,0,309,314,3,18,9,0,310,311,5,66,0,0,311,313,3,18,9,0,312,
        310,1,0,0,0,313,316,1,0,0,0,314,312,1,0,0,0,314,315,1,0,0,0,315,
        317,1,0,0,0,316,314,1,0,0,0,317,318,5,69,0,0,318,17,1,0,0,0,319,
        321,3,106,53,0,320,319,1,0,0,0,321,324,1,0,0,0,322,320,1,0,0,0,322,
        323,1,0,0,0,323,325,1,0,0,0,324,322,1,0,0,0,325,328,5,102,0,0,326,
        327,5,19,0,0,327,329,3,20,10,0,328,326,1,0,0,0,328,329,1,0,0,0,329,
        19,1,0,0,0,330,335,3,76,38,0,331,332,5,87,0,0,332,334,3,76,38,0,
        333,331,1,0,0,0,334,337,1,0,0,0,335,333,1,0,0,0,335,336,1,0,0,0,
        336,21,1,0,0,0,337,335,1,0,0,0,338,339,5,18,0,0,339,342,5,102,0,
        0,340,341,5,26,0,0,341,343,3,32,16,0,342,340,1,0,0,0,342,343,1,0,
        0,0,343,344,1,0,0,0,344,346,5,61,0,0,345,347,3,24,12,0,346,345,1,
        0,0,0,346,347,1,0,0,0,347,349,1,0,0,0,348,350,5,66,0,0,349,348,1,
        0,0,0,349,350,1,0,0,0,350,352,1,0,0,0,351,353,3,28,14,0,352,351,
        1,0,0,0,352,353,1,0,0,0,353,354,1,0,0,0,354,355,5,62,0,0,355,23,
        1,0,0,0,356,361,3,26,13,0,357,358,5,66,0,0,358,360,3,26,13,0,359,
        357,1,0,0,0,360,363,1,0,0,0,361,359,1,0,0,0,361,362,1,0,0,0,362,
        25,1,0,0,0,363,361,1,0,0,0,364,366,3,106,53,0,365,364,1,0,0,0,366,
        369,1,0,0,0,367,365,1,0,0,0,367,368,1,0,0,0,368,370,1,0,0,0,369,
        367,1,0,0,0,370,372,5,102,0,0,371,373,3,210,105,0,372,371,1,0,0,
        0,372,373,1,0,0,0,373,375,1,0,0,0,374,376,3,34,17,0,375,374,1,0,
        0,0,375,376,1,0,0,0,376,27,1,0,0,0,377,381,5,65,0,0,378,380,3,38,
        19,0,379,378,1,0,0,0,380,383,1,0,0,0,381,379,1,0,0,0,381,382,1,0,
        0,0,382,29,1,0,0,0,383,381,1,0,0,0,384,385,5,30,0,0,385,387,5,102,
        0,0,386,388,3,16,8,0,387,386,1,0,0,0,387,388,1,0,0,0,388,391,1,0,
        0,0,389,390,5,19,0,0,390,392,3,32,16,0,391,389,1,0,0,0,391,392,1,
        0,0,0,392,393,1,0,0,0,393,394,3,36,18,0,394,31,1,0,0,0,395,400,3,
        76,38,0,396,397,5,66,0,0,397,399,3,76,38,0,398,396,1,0,0,0,399,402,
        1,0,0,0,400,398,1,0,0,0,400,401,1,0,0,0,401,33,1,0,0,0,402,400,1,
        0,0,0,403,407,5,61,0,0,404,406,3,38,19,0,405,404,1,0,0,0,406,409,
        1,0,0,0,407,405,1,0,0,0,407,408,1,0,0,0,408,410,1,0,0,0,409,407,
        1,0,0,0,410,411,5,62,0,0,411,35,1,0,0,0,412,416,5,61,0,0,413,415,
        3,52,26,0,414,413,1,0,0,0,415,418,1,0,0,0,416,414,1,0,0,0,416,417,
        1,0,0,0,417,419,1,0,0,0,418,416,1,0,0,0,419,420,5,62,0,0,420,37,
        1,0,0,0,421,434,5,65,0,0,422,424,5,40,0,0,423,422,1,0,0,0,423,424,
        1,0,0,0,424,425,1,0,0,0,425,434,3,134,67,0,426,428,3,8,4,0,427,426,
        1,0,0,0,428,431,1,0,0,0,429,427,1,0,0,0,429,430,1,0,0,0,430,432,
        1,0,0,0,431,429,1,0,0,0,432,434,3,40,20,0,433,421,1,0,0,0,433,423,
        1,0,0,0,433,429,1,0,0,0,434,39,1,0,0,0,435,445,3,42,21,0,436,445,
        3,44,22,0,437,445,3,50,25,0,438,445,3,46,23,0,439,445,3,48,24,0,
        440,445,3,30,15,0,441,445,3,118,59,0,442,445,3,14,7,0,443,445,3,
        22,11,0,444,435,1,0,0,0,444,436,1,0,0,0,444,437,1,0,0,0,444,438,
        1,0,0,0,444,439,1,0,0,0,444,440,1,0,0,0,444,441,1,0,0,0,444,442,
        1,0,0,0,444,443,1,0,0,0,445,41,1,0,0,0,446,449,3,76,38,0,447,449,
        5,50,0,0,448,446,1,0,0,0,448,447,1,0,0,0,449,450,1,0,0,0,450,451,
        5,102,0,0,451,456,3,90,45,0,452,453,5,63,0,0,453,455,5,64,0,0,454,
        452,1,0,0,0,455,458,1,0,0,0,456,454,1,0,0,0,456,457,1,0,0,0,457,
        461,1,0,0,0,458,456,1,0,0,0,459,460,5,47,0,0,460,462,3,88,44,0,461,
        459,1,0,0,0,461,462,1,0,0,0,462,465,1,0,0,0,463,466,3,98,49,0,464,
        466,5,65,0,0,465,463,1,0,0,0,465,464,1,0,0,0,466,43,1,0,0,0,467,
        468,3,16,8,0,468,469,3,42,21,0,469,45,1,0,0,0,470,471,5,102,0,0,
        471,474,3,90,45,0,472,473,5,47,0,0,473,475,3,88,44,0,474,472,1,0,
        0,0,474,475,1,0,0,0,475,476,1,0,0,0,476,477,3,100,50,0,477,47,1,
        0,0,0,478,479,3,16,8,0,479,480,3,46,23,0,480,49,1,0,0,0,481,482,
        3,76,38,0,482,483,3,64,32,0,483,484,5,65,0,0,484,51,1,0,0,0,485,
        487,3,8,4,0,486,485,1,0,0,0,487,490,1,0,0,0,488,486,1,0,0,0,488,
        489,1,0,0,0,489,491,1,0,0,0,490,488,1,0,0,0,491,494,3,54,27,0,492,
        494,5,65,0,0,493,488,1,0,0,0,493,492,1,0,0,0,494,53,1,0,0,0,495,
        503,3,56,28,0,496,503,3,60,30,0,497,503,3,62,31,0,498,503,3,30,15,
        0,499,503,3,118,59,0,500,503,3,14,7,0,501,503,3,22,11,0,502,495,
        1,0,0,0,502,496,1,0,0,0,502,497,1,0,0,0,502,498,1,0,0,0,502,499,
        1,0,0,0,502,500,1,0,0,0,502,501,1,0,0,0,503,55,1,0,0,0,504,505,3,
        76,38,0,505,510,3,58,29,0,506,507,5,66,0,0,507,509,3,58,29,0,508,
        506,1,0,0,0,509,512,1,0,0,0,510,508,1,0,0,0,510,511,1,0,0,0,511,
        513,1,0,0,0,512,510,1,0,0,0,513,514,5,65,0,0,514,57,1,0,0,0,515,
        520,5,102,0,0,516,517,5,63,0,0,517,519,5,64,0,0,518,516,1,0,0,0,
        519,522,1,0,0,0,520,518,1,0,0,0,520,521,1,0,0,0,521,523,1,0,0,0,
        522,520,1,0,0,0,523,524,5,68,0,0,524,525,3,70,35,0,525,59,1,0,0,
        0,526,529,3,76,38,0,527,529,5,50,0,0,528,526,1,0,0,0,528,527,1,0,
        0,0,529,530,1,0,0,0,530,531,5,102,0,0,531,536,3,90,45,0,532,533,
        5,63,0,0,533,535,5,64,0,0,534,532,1,0,0,0,535,538,1,0,0,0,536,534,
        1,0,0,0,536,537,1,0,0,0,537,541,1,0,0,0,538,536,1,0,0,0,539,540,
        5,47,0,0,540,542,3,88,44,0,541,539,1,0,0,0,541,542,1,0,0,0,542,543,
        1,0,0,0,543,544,5,65,0,0,544,551,1,0,0,0,545,547,7,2,0,0,546,548,
        3,16,8,0,547,546,1,0,0,0,547,548,1,0,0,0,548,549,1,0,0,0,549,551,
        3,42,21,0,550,528,1,0,0,0,550,545,1,0,0,0,551,61,1,0,0,0,552,553,
        3,16,8,0,553,554,3,60,30,0,554,63,1,0,0,0,555,560,3,66,33,0,556,
        557,5,66,0,0,557,559,3,66,33,0,558,556,1,0,0,0,559,562,1,0,0,0,560,
        558,1,0,0,0,560,561,1,0,0,0,561,65,1,0,0,0,562,560,1,0,0,0,563,566,
        3,68,34,0,564,565,5,68,0,0,565,567,3,70,35,0,566,564,1,0,0,0,566,
        567,1,0,0,0,567,67,1,0,0,0,568,573,5,102,0,0,569,570,5,63,0,0,570,
        572,5,64,0,0,571,569,1,0,0,0,572,575,1,0,0,0,573,571,1,0,0,0,573,
        574,1,0,0,0,574,69,1,0,0,0,575,573,1,0,0,0,576,579,3,72,36,0,577,
        579,3,184,92,0,578,576,1,0,0,0,578,577,1,0,0,0,579,71,1,0,0,0,580,
        592,5,61,0,0,581,586,3,70,35,0,582,583,5,66,0,0,583,585,3,70,35,
        0,584,582,1,0,0,0,585,588,1,0,0,0,586,584,1,0,0,0,586,587,1,0,0,
        0,587,590,1,0,0,0,588,586,1,0,0,0,589,591,5,66,0,0,590,589,1,0,0,
        0,590,591,1,0,0,0,591,593,1,0,0,0,592,581,1,0,0,0,592,593,1,0,0,
        0,593,594,1,0,0,0,594,595,5,62,0,0,595,73,1,0,0,0,596,597,5,102,
        0,0,597,75,1,0,0,0,598,603,3,78,39,0,599,600,5,63,0,0,600,602,5,
        64,0,0,601,599,1,0,0,0,602,605,1,0,0,0,603,601,1,0,0,0,603,604,1,
        0,0,0,604,615,1,0,0,0,605,603,1,0,0,0,606,611,3,80,40,0,607,608,
        5,63,0,0,608,610,5,64,0,0,609,607,1,0,0,0,610,613,1,0,0,0,611,609,
        1,0,0,0,611,612,1,0,0,0,612,615,1,0,0,0,613,611,1,0,0,0,614,598,
        1,0,0,0,614,606,1,0,0,0,615,77,1,0,0,0,616,618,5,102,0,0,617,619,
        3,82,41,0,618,617,1,0,0,0,618,619,1,0,0,0,619,627,1,0,0,0,620,621,
        5,67,0,0,621,623,5,102,0,0,622,624,3,82,41,0,623,622,1,0,0,0,623,
        624,1,0,0,0,624,626,1,0,0,0,625,620,1,0,0,0,626,629,1,0,0,0,627,
        625,1,0,0,0,627,628,1,0,0,0,628,79,1,0,0,0,629,627,1,0,0,0,630,631,
        7,3,0,0,631,81,1,0,0,0,632,633,5,70,0,0,633,638,3,84,42,0,634,635,
        5,66,0,0,635,637,3,84,42,0,636,634,1,0,0,0,637,640,1,0,0,0,638,636,
        1,0,0,0,638,639,1,0,0,0,639,641,1,0,0,0,640,638,1,0,0,0,641,642,
        5,69,0,0,642,83,1,0,0,0,643,645,3,106,53,0,644,643,1,0,0,0,644,645,
        1,0,0,0,645,646,1,0,0,0,646,647,3,86,43,0,647,85,1,0,0,0,648,655,
        3,76,38,0,649,652,5,73,0,0,650,651,7,4,0,0,651,653,3,76,38,0,652,
        650,1,0,0,0,652,653,1,0,0,0,653,655,1,0,0,0,654,648,1,0,0,0,654,
        649,1,0,0,0,655,87,1,0,0,0,656,661,3,102,51,0,657,658,5,66,0,0,658,
        660,3,102,51,0,659,657,1,0,0,0,660,663,1,0,0,0,661,659,1,0,0,0,661,
        662,1,0,0,0,662,89,1,0,0,0,663,661,1,0,0,0,664,666,5,59,0,0,665,
        667,3,92,46,0,666,665,1,0,0,0,666,667,1,0,0,0,667,668,1,0,0,0,668,
        669,5,60,0,0,669,91,1,0,0,0,670,675,3,94,47,0,671,672,5,66,0,0,672,
        674,3,94,47,0,673,671,1,0,0,0,674,677,1,0,0,0,675,673,1,0,0,0,675,
        676,1,0,0,0,676,680,1,0,0,0,677,675,1,0,0,0,678,679,5,66,0,0,679,
        681,3,96,48,0,680,678,1,0,0,0,680,681,1,0,0,0,681,684,1,0,0,0,682,
        684,3,96,48,0,683,670,1,0,0,0,683,682,1,0,0,0,684,93,1,0,0,0,685,
        687,3,12,6,0,686,685,1,0,0,0,687,690,1,0,0,0,688,686,1,0,0,0,688,
        689,1,0,0,0,689,691,1,0,0,0,690,688,1,0,0,0,691,692,3,76,38,0,692,
        693,3,68,34,0,693,95,1,0,0,0,694,696,3,12,6,0,695,694,1,0,0,0,696,
        699,1,0,0,0,697,695,1,0,0,0,697,698,1,0,0,0,698,700,1,0,0,0,699,
        697,1,0,0,0,700,701,3,76,38,0,701,702,5,104,0,0,702,703,3,68,34,
        0,703,97,1,0,0,0,704,705,3,134,67,0,705,99,1,0,0,0,706,707,3,134,
        67,0,707,101,1,0,0,0,708,713,5,102,0,0,709,710,5,67,0,0,710,712,
        5,102,0,0,711,709,1,0,0,0,712,715,1,0,0,0,713,711,1,0,0,0,713,714,
        1,0,0,0,714,103,1,0,0,0,715,713,1,0,0,0,716,717,7,5,0,0,717,105,
        1,0,0,0,718,719,5,103,0,0,719,726,3,108,54,0,720,723,5,59,0,0,721,
        724,3,110,55,0,722,724,3,114,57,0,723,721,1,0,0,0,723,722,1,0,0,
        0,723,724,1,0,0,0,724,725,1,0,0,0,725,727,5,60,0,0,726,720,1,0,0,
        0,726,727,1,0,0,0,727,107,1,0,0,0,728,729,3,102,51,0,729,109,1,0,
        0,0,730,735,3,112,56,0,731,732,5,66,0,0,732,734,3,112,56,0,733,731,
        1,0,0,0,734,737,1,0,0,0,735,733,1,0,0,0,735,736,1,0,0,0,736,111,
        1,0,0,0,737,735,1,0,0,0,738,739,5,102,0,0,739,740,5,68,0,0,740,741,
        3,114,57,0,741,113,1,0,0,0,742,746,3,184,92,0,743,746,3,106,53,0,
        744,746,3,116,58,0,745,742,1,0,0,0,745,743,1,0,0,0,745,744,1,0,0,
        0,746,115,1,0,0,0,747,756,5,61,0,0,748,753,3,114,57,0,749,750,5,
        66,0,0,750,752,3,114,57,0,751,749,1,0,0,0,752,755,1,0,0,0,753,751,
        1,0,0,0,753,754,1,0,0,0,754,757,1,0,0,0,755,753,1,0,0,0,756,748,
        1,0,0,0,756,757,1,0,0,0,757,759,1,0,0,0,758,760,5,66,0,0,759,758,
        1,0,0,0,759,760,1,0,0,0,760,761,1,0,0,0,761,762,5,62,0,0,762,117,
        1,0,0,0,763,764,5,103,0,0,764,765,5,30,0,0,765,766,5,102,0,0,766,
        767,3,120,60,0,767,119,1,0,0,0,768,772,5,61,0,0,769,771,3,122,61,
        0,770,769,1,0,0,0,771,774,1,0,0,0,772,770,1,0,0,0,772,773,1,0,0,
        0,773,775,1,0,0,0,774,772,1,0,0,0,775,776,5,62,0,0,776,121,1,0,0,
        0,777,779,3,8,4,0,778,777,1,0,0,0,779,782,1,0,0,0,780,778,1,0,0,
        0,780,781,1,0,0,0,781,783,1,0,0,0,782,780,1,0,0,0,783,786,3,124,
        62,0,784,786,5,65,0,0,785,780,1,0,0,0,785,784,1,0,0,0,786,123,1,
        0,0,0,787,788,3,76,38,0,788,789,3,126,63,0,789,790,5,65,0,0,790,
        808,1,0,0,0,791,793,3,14,7,0,792,794,5,65,0,0,793,792,1,0,0,0,793,
        794,1,0,0,0,794,808,1,0,0,0,795,797,3,30,15,0,796,798,5,65,0,0,797,
        796,1,0,0,0,797,798,1,0,0,0,798,808,1,0,0,0,799,801,3,22,11,0,800,
        802,5,65,0,0,801,800,1,0,0,0,801,802,1,0,0,0,802,808,1,0,0,0,803,
        805,3,118,59,0,804,806,5,65,0,0,805,804,1,0,0,0,805,806,1,0,0,0,
        806,808,1,0,0,0,807,787,1,0,0,0,807,791,1,0,0,0,807,795,1,0,0,0,
        807,799,1,0,0,0,807,803,1,0,0,0,808,125,1,0,0,0,809,812,3,128,64,
        0,810,812,3,130,65,0,811,809,1,0,0,0,811,810,1,0,0,0,812,127,1,0,
        0,0,813,814,5,102,0,0,814,815,5,59,0,0,815,817,5,60,0,0,816,818,
        3,132,66,0,817,816,1,0,0,0,817,818,1,0,0,0,818,129,1,0,0,0,819,820,
        3,64,32,0,820,131,1,0,0,0,821,822,5,14,0,0,822,823,3,114,57,0,823,
        133,1,0,0,0,824,828,5,61,0,0,825,827,3,136,68,0,826,825,1,0,0,0,
        827,830,1,0,0,0,828,826,1,0,0,0,828,829,1,0,0,0,829,831,1,0,0,0,
        830,828,1,0,0,0,831,832,5,62,0,0,832,135,1,0,0,0,833,837,3,138,69,
        0,834,837,3,142,71,0,835,837,3,6,3,0,836,833,1,0,0,0,836,834,1,0,
        0,0,836,835,1,0,0,0,837,137,1,0,0,0,838,839,3,140,70,0,839,840,5,
        65,0,0,840,139,1,0,0,0,841,843,3,12,6,0,842,841,1,0,0,0,843,846,
        1,0,0,0,844,842,1,0,0,0,844,845,1,0,0,0,845,847,1,0,0,0,846,844,
        1,0,0,0,847,848,3,76,38,0,848,849,3,64,32,0,849,141,1,0,0,0,850,
        955,3,134,67,0,851,852,5,4,0,0,852,855,3,184,92,0,853,854,5,74,0,
        0,854,856,3,184,92,0,855,853,1,0,0,0,855,856,1,0,0,0,856,857,1,0,
        0,0,857,858,5,65,0,0,858,955,1,0,0,0,859,860,5,24,0,0,860,861,3,
        168,84,0,861,864,3,142,71,0,862,863,5,17,0,0,863,865,3,142,71,0,
        864,862,1,0,0,0,864,865,1,0,0,0,865,955,1,0,0,0,866,867,5,23,0,0,
        867,868,5,59,0,0,868,869,3,160,80,0,869,870,5,60,0,0,870,871,3,142,
        71,0,871,955,1,0,0,0,872,873,5,52,0,0,873,874,3,168,84,0,874,875,
        3,142,71,0,875,955,1,0,0,0,876,877,5,15,0,0,877,878,3,142,71,0,878,
        879,5,52,0,0,879,880,3,168,84,0,880,881,5,65,0,0,881,955,1,0,0,0,
        882,883,5,49,0,0,883,893,3,134,67,0,884,886,3,144,72,0,885,884,1,
        0,0,0,886,887,1,0,0,0,887,885,1,0,0,0,887,888,1,0,0,0,888,890,1,
        0,0,0,889,891,3,148,74,0,890,889,1,0,0,0,890,891,1,0,0,0,891,894,
        1,0,0,0,892,894,3,148,74,0,893,885,1,0,0,0,893,892,1,0,0,0,894,955,
        1,0,0,0,895,896,5,49,0,0,896,897,3,150,75,0,897,901,3,134,67,0,898,
        900,3,144,72,0,899,898,1,0,0,0,900,903,1,0,0,0,901,899,1,0,0,0,901,
        902,1,0,0,0,902,905,1,0,0,0,903,901,1,0,0,0,904,906,3,148,74,0,905,
        904,1,0,0,0,905,906,1,0,0,0,906,955,1,0,0,0,907,908,5,43,0,0,908,
        909,3,168,84,0,909,913,5,61,0,0,910,912,3,156,78,0,911,910,1,0,0,
        0,912,915,1,0,0,0,913,911,1,0,0,0,913,914,1,0,0,0,914,919,1,0,0,
        0,915,913,1,0,0,0,916,918,3,158,79,0,917,916,1,0,0,0,918,921,1,0,
        0,0,919,917,1,0,0,0,919,920,1,0,0,0,920,922,1,0,0,0,921,919,1,0,
        0,0,922,923,5,62,0,0,923,955,1,0,0,0,924,925,5,44,0,0,925,926,3,
        168,84,0,926,927,3,134,67,0,927,955,1,0,0,0,928,930,5,38,0,0,929,
        931,3,184,92,0,930,929,1,0,0,0,930,931,1,0,0,0,931,932,1,0,0,0,932,
        955,5,65,0,0,933,934,5,46,0,0,934,935,3,184,92,0,935,936,5,65,0,
        0,936,955,1,0,0,0,937,939,5,6,0,0,938,940,5,102,0,0,939,938,1,0,
        0,0,939,940,1,0,0,0,940,941,1,0,0,0,941,955,5,65,0,0,942,944,5,13,
        0,0,943,945,5,102,0,0,944,943,1,0,0,0,944,945,1,0,0,0,945,946,1,
        0,0,0,946,955,5,65,0,0,947,955,5,65,0,0,948,949,3,172,86,0,949,950,
        5,65,0,0,950,955,1,0,0,0,951,952,5,102,0,0,952,953,5,74,0,0,953,
        955,3,142,71,0,954,850,1,0,0,0,954,851,1,0,0,0,954,859,1,0,0,0,954,
        866,1,0,0,0,954,872,1,0,0,0,954,876,1,0,0,0,954,882,1,0,0,0,954,
        895,1,0,0,0,954,907,1,0,0,0,954,924,1,0,0,0,954,928,1,0,0,0,954,
        933,1,0,0,0,954,937,1,0,0,0,954,942,1,0,0,0,954,947,1,0,0,0,954,
        948,1,0,0,0,954,951,1,0,0,0,955,143,1,0,0,0,956,957,5,9,0,0,957,
        961,5,59,0,0,958,960,3,12,6,0,959,958,1,0,0,0,960,963,1,0,0,0,961,
        959,1,0,0,0,961,962,1,0,0,0,962,964,1,0,0,0,963,961,1,0,0,0,964,
        965,3,146,73,0,965,966,5,102,0,0,966,967,5,60,0,0,967,968,3,134,
        67,0,968,145,1,0,0,0,969,974,3,102,51,0,970,971,5,88,0,0,971,973,
        3,102,51,0,972,970,1,0,0,0,973,976,1,0,0,0,974,972,1,0,0,0,974,975,
        1,0,0,0,975,147,1,0,0,0,976,974,1,0,0,0,977,978,5,21,0,0,978,979,
        3,134,67,0,979,149,1,0,0,0,980,981,5,59,0,0,981,983,3,152,76,0,982,
        984,5,65,0,0,983,982,1,0,0,0,983,984,1,0,0,0,984,985,1,0,0,0,985,
        986,5,60,0,0,986,151,1,0,0,0,987,992,3,154,77,0,988,989,5,65,0,0,
        989,991,3,154,77,0,990,988,1,0,0,0,991,994,1,0,0,0,992,990,1,0,0,
        0,992,993,1,0,0,0,993,153,1,0,0,0,994,992,1,0,0,0,995,997,3,12,6,
        0,996,995,1,0,0,0,997,1000,1,0,0,0,998,996,1,0,0,0,998,999,1,0,0,
        0,999,1001,1,0,0,0,1000,998,1,0,0,0,1001,1002,3,78,39,0,1002,1003,
        3,68,34,0,1003,1004,5,68,0,0,1004,1005,3,184,92,0,1005,155,1,0,0,
        0,1006,1008,3,158,79,0,1007,1006,1,0,0,0,1008,1009,1,0,0,0,1009,
        1007,1,0,0,0,1009,1010,1,0,0,0,1010,1012,1,0,0,0,1011,1013,3,136,
        68,0,1012,1011,1,0,0,0,1013,1014,1,0,0,0,1014,1012,1,0,0,0,1014,
        1015,1,0,0,0,1015,157,1,0,0,0,1016,1017,5,8,0,0,1017,1018,3,174,
        87,0,1018,1019,5,74,0,0,1019,1027,1,0,0,0,1020,1021,5,8,0,0,1021,
        1022,3,74,37,0,1022,1023,5,74,0,0,1023,1027,1,0,0,0,1024,1025,5,
        14,0,0,1025,1027,5,74,0,0,1026,1016,1,0,0,0,1026,1020,1,0,0,0,1026,
        1024,1,0,0,0,1027,159,1,0,0,0,1028,1041,3,164,82,0,1029,1031,3,162,
        81,0,1030,1029,1,0,0,0,1030,1031,1,0,0,0,1031,1032,1,0,0,0,1032,
        1034,5,65,0,0,1033,1035,3,184,92,0,1034,1033,1,0,0,0,1034,1035,1,
        0,0,0,1035,1036,1,0,0,0,1036,1038,5,65,0,0,1037,1039,3,166,83,0,
        1038,1037,1,0,0,0,1038,1039,1,0,0,0,1039,1041,1,0,0,0,1040,1028,
        1,0,0,0,1040,1030,1,0,0,0,1041,161,1,0,0,0,1042,1045,3,140,70,0,
        1043,1045,3,170,85,0,1044,1042,1,0,0,0,1044,1043,1,0,0,0,1045,163,
        1,0,0,0,1046,1048,3,12,6,0,1047,1046,1,0,0,0,1048,1051,1,0,0,0,1049,
        1047,1,0,0,0,1049,1050,1,0,0,0,1050,1052,1,0,0,0,1051,1049,1,0,0,
        0,1052,1053,3,76,38,0,1053,1054,3,68,34,0,1054,1055,5,74,0,0,1055,
        1056,3,184,92,0,1056,165,1,0,0,0,1057,1058,3,170,85,0,1058,167,1,
        0,0,0,1059,1060,5,59,0,0,1060,1061,3,184,92,0,1061,1062,5,60,0,0,
        1062,169,1,0,0,0,1063,1068,3,184,92,0,1064,1065,5,66,0,0,1065,1067,
        3,184,92,0,1066,1064,1,0,0,0,1067,1070,1,0,0,0,1068,1066,1,0,0,0,
        1068,1069,1,0,0,0,1069,171,1,0,0,0,1070,1068,1,0,0,0,1071,1072,3,
        184,92,0,1072,173,1,0,0,0,1073,1074,3,184,92,0,1074,175,1,0,0,0,
        1075,1076,3,178,89,0,1076,1077,5,1,0,0,1077,1078,3,182,91,0,1078,
        177,1,0,0,0,1079,1090,5,102,0,0,1080,1082,5,59,0,0,1081,1083,3,92,
        46,0,1082,1081,1,0,0,0,1082,1083,1,0,0,0,1083,1084,1,0,0,0,1084,
        1090,5,60,0,0,1085,1086,5,59,0,0,1086,1087,3,180,90,0,1087,1088,
        5,60,0,0,1088,1090,1,0,0,0,1089,1079,1,0,0,0,1089,1080,1,0,0,0,1089,
        1085,1,0,0,0,1090,179,1,0,0,0,1091,1096,5,102,0,0,1092,1093,5,66,
        0,0,1093,1095,5,102,0,0,1094,1092,1,0,0,0,1095,1098,1,0,0,0,1096,
        1094,1,0,0,0,1096,1097,1,0,0,0,1097,181,1,0,0,0,1098,1096,1,0,0,
        0,1099,1102,3,184,92,0,1100,1102,3,134,67,0,1101,1099,1,0,0,0,1101,
        1100,1,0,0,0,1102,183,1,0,0,0,1103,1104,6,92,-1,0,1104,1118,3,186,
        93,0,1105,1106,5,33,0,0,1106,1118,3,188,94,0,1107,1108,5,59,0,0,
        1108,1109,3,76,38,0,1109,1110,5,60,0,0,1110,1111,3,184,92,21,1111,
        1118,1,0,0,0,1112,1113,7,6,0,0,1113,1118,3,184,92,19,1114,1115,7,
        7,0,0,1115,1118,3,184,92,18,1116,1118,3,176,88,0,1117,1103,1,0,0,
        0,1117,1105,1,0,0,0,1117,1107,1,0,0,0,1117,1112,1,0,0,0,1117,1114,
        1,0,0,0,1117,1116,1,0,0,0,1118,1224,1,0,0,0,1119,1120,10,17,0,0,
        1120,1121,7,8,0,0,1121,1223,3,184,92,18,1122,1123,10,16,0,0,1123,
        1124,7,9,0,0,1124,1223,3,184,92,17,1125,1133,10,15,0,0,1126,1127,
        5,70,0,0,1127,1134,5,70,0,0,1128,1129,5,69,0,0,1129,1130,5,69,0,
        0,1130,1134,5,69,0,0,1131,1132,5,69,0,0,1132,1134,5,69,0,0,1133,
        1126,1,0,0,0,1133,1128,1,0,0,0,1133,1131,1,0,0,0,1134,1135,1,0,0,
        0,1135,1223,3,184,92,16,1136,1137,10,14,0,0,1137,1138,7,10,0,0,1138,
        1223,3,184,92,15,1139,1140,10,12,0,0,1140,1141,7,11,0,0,1141,1223,
        3,184,92,13,1142,1143,10,11,0,0,1143,1144,5,87,0,0,1144,1223,3,184,
        92,12,1145,1146,10,10,0,0,1146,1147,5,89,0,0,1147,1223,3,184,92,
        11,1148,1149,10,9,0,0,1149,1150,5,88,0,0,1150,1223,3,184,92,10,1151,
        1152,10,8,0,0,1152,1153,5,79,0,0,1153,1223,3,184,92,9,1154,1155,
        10,7,0,0,1155,1156,5,80,0,0,1156,1223,3,184,92,8,1157,1158,10,6,
        0,0,1158,1159,5,73,0,0,1159,1160,3,184,92,0,1160,1161,5,74,0,0,1161,
        1162,3,184,92,7,1162,1223,1,0,0,0,1163,1164,10,1,0,0,1164,1165,7,
        12,0,0,1165,1223,3,184,92,1,1166,1167,10,29,0,0,1167,1168,5,67,0,
        0,1168,1223,5,102,0,0,1169,1170,10,28,0,0,1170,1171,5,67,0,0,1171,
        1223,5,45,0,0,1172,1173,10,27,0,0,1173,1174,5,67,0,0,1174,1176,5,
        33,0,0,1175,1177,3,200,100,0,1176,1175,1,0,0,0,1176,1177,1,0,0,0,
        1177,1178,1,0,0,0,1178,1223,3,192,96,0,1179,1180,10,26,0,0,1180,
        1181,5,67,0,0,1181,1182,5,42,0,0,1182,1223,3,206,103,0,1183,1184,
        10,25,0,0,1184,1185,5,67,0,0,1185,1223,3,198,99,0,1186,1187,10,24,
        0,0,1187,1188,5,63,0,0,1188,1189,3,184,92,0,1189,1190,5,64,0,0,1190,
        1223,1,0,0,0,1191,1192,10,23,0,0,1192,1194,5,59,0,0,1193,1195,3,
        170,85,0,1194,1193,1,0,0,0,1194,1195,1,0,0,0,1195,1196,1,0,0,0,1196,
        1223,5,60,0,0,1197,1198,10,20,0,0,1198,1223,7,13,0,0,1199,1200,10,
        13,0,0,1200,1201,5,28,0,0,1201,1223,3,76,38,0,1202,1203,10,4,0,0,
        1203,1205,5,2,0,0,1204,1206,3,82,41,0,1205,1204,1,0,0,0,1205,1206,
        1,0,0,0,1206,1207,1,0,0,0,1207,1223,5,102,0,0,1208,1209,10,3,0,0,
        1209,1211,5,2,0,0,1210,1212,3,82,41,0,1211,1210,1,0,0,0,1211,1212,
        1,0,0,0,1212,1213,1,0,0,0,1213,1223,5,33,0,0,1214,1215,10,2,0,0,
        1215,1216,5,63,0,0,1216,1217,5,64,0,0,1217,1219,5,2,0,0,1218,1220,
        3,82,41,0,1219,1218,1,0,0,0,1219,1220,1,0,0,0,1220,1221,1,0,0,0,
        1221,1223,5,33,0,0,1222,1119,1,0,0,0,1222,1122,1,0,0,0,1222,1125,
        1,0,0,0,1222,1136,1,0,0,0,1222,1139,1,0,0,0,1222,1142,1,0,0,0,1222,
        1145,1,0,0,0,1222,1148,1,0,0,0,1222,1151,1,0,0,0,1222,1154,1,0,0,
        0,1222,1157,1,0,0,0,1222,1163,1,0,0,0,1222,1166,1,0,0,0,1222,1169,
        1,0,0,0,1222,1172,1,0,0,0,1222,1179,1,0,0,0,1222,1183,1,0,0,0,1222,
        1186,1,0,0,0,1222,1191,1,0,0,0,1222,1197,1,0,0,0,1222,1199,1,0,0,
        0,1222,1202,1,0,0,0,1222,1208,1,0,0,0,1222,1214,1,0,0,0,1223,1226,
        1,0,0,0,1224,1222,1,0,0,0,1224,1225,1,0,0,0,1225,185,1,0,0,0,1226,
        1224,1,0,0,0,1227,1228,5,59,0,0,1228,1229,3,184,92,0,1229,1230,5,
        60,0,0,1230,1249,1,0,0,0,1231,1249,5,45,0,0,1232,1249,5,42,0,0,1233,
        1249,3,104,52,0,1234,1249,5,102,0,0,1235,1236,3,76,38,0,1236,1237,
        5,67,0,0,1237,1238,5,11,0,0,1238,1249,1,0,0,0,1239,1240,5,50,0,0,
        1240,1241,5,67,0,0,1241,1249,5,11,0,0,1242,1246,3,200,100,0,1243,
        1247,3,208,104,0,1244,1245,5,45,0,0,1245,1247,3,210,105,0,1246,1243,
        1,0,0,0,1246,1244,1,0,0,0,1247,1249,1,0,0,0,1248,1227,1,0,0,0,1248,
        1231,1,0,0,0,1248,1232,1,0,0,0,1248,1233,1,0,0,0,1248,1234,1,0,0,
        0,1248,1235,1,0,0,0,1248,1239,1,0,0,0,1248,1242,1,0,0,0,1249,187,
        1,0,0,0,1250,1251,3,200,100,0,1251,1252,3,190,95,0,1252,1253,3,196,
        98,0,1253,1260,1,0,0,0,1254,1257,3,190,95,0,1255,1258,3,194,97,0,
        1256,1258,3,196,98,0,1257,1255,1,0,0,0,1257,1256,1,0,0,0,1258,1260,
        1,0,0,0,1259,1250,1,0,0,0,1259,1254,1,0,0,0,1260,189,1,0,0,0,1261,
        1263,5,102,0,0,1262,1264,3,202,101,0,1263,1262,1,0,0,0,1263,1264,
        1,0,0,0,1264,1272,1,0,0,0,1265,1266,5,67,0,0,1266,1268,5,102,0,0,
        1267,1269,3,202,101,0,1268,1267,1,0,0,0,1268,1269,1,0,0,0,1269,1271,
        1,0,0,0,1270,1265,1,0,0,0,1271,1274,1,0,0,0,1272,1270,1,0,0,0,1272,
        1273,1,0,0,0,1273,1277,1,0,0,0,1274,1272,1,0,0,0,1275,1277,3,80,
        40,0,1276,1261,1,0,0,0,1276,1275,1,0,0,0,1277,191,1,0,0,0,1278,1280,
        5,102,0,0,1279,1281,3,204,102,0,1280,1279,1,0,0,0,1280,1281,1,0,
        0,0,1281,1282,1,0,0,0,1282,1283,3,196,98,0,1283,193,1,0,0,0,1284,
        1312,5,63,0,0,1285,1290,5,64,0,0,1286,1287,5,63,0,0,1287,1289,5,
        64,0,0,1288,1286,1,0,0,0,1289,1292,1,0,0,0,1290,1288,1,0,0,0,1290,
        1291,1,0,0,0,1291,1293,1,0,0,0,1292,1290,1,0,0,0,1293,1313,3,72,
        36,0,1294,1295,3,184,92,0,1295,1302,5,64,0,0,1296,1297,5,63,0,0,
        1297,1298,3,184,92,0,1298,1299,5,64,0,0,1299,1301,1,0,0,0,1300,1296,
        1,0,0,0,1301,1304,1,0,0,0,1302,1300,1,0,0,0,1302,1303,1,0,0,0,1303,
        1309,1,0,0,0,1304,1302,1,0,0,0,1305,1306,5,63,0,0,1306,1308,5,64,
        0,0,1307,1305,1,0,0,0,1308,1311,1,0,0,0,1309,1307,1,0,0,0,1309,1310,
        1,0,0,0,1310,1313,1,0,0,0,1311,1309,1,0,0,0,1312,1285,1,0,0,0,1312,
        1294,1,0,0,0,1313,195,1,0,0,0,1314,1316,3,210,105,0,1315,1317,3,
        34,17,0,1316,1315,1,0,0,0,1316,1317,1,0,0,0,1317,197,1,0,0,0,1318,
        1319,3,200,100,0,1319,1320,3,208,104,0,1320,199,1,0,0,0,1321,1322,
        5,70,0,0,1322,1323,3,32,16,0,1323,1324,5,69,0,0,1324,201,1,0,0,0,
        1325,1326,5,70,0,0,1326,1329,5,69,0,0,1327,1329,3,82,41,0,1328,1325,
        1,0,0,0,1328,1327,1,0,0,0,1329,203,1,0,0,0,1330,1331,5,70,0,0,1331,
        1334,5,69,0,0,1332,1334,3,200,100,0,1333,1330,1,0,0,0,1333,1332,
        1,0,0,0,1334,205,1,0,0,0,1335,1342,3,210,105,0,1336,1337,5,67,0,
        0,1337,1339,5,102,0,0,1338,1340,3,210,105,0,1339,1338,1,0,0,0,1339,
        1340,1,0,0,0,1340,1342,1,0,0,0,1341,1335,1,0,0,0,1341,1336,1,0,0,
        0,1342,207,1,0,0,0,1343,1344,5,42,0,0,1344,1348,3,206,103,0,1345,
        1346,5,102,0,0,1346,1348,3,210,105,0,1347,1343,1,0,0,0,1347,1345,
        1,0,0,0,1348,209,1,0,0,0,1349,1351,5,59,0,0,1350,1352,3,170,85,0,
        1351,1350,1,0,0,0,1351,1352,1,0,0,0,1352,1353,1,0,0,0,1353,1354,
        5,60,0,0,1354,211,1,0,0,0,160,213,218,224,232,241,246,253,260,267,
        274,279,283,287,291,296,300,304,314,322,328,335,342,346,349,352,
        361,367,372,375,381,387,391,400,407,416,423,429,433,444,448,456,
        461,465,474,488,493,502,510,520,528,536,541,547,550,560,566,573,
        578,586,590,592,603,611,614,618,623,627,638,644,652,654,661,666,
        675,680,683,688,697,713,723,726,735,745,753,756,759,772,780,785,
        793,797,801,805,807,811,817,828,836,844,855,864,887,890,893,901,
        905,913,919,930,939,944,954,961,974,983,992,998,1009,1014,1026,1030,
        1034,1038,1040,1044,1049,1068,1082,1089,1096,1101,1117,1133,1176,
        1194,1205,1211,1219,1222,1224,1246,1248,1257,1259,1263,1268,1272,
        1276,1280,1290,1302,1309,1312,1316,1328,1333,1339,1341,1347,1351
    ]

class JavaParser ( Parser ):

    grammarFileName = "Java.g4"

    atn = ATNDeserializer().deserialize(serializedATN())

    decisionsToDFA = [ DFA(ds, i) for i, ds in enumerate(atn.decisionToState) ]

    sharedContextCache = PredictionContextCache()

    literalNames = [ "<INVALID>", "'->'", "'::'", "'abstract'", "'assert'", 
                     "'boolean'", "'break'", "'byte'", "'case'", "'catch'", 
                     "'char'", "'class'", "'const'", "'continue'", "'default'", 
                     "'do'", "'double'", "'else'", "'enum'", "'extends'", 
                     "'final'", "'finally'", "'float'", "'for'", "'if'", 
                     "'goto'", "'implements'", "'import'", "'instanceof'", 
                     "'int'", "'interface'", "'long'", "'native'", "'new'", 
                     "'package'", "'private'", "'protected'", "'public'", 
                     "'return'", "'short'", "'static'", "'strictfp'", "'super'", 
                     "'switch'", "'synchronized'", "'this'", "'throw'", 
                     "'throws'", "'transient'", "'try'", "'void'", "'volatile'", 
                     "'while'", "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "'null'", "'('", "')'", "'{'", "'}'", 
                     "'['", "']'", "';'", "','", "'.'", "'='", "'>'", "'<'", 
                     "'!'", "'~'", "'?'", "':'", "'=='", "'<='", "'>='", 
                     "'!='", "'&&'", "'||'", "'++'", "'--'", "'+'", "'-'", 
                     "'*'", "'/'", "'&'", "'|'", "'^'", "'%'", "'+='", "'-='", 
                     "'*='", "'/='", "'&='", "'|='", "'^='", "'%='", "'<<='", 
                     "'>>='", "'>>>='", "<INVALID>", "'@'", "'...'" ]

    symbolicNames = [ "<INVALID>", "<INVALID>", "<INVALID>", "ABSTRACT", 
                      "ASSERT", "BOOLEAN", "BREAK", "BYTE", "CASE", "CATCH", 
                      "CHAR", "CLASS", "CONST", "CONTINUE", "DEFAULT", "DO", 
                      "DOUBLE", "ELSE", "ENUM", "EXTENDS", "FINAL", "FINALLY", 
                      "FLOAT", "FOR", "IF", "GOTO", "IMPLEMENTS", "IMPORT", 
                      "INSTANCEOF", "INT", "INTERFACE", "LONG", "NATIVE", 
                      "NEW", "PACKAGE", "PRIVATE", "PROTECTED", "PUBLIC", 
                      "RETURN", "SHORT", "STATIC", "STRICTFP", "SUPER", 
                      "SWITCH", "SYNCHRONIZED", "THIS", "THROW", "THROWS", 
                      "TRANSIENT", "TRY", "VOID", "VOLATILE", "WHILE", "IntegerLiteral", 
                      "FloatingPointLiteral", "BooleanLiteral", "CharacterLiteral", 
                      "StringLiteral", "NullLiteral", "LPAREN", "RPAREN", 
                      "LBRACE", "RBRACE", "LBRACK", "RBRACK", "SEMI", "COMMA", 
                      "DOT", "ASSIGN", "GT", "LT", "BANG", "TILDE", "QUESTION", 
                      "COLON", "EQUAL", "LE", "GE", "NOTEQUAL", "AND", "OR", 
                      "INC", "DEC", "ADD", "SUB", "MUL", "DIV", "BITAND", 
                      "BITOR", "CARET", "MOD", "ADD_ASSIGN", "SUB_ASSIGN", 
                      "MUL_ASSIGN", "DIV_ASSIGN", "AND_ASSIGN", "OR_ASSIGN", 
                      "XOR_ASSIGN", "MOD_ASSIGN", "LSHIFT_ASSIGN", "RSHIFT_ASSIGN", 
                      "URSHIFT_ASSIGN", "Identifier", "AT", "ELLIPSIS", 
                      "WS", "COMMENT", "LINE_COMMENT" ]

    RULE_compilationUnit = 0
    RULE_packageDeclaration = 1
    RULE_importDeclaration = 2
    RULE_typeDeclaration = 3
    RULE_modifier = 4
    RULE_classOrInterfaceModifier = 5
    RULE_variableModifier = 6
    RULE_classDeclaration = 7
    RULE_typeParameters = 8
    RULE_typeParameter = 9
    RULE_typeBound = 10
    RULE_enumDeclaration = 11
    RULE_enumConstants = 12
    RULE_enumConstant = 13
    RULE_enumBodyDeclarations = 14
    RULE_interfaceDeclaration = 15
    RULE_typeList = 16
    RULE_classBody = 17
    RULE_interfaceBody = 18
    RULE_classBodyDeclaration = 19
    RULE_memberDeclaration = 20
    RULE_methodDeclaration = 21
    RULE_genericMethodDeclaration = 22
    RULE_constructorDeclaration = 23
    RULE_genericConstructorDeclaration = 24
    RULE_fieldDeclaration = 25
    RULE_interfaceBodyDeclaration = 26
    RULE_interfaceMemberDeclaration = 27
    RULE_constDeclaration = 28
    RULE_constantDeclarator = 29
    RULE_interfaceMethodDeclaration = 30
    RULE_genericInterfaceMethodDeclaration = 31
    RULE_variableDeclarators = 32
    RULE_variableDeclarator = 33
    RULE_variableDeclaratorId = 34
    RULE_variableInitializer = 35
    RULE_arrayInitializer = 36
    RULE_enumConstantName = 37
    RULE_jType = 38
    RULE_classOrInterfaceType = 39
    RULE_primitiveType = 40
    RULE_typeArguments = 41
    RULE_typeArgumentAnnotation = 42
    RULE_typeArgument = 43
    RULE_qualifiedNameList = 44
    RULE_formalParameters = 45
    RULE_formalParameterList = 46
    RULE_formalParameter = 47
    RULE_lastFormalParameter = 48
    RULE_methodBody = 49
    RULE_constructorBody = 50
    RULE_qualifiedName = 51
    RULE_literal = 52
    RULE_annotation = 53
    RULE_annotationName = 54
    RULE_elementValuePairs = 55
    RULE_elementValuePair = 56
    RULE_elementValue = 57
    RULE_elementValueArrayInitializer = 58
    RULE_annotationTypeDeclaration = 59
    RULE_annotationTypeBody = 60
    RULE_annotationTypeElementDeclaration = 61
    RULE_annotationTypeElementRest = 62
    RULE_annotationMethodOrConstantRest = 63
    RULE_annotationMethodRest = 64
    RULE_annotationConstantRest = 65
    RULE_defaultValue = 66
    RULE_block = 67
    RULE_blockStatement = 68
    RULE_localVariableDeclarationStatement = 69
    RULE_localVariableDeclaration = 70
    RULE_statement = 71
    RULE_catchClause = 72
    RULE_catchType = 73
    RULE_finallyBlock = 74
    RULE_resourceSpecification = 75
    RULE_resources = 76
    RULE_resource = 77
    RULE_switchBlockStatementGroup = 78
    RULE_switchLabel = 79
    RULE_forControl = 80
    RULE_forInit = 81
    RULE_enhancedForControl = 82
    RULE_forUpdate = 83
    RULE_parExpression = 84
    RULE_expressionList = 85
    RULE_statementExpression = 86
    RULE_constantExpression = 87
    RULE_lambdaExpression = 88
    RULE_lambdaParameters = 89
    RULE_inferredFormalParameterList = 90
    RULE_lambdaBody = 91
    RULE_expression = 92
    RULE_primary = 93
    RULE_creator = 94
    RULE_createdName = 95
    RULE_innerCreator = 96
    RULE_arrayCreatorRest = 97
    RULE_classCreatorRest = 98
    RULE_explicitGenericInvocation = 99
    RULE_nonWildcardTypeArguments = 100
    RULE_typeArgumentsOrDiamond = 101
    RULE_nonWildcardTypeArgumentsOrDiamond = 102
    RULE_superSuffix = 103
    RULE_explicitGenericInvocationSuffix = 104
    RULE_arguments = 105

    ruleNames =  [ "compilationUnit", "packageDeclaration", "importDeclaration", 
                   "typeDeclaration", "modifier", "classOrInterfaceModifier", 
                   "variableModifier", "classDeclaration", "typeParameters", 
                   "typeParameter", "typeBound", "enumDeclaration", "enumConstants", 
                   "enumConstant", "enumBodyDeclarations", "interfaceDeclaration", 
                   "typeList", "classBody", "interfaceBody", "classBodyDeclaration", 
                   "memberDeclaration", "methodDeclaration", "genericMethodDeclaration", 
                   "constructorDeclaration", "genericConstructorDeclaration", 
                   "fieldDeclaration", "interfaceBodyDeclaration", "interfaceMemberDeclaration", 
                   "constDeclaration", "constantDeclarator", "interfaceMethodDeclaration", 
                   "genericInterfaceMethodDeclaration", "variableDeclarators", 
                   "variableDeclarator", "variableDeclaratorId", "variableInitializer", 
                   "arrayInitializer", "enumConstantName", "jType", "classOrInterfaceType", 
                   "primitiveType", "typeArguments", "typeArgumentAnnotation", 
                   "typeArgument", "qualifiedNameList", "formalParameters", 
                   "formalParameterList", "formalParameter", "lastFormalParameter", 
                   "methodBody", "constructorBody", "qualifiedName", "literal", 
                   "annotation", "annotationName", "elementValuePairs", 
                   "elementValuePair", "elementValue", "elementValueArrayInitializer", 
                   "annotationTypeDeclaration", "annotationTypeBody", "annotationTypeElementDeclaration", 
                   "annotationTypeElementRest", "annotationMethodOrConstantRest", 
                   "annotationMethodRest", "annotationConstantRest", "defaultValue", 
                   "block", "blockStatement", "localVariableDeclarationStatement", 
                   "localVariableDeclaration", "statement", "catchClause", 
                   "catchType", "finallyBlock", "resourceSpecification", 
                   "resources", "resource", "switchBlockStatementGroup", 
                   "switchLabel", "forControl", "forInit", "enhancedForControl", 
                   "forUpdate", "parExpression", "expressionList", "statementExpression", 
                   "constantExpression", "lambdaExpression", "lambdaParameters", 
                   "inferredFormalParameterList", "lambdaBody", "expression", 
                   "primary", "creator", "createdName", "innerCreator", 
                   "arrayCreatorRest", "classCreatorRest", "explicitGenericInvocation", 
                   "nonWildcardTypeArguments", "typeArgumentsOrDiamond", 
                   "nonWildcardTypeArgumentsOrDiamond", "superSuffix", "explicitGenericInvocationSuffix", 
                   "arguments" ]

    EOF = Token.EOF
    T__0=1
    T__1=2
    ABSTRACT=3
    ASSERT=4
    BOOLEAN=5
    BREAK=6
    BYTE=7
    CASE=8
    CATCH=9
    CHAR=10
    CLASS=11
    CONST=12
    CONTINUE=13
    DEFAULT=14
    DO=15
    DOUBLE=16
    ELSE=17
    ENUM=18
    EXTENDS=19
    FINAL=20
    FINALLY=21
    FLOAT=22
    FOR=23
    IF=24
    GOTO=25
    IMPLEMENTS=26
    IMPORT=27
    INSTANCEOF=28
    INT=29
    INTERFACE=30
    LONG=31
    NATIVE=32
    NEW=33
    PACKAGE=34
    PRIVATE=35
    PROTECTED=36
    PUBLIC=37
    RETURN=38
    SHORT=39
    STATIC=40
    STRICTFP=41
    SUPER=42
    SWITCH=43
    SYNCHRONIZED=44
    THIS=45
    THROW=46
    THROWS=47
    TRANSIENT=48
    TRY=49
    VOID=50
    VOLATILE=51
    WHILE=52
    IntegerLiteral=53
    FloatingPointLiteral=54
    BooleanLiteral=55
    CharacterLiteral=56
    StringLiteral=57
    NullLiteral=58
    LPAREN=59
    RPAREN=60
    LBRACE=61
    RBRACE=62
    LBRACK=63
    RBRACK=64
    SEMI=65
    COMMA=66
    DOT=67
    ASSIGN=68
    GT=69
    LT=70
    BANG=71
    TILDE=72
    QUESTION=73
    COLON=74
    EQUAL=75
    LE=76
    GE=77
    NOTEQUAL=78
    AND=79
    OR=80
    INC=81
    DEC=82
    ADD=83
    SUB=84
    MUL=85
    DIV=86
    BITAND=87
    BITOR=88
    CARET=89
    MOD=90
    ADD_ASSIGN=91
    SUB_ASSIGN=92
    MUL_ASSIGN=93
    DIV_ASSIGN=94
    AND_ASSIGN=95
    OR_ASSIGN=96
    XOR_ASSIGN=97
    MOD_ASSIGN=98
    LSHIFT_ASSIGN=99
    RSHIFT_ASSIGN=100
    URSHIFT_ASSIGN=101
    Identifier=102
    AT=103
    ELLIPSIS=104
    WS=105
    COMMENT=106
    LINE_COMMENT=107

    def __init__(self, input:TokenStream, output:TextIO = sys.stdout):
        super().__init__(input, output)
        self.checkVersion("4.10.1")
        self._interp = ParserATNSimulator(self, self.atn, self.decisionsToDFA, self.sharedContextCache)
        self._predicates = None




    class CompilationUnitContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def EOF(self):
            return self.getToken(JavaParser.EOF, 0)

        def packageDeclaration(self):
            return self.getTypedRuleContext(JavaParser.PackageDeclarationContext,0)


        def importDeclaration(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.ImportDeclarationContext)
            else:
                return self.getTypedRuleContext(JavaParser.ImportDeclarationContext,i)


        def typeDeclaration(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.TypeDeclarationContext)
            else:
                return self.getTypedRuleContext(JavaParser.TypeDeclarationContext,i)


        def getRuleIndex(self):
            return JavaParser.RULE_compilationUnit

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCompilationUnit" ):
                listener.enterCompilationUnit(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCompilationUnit" ):
                listener.exitCompilationUnit(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitCompilationUnit" ):
                return visitor.visitCompilationUnit(self)
            else:
                return visitor.visitChildren(self)




    def compilationUnit(self):

        localctx = JavaParser.CompilationUnitContext(self, self._ctx, self.state)
        self.enterRule(localctx, 0, self.RULE_compilationUnit)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 213
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,0,self._ctx)
            if la_ == 1:
                self.state = 212
                self.packageDeclaration()


            self.state = 218
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==JavaParser.IMPORT:
                self.state = 215
                self.importDeclaration()
                self.state = 220
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 224
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << JavaParser.ABSTRACT) | (1 << JavaParser.CLASS) | (1 << JavaParser.ENUM) | (1 << JavaParser.FINAL) | (1 << JavaParser.INTERFACE) | (1 << JavaParser.PRIVATE) | (1 << JavaParser.PROTECTED) | (1 << JavaParser.PUBLIC) | (1 << JavaParser.STATIC) | (1 << JavaParser.STRICTFP))) != 0) or _la==JavaParser.SEMI or _la==JavaParser.AT:
                self.state = 221
                self.typeDeclaration()
                self.state = 226
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 227
            self.match(JavaParser.EOF)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class PackageDeclarationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def PACKAGE(self):
            return self.getToken(JavaParser.PACKAGE, 0)

        def qualifiedName(self):
            return self.getTypedRuleContext(JavaParser.QualifiedNameContext,0)


        def SEMI(self):
            return self.getToken(JavaParser.SEMI, 0)

        def annotation(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.AnnotationContext)
            else:
                return self.getTypedRuleContext(JavaParser.AnnotationContext,i)


        def getRuleIndex(self):
            return JavaParser.RULE_packageDeclaration

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPackageDeclaration" ):
                listener.enterPackageDeclaration(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPackageDeclaration" ):
                listener.exitPackageDeclaration(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitPackageDeclaration" ):
                return visitor.visitPackageDeclaration(self)
            else:
                return visitor.visitChildren(self)




    def packageDeclaration(self):

        localctx = JavaParser.PackageDeclarationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 2, self.RULE_packageDeclaration)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 232
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==JavaParser.AT:
                self.state = 229
                self.annotation()
                self.state = 234
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 235
            self.match(JavaParser.PACKAGE)
            self.state = 236
            self.qualifiedName()
            self.state = 237
            self.match(JavaParser.SEMI)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ImportDeclarationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def IMPORT(self):
            return self.getToken(JavaParser.IMPORT, 0)

        def qualifiedName(self):
            return self.getTypedRuleContext(JavaParser.QualifiedNameContext,0)


        def SEMI(self):
            return self.getToken(JavaParser.SEMI, 0)

        def STATIC(self):
            return self.getToken(JavaParser.STATIC, 0)

        def DOT(self):
            return self.getToken(JavaParser.DOT, 0)

        def MUL(self):
            return self.getToken(JavaParser.MUL, 0)

        def getRuleIndex(self):
            return JavaParser.RULE_importDeclaration

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterImportDeclaration" ):
                listener.enterImportDeclaration(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitImportDeclaration" ):
                listener.exitImportDeclaration(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitImportDeclaration" ):
                return visitor.visitImportDeclaration(self)
            else:
                return visitor.visitChildren(self)




    def importDeclaration(self):

        localctx = JavaParser.ImportDeclarationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 4, self.RULE_importDeclaration)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 239
            self.match(JavaParser.IMPORT)
            self.state = 241
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==JavaParser.STATIC:
                self.state = 240
                self.match(JavaParser.STATIC)


            self.state = 243
            self.qualifiedName()
            self.state = 246
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==JavaParser.DOT:
                self.state = 244
                self.match(JavaParser.DOT)
                self.state = 245
                self.match(JavaParser.MUL)


            self.state = 248
            self.match(JavaParser.SEMI)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class TypeDeclarationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def classDeclaration(self):
            return self.getTypedRuleContext(JavaParser.ClassDeclarationContext,0)


        def classOrInterfaceModifier(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.ClassOrInterfaceModifierContext)
            else:
                return self.getTypedRuleContext(JavaParser.ClassOrInterfaceModifierContext,i)


        def enumDeclaration(self):
            return self.getTypedRuleContext(JavaParser.EnumDeclarationContext,0)


        def interfaceDeclaration(self):
            return self.getTypedRuleContext(JavaParser.InterfaceDeclarationContext,0)


        def annotationTypeDeclaration(self):
            return self.getTypedRuleContext(JavaParser.AnnotationTypeDeclarationContext,0)


        def SEMI(self):
            return self.getToken(JavaParser.SEMI, 0)

        def getRuleIndex(self):
            return JavaParser.RULE_typeDeclaration

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTypeDeclaration" ):
                listener.enterTypeDeclaration(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTypeDeclaration" ):
                listener.exitTypeDeclaration(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitTypeDeclaration" ):
                return visitor.visitTypeDeclaration(self)
            else:
                return visitor.visitChildren(self)




    def typeDeclaration(self):

        localctx = JavaParser.TypeDeclarationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 6, self.RULE_typeDeclaration)
        self._la = 0 # Token type
        try:
            self.state = 279
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,10,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 253
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << JavaParser.ABSTRACT) | (1 << JavaParser.FINAL) | (1 << JavaParser.PRIVATE) | (1 << JavaParser.PROTECTED) | (1 << JavaParser.PUBLIC) | (1 << JavaParser.STATIC) | (1 << JavaParser.STRICTFP))) != 0) or _la==JavaParser.AT:
                    self.state = 250
                    self.classOrInterfaceModifier()
                    self.state = 255
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                self.state = 256
                self.classDeclaration()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 260
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << JavaParser.ABSTRACT) | (1 << JavaParser.FINAL) | (1 << JavaParser.PRIVATE) | (1 << JavaParser.PROTECTED) | (1 << JavaParser.PUBLIC) | (1 << JavaParser.STATIC) | (1 << JavaParser.STRICTFP))) != 0) or _la==JavaParser.AT:
                    self.state = 257
                    self.classOrInterfaceModifier()
                    self.state = 262
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                self.state = 263
                self.enumDeclaration()
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 267
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << JavaParser.ABSTRACT) | (1 << JavaParser.FINAL) | (1 << JavaParser.PRIVATE) | (1 << JavaParser.PROTECTED) | (1 << JavaParser.PUBLIC) | (1 << JavaParser.STATIC) | (1 << JavaParser.STRICTFP))) != 0) or _la==JavaParser.AT:
                    self.state = 264
                    self.classOrInterfaceModifier()
                    self.state = 269
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                self.state = 270
                self.interfaceDeclaration()
                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 274
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,9,self._ctx)
                while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                    if _alt==1:
                        self.state = 271
                        self.classOrInterfaceModifier() 
                    self.state = 276
                    self._errHandler.sync(self)
                    _alt = self._interp.adaptivePredict(self._input,9,self._ctx)

                self.state = 277
                self.annotationTypeDeclaration()
                pass

            elif la_ == 5:
                self.enterOuterAlt(localctx, 5)
                self.state = 278
                self.match(JavaParser.SEMI)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ModifierContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def classOrInterfaceModifier(self):
            return self.getTypedRuleContext(JavaParser.ClassOrInterfaceModifierContext,0)


        def NATIVE(self):
            return self.getToken(JavaParser.NATIVE, 0)

        def SYNCHRONIZED(self):
            return self.getToken(JavaParser.SYNCHRONIZED, 0)

        def TRANSIENT(self):
            return self.getToken(JavaParser.TRANSIENT, 0)

        def VOLATILE(self):
            return self.getToken(JavaParser.VOLATILE, 0)

        def getRuleIndex(self):
            return JavaParser.RULE_modifier

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterModifier" ):
                listener.enterModifier(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitModifier" ):
                listener.exitModifier(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitModifier" ):
                return visitor.visitModifier(self)
            else:
                return visitor.visitChildren(self)




    def modifier(self):

        localctx = JavaParser.ModifierContext(self, self._ctx, self.state)
        self.enterRule(localctx, 8, self.RULE_modifier)
        self._la = 0 # Token type
        try:
            self.state = 283
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [JavaParser.ABSTRACT, JavaParser.FINAL, JavaParser.PRIVATE, JavaParser.PROTECTED, JavaParser.PUBLIC, JavaParser.STATIC, JavaParser.STRICTFP, JavaParser.AT]:
                self.enterOuterAlt(localctx, 1)
                self.state = 281
                self.classOrInterfaceModifier()
                pass
            elif token in [JavaParser.NATIVE, JavaParser.SYNCHRONIZED, JavaParser.TRANSIENT, JavaParser.VOLATILE]:
                self.enterOuterAlt(localctx, 2)
                self.state = 282
                _la = self._input.LA(1)
                if not((((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << JavaParser.NATIVE) | (1 << JavaParser.SYNCHRONIZED) | (1 << JavaParser.TRANSIENT) | (1 << JavaParser.VOLATILE))) != 0)):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ClassOrInterfaceModifierContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def annotation(self):
            return self.getTypedRuleContext(JavaParser.AnnotationContext,0)


        def PUBLIC(self):
            return self.getToken(JavaParser.PUBLIC, 0)

        def PROTECTED(self):
            return self.getToken(JavaParser.PROTECTED, 0)

        def PRIVATE(self):
            return self.getToken(JavaParser.PRIVATE, 0)

        def STATIC(self):
            return self.getToken(JavaParser.STATIC, 0)

        def ABSTRACT(self):
            return self.getToken(JavaParser.ABSTRACT, 0)

        def FINAL(self):
            return self.getToken(JavaParser.FINAL, 0)

        def STRICTFP(self):
            return self.getToken(JavaParser.STRICTFP, 0)

        def getRuleIndex(self):
            return JavaParser.RULE_classOrInterfaceModifier

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterClassOrInterfaceModifier" ):
                listener.enterClassOrInterfaceModifier(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitClassOrInterfaceModifier" ):
                listener.exitClassOrInterfaceModifier(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitClassOrInterfaceModifier" ):
                return visitor.visitClassOrInterfaceModifier(self)
            else:
                return visitor.visitChildren(self)




    def classOrInterfaceModifier(self):

        localctx = JavaParser.ClassOrInterfaceModifierContext(self, self._ctx, self.state)
        self.enterRule(localctx, 10, self.RULE_classOrInterfaceModifier)
        self._la = 0 # Token type
        try:
            self.state = 287
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [JavaParser.AT]:
                self.enterOuterAlt(localctx, 1)
                self.state = 285
                self.annotation()
                pass
            elif token in [JavaParser.ABSTRACT, JavaParser.FINAL, JavaParser.PRIVATE, JavaParser.PROTECTED, JavaParser.PUBLIC, JavaParser.STATIC, JavaParser.STRICTFP]:
                self.enterOuterAlt(localctx, 2)
                self.state = 286
                _la = self._input.LA(1)
                if not((((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << JavaParser.ABSTRACT) | (1 << JavaParser.FINAL) | (1 << JavaParser.PRIVATE) | (1 << JavaParser.PROTECTED) | (1 << JavaParser.PUBLIC) | (1 << JavaParser.STATIC) | (1 << JavaParser.STRICTFP))) != 0)):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class VariableModifierContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def FINAL(self):
            return self.getToken(JavaParser.FINAL, 0)

        def annotation(self):
            return self.getTypedRuleContext(JavaParser.AnnotationContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_variableModifier

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterVariableModifier" ):
                listener.enterVariableModifier(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitVariableModifier" ):
                listener.exitVariableModifier(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitVariableModifier" ):
                return visitor.visitVariableModifier(self)
            else:
                return visitor.visitChildren(self)




    def variableModifier(self):

        localctx = JavaParser.VariableModifierContext(self, self._ctx, self.state)
        self.enterRule(localctx, 12, self.RULE_variableModifier)
        try:
            self.state = 291
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [JavaParser.FINAL]:
                self.enterOuterAlt(localctx, 1)
                self.state = 289
                self.match(JavaParser.FINAL)
                pass
            elif token in [JavaParser.AT]:
                self.enterOuterAlt(localctx, 2)
                self.state = 290
                self.annotation()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ClassDeclarationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def CLASS(self):
            return self.getToken(JavaParser.CLASS, 0)

        def Identifier(self):
            return self.getToken(JavaParser.Identifier, 0)

        def classBody(self):
            return self.getTypedRuleContext(JavaParser.ClassBodyContext,0)


        def typeParameters(self):
            return self.getTypedRuleContext(JavaParser.TypeParametersContext,0)


        def EXTENDS(self):
            return self.getToken(JavaParser.EXTENDS, 0)

        def jType(self):
            return self.getTypedRuleContext(JavaParser.JTypeContext,0)


        def IMPLEMENTS(self):
            return self.getToken(JavaParser.IMPLEMENTS, 0)

        def typeList(self):
            return self.getTypedRuleContext(JavaParser.TypeListContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_classDeclaration

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterClassDeclaration" ):
                listener.enterClassDeclaration(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitClassDeclaration" ):
                listener.exitClassDeclaration(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitClassDeclaration" ):
                return visitor.visitClassDeclaration(self)
            else:
                return visitor.visitChildren(self)




    def classDeclaration(self):

        localctx = JavaParser.ClassDeclarationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 14, self.RULE_classDeclaration)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 293
            self.match(JavaParser.CLASS)
            self.state = 294
            self.match(JavaParser.Identifier)
            self.state = 296
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==JavaParser.LT:
                self.state = 295
                self.typeParameters()


            self.state = 300
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==JavaParser.EXTENDS:
                self.state = 298
                self.match(JavaParser.EXTENDS)
                self.state = 299
                self.jType()


            self.state = 304
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==JavaParser.IMPLEMENTS:
                self.state = 302
                self.match(JavaParser.IMPLEMENTS)
                self.state = 303
                self.typeList()


            self.state = 306
            self.classBody()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class TypeParametersContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LT(self):
            return self.getToken(JavaParser.LT, 0)

        def typeParameter(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.TypeParameterContext)
            else:
                return self.getTypedRuleContext(JavaParser.TypeParameterContext,i)


        def GT(self):
            return self.getToken(JavaParser.GT, 0)

        def COMMA(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.COMMA)
            else:
                return self.getToken(JavaParser.COMMA, i)

        def getRuleIndex(self):
            return JavaParser.RULE_typeParameters

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTypeParameters" ):
                listener.enterTypeParameters(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTypeParameters" ):
                listener.exitTypeParameters(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitTypeParameters" ):
                return visitor.visitTypeParameters(self)
            else:
                return visitor.visitChildren(self)




    def typeParameters(self):

        localctx = JavaParser.TypeParametersContext(self, self._ctx, self.state)
        self.enterRule(localctx, 16, self.RULE_typeParameters)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 308
            self.match(JavaParser.LT)
            self.state = 309
            self.typeParameter()
            self.state = 314
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==JavaParser.COMMA:
                self.state = 310
                self.match(JavaParser.COMMA)
                self.state = 311
                self.typeParameter()
                self.state = 316
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 317
            self.match(JavaParser.GT)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class TypeParameterContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Identifier(self):
            return self.getToken(JavaParser.Identifier, 0)

        def annotation(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.AnnotationContext)
            else:
                return self.getTypedRuleContext(JavaParser.AnnotationContext,i)


        def EXTENDS(self):
            return self.getToken(JavaParser.EXTENDS, 0)

        def typeBound(self):
            return self.getTypedRuleContext(JavaParser.TypeBoundContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_typeParameter

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTypeParameter" ):
                listener.enterTypeParameter(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTypeParameter" ):
                listener.exitTypeParameter(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitTypeParameter" ):
                return visitor.visitTypeParameter(self)
            else:
                return visitor.visitChildren(self)




    def typeParameter(self):

        localctx = JavaParser.TypeParameterContext(self, self._ctx, self.state)
        self.enterRule(localctx, 18, self.RULE_typeParameter)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 322
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==JavaParser.AT:
                self.state = 319
                self.annotation()
                self.state = 324
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 325
            self.match(JavaParser.Identifier)
            self.state = 328
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==JavaParser.EXTENDS:
                self.state = 326
                self.match(JavaParser.EXTENDS)
                self.state = 327
                self.typeBound()


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class TypeBoundContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def jType(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.JTypeContext)
            else:
                return self.getTypedRuleContext(JavaParser.JTypeContext,i)


        def BITAND(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.BITAND)
            else:
                return self.getToken(JavaParser.BITAND, i)

        def getRuleIndex(self):
            return JavaParser.RULE_typeBound

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTypeBound" ):
                listener.enterTypeBound(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTypeBound" ):
                listener.exitTypeBound(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitTypeBound" ):
                return visitor.visitTypeBound(self)
            else:
                return visitor.visitChildren(self)




    def typeBound(self):

        localctx = JavaParser.TypeBoundContext(self, self._ctx, self.state)
        self.enterRule(localctx, 20, self.RULE_typeBound)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 330
            self.jType()
            self.state = 335
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==JavaParser.BITAND:
                self.state = 331
                self.match(JavaParser.BITAND)
                self.state = 332
                self.jType()
                self.state = 337
                self._errHandler.sync(self)
                _la = self._input.LA(1)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class EnumDeclarationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ENUM(self):
            return self.getToken(JavaParser.ENUM, 0)

        def Identifier(self):
            return self.getToken(JavaParser.Identifier, 0)

        def LBRACE(self):
            return self.getToken(JavaParser.LBRACE, 0)

        def RBRACE(self):
            return self.getToken(JavaParser.RBRACE, 0)

        def IMPLEMENTS(self):
            return self.getToken(JavaParser.IMPLEMENTS, 0)

        def typeList(self):
            return self.getTypedRuleContext(JavaParser.TypeListContext,0)


        def enumConstants(self):
            return self.getTypedRuleContext(JavaParser.EnumConstantsContext,0)


        def COMMA(self):
            return self.getToken(JavaParser.COMMA, 0)

        def enumBodyDeclarations(self):
            return self.getTypedRuleContext(JavaParser.EnumBodyDeclarationsContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_enumDeclaration

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterEnumDeclaration" ):
                listener.enterEnumDeclaration(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitEnumDeclaration" ):
                listener.exitEnumDeclaration(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitEnumDeclaration" ):
                return visitor.visitEnumDeclaration(self)
            else:
                return visitor.visitChildren(self)




    def enumDeclaration(self):

        localctx = JavaParser.EnumDeclarationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 22, self.RULE_enumDeclaration)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 338
            self.match(JavaParser.ENUM)
            self.state = 339
            self.match(JavaParser.Identifier)
            self.state = 342
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==JavaParser.IMPLEMENTS:
                self.state = 340
                self.match(JavaParser.IMPLEMENTS)
                self.state = 341
                self.typeList()


            self.state = 344
            self.match(JavaParser.LBRACE)
            self.state = 346
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==JavaParser.Identifier or _la==JavaParser.AT:
                self.state = 345
                self.enumConstants()


            self.state = 349
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==JavaParser.COMMA:
                self.state = 348
                self.match(JavaParser.COMMA)


            self.state = 352
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==JavaParser.SEMI:
                self.state = 351
                self.enumBodyDeclarations()


            self.state = 354
            self.match(JavaParser.RBRACE)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class EnumConstantsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def enumConstant(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.EnumConstantContext)
            else:
                return self.getTypedRuleContext(JavaParser.EnumConstantContext,i)


        def COMMA(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.COMMA)
            else:
                return self.getToken(JavaParser.COMMA, i)

        def getRuleIndex(self):
            return JavaParser.RULE_enumConstants

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterEnumConstants" ):
                listener.enterEnumConstants(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitEnumConstants" ):
                listener.exitEnumConstants(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitEnumConstants" ):
                return visitor.visitEnumConstants(self)
            else:
                return visitor.visitChildren(self)




    def enumConstants(self):

        localctx = JavaParser.EnumConstantsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 24, self.RULE_enumConstants)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 356
            self.enumConstant()
            self.state = 361
            self._errHandler.sync(self)
            _alt = self._interp.adaptivePredict(self._input,25,self._ctx)
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt==1:
                    self.state = 357
                    self.match(JavaParser.COMMA)
                    self.state = 358
                    self.enumConstant() 
                self.state = 363
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,25,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class EnumConstantContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Identifier(self):
            return self.getToken(JavaParser.Identifier, 0)

        def annotation(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.AnnotationContext)
            else:
                return self.getTypedRuleContext(JavaParser.AnnotationContext,i)


        def arguments(self):
            return self.getTypedRuleContext(JavaParser.ArgumentsContext,0)


        def classBody(self):
            return self.getTypedRuleContext(JavaParser.ClassBodyContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_enumConstant

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterEnumConstant" ):
                listener.enterEnumConstant(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitEnumConstant" ):
                listener.exitEnumConstant(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitEnumConstant" ):
                return visitor.visitEnumConstant(self)
            else:
                return visitor.visitChildren(self)




    def enumConstant(self):

        localctx = JavaParser.EnumConstantContext(self, self._ctx, self.state)
        self.enterRule(localctx, 26, self.RULE_enumConstant)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 367
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==JavaParser.AT:
                self.state = 364
                self.annotation()
                self.state = 369
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 370
            self.match(JavaParser.Identifier)
            self.state = 372
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==JavaParser.LPAREN:
                self.state = 371
                self.arguments()


            self.state = 375
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==JavaParser.LBRACE:
                self.state = 374
                self.classBody()


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class EnumBodyDeclarationsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def SEMI(self):
            return self.getToken(JavaParser.SEMI, 0)

        def classBodyDeclaration(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.ClassBodyDeclarationContext)
            else:
                return self.getTypedRuleContext(JavaParser.ClassBodyDeclarationContext,i)


        def getRuleIndex(self):
            return JavaParser.RULE_enumBodyDeclarations

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterEnumBodyDeclarations" ):
                listener.enterEnumBodyDeclarations(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitEnumBodyDeclarations" ):
                listener.exitEnumBodyDeclarations(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitEnumBodyDeclarations" ):
                return visitor.visitEnumBodyDeclarations(self)
            else:
                return visitor.visitChildren(self)




    def enumBodyDeclarations(self):

        localctx = JavaParser.EnumBodyDeclarationsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 28, self.RULE_enumBodyDeclarations)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 377
            self.match(JavaParser.SEMI)
            self.state = 381
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << JavaParser.ABSTRACT) | (1 << JavaParser.BOOLEAN) | (1 << JavaParser.BYTE) | (1 << JavaParser.CHAR) | (1 << JavaParser.CLASS) | (1 << JavaParser.DOUBLE) | (1 << JavaParser.ENUM) | (1 << JavaParser.FINAL) | (1 << JavaParser.FLOAT) | (1 << JavaParser.INT) | (1 << JavaParser.INTERFACE) | (1 << JavaParser.LONG) | (1 << JavaParser.NATIVE) | (1 << JavaParser.PRIVATE) | (1 << JavaParser.PROTECTED) | (1 << JavaParser.PUBLIC) | (1 << JavaParser.SHORT) | (1 << JavaParser.STATIC) | (1 << JavaParser.STRICTFP) | (1 << JavaParser.SYNCHRONIZED) | (1 << JavaParser.TRANSIENT) | (1 << JavaParser.VOID) | (1 << JavaParser.VOLATILE) | (1 << JavaParser.LBRACE))) != 0) or ((((_la - 65)) & ~0x3f) == 0 and ((1 << (_la - 65)) & ((1 << (JavaParser.SEMI - 65)) | (1 << (JavaParser.LT - 65)) | (1 << (JavaParser.Identifier - 65)) | (1 << (JavaParser.AT - 65)))) != 0):
                self.state = 378
                self.classBodyDeclaration()
                self.state = 383
                self._errHandler.sync(self)
                _la = self._input.LA(1)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class InterfaceDeclarationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def INTERFACE(self):
            return self.getToken(JavaParser.INTERFACE, 0)

        def Identifier(self):
            return self.getToken(JavaParser.Identifier, 0)

        def interfaceBody(self):
            return self.getTypedRuleContext(JavaParser.InterfaceBodyContext,0)


        def typeParameters(self):
            return self.getTypedRuleContext(JavaParser.TypeParametersContext,0)


        def EXTENDS(self):
            return self.getToken(JavaParser.EXTENDS, 0)

        def typeList(self):
            return self.getTypedRuleContext(JavaParser.TypeListContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_interfaceDeclaration

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterInterfaceDeclaration" ):
                listener.enterInterfaceDeclaration(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitInterfaceDeclaration" ):
                listener.exitInterfaceDeclaration(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitInterfaceDeclaration" ):
                return visitor.visitInterfaceDeclaration(self)
            else:
                return visitor.visitChildren(self)




    def interfaceDeclaration(self):

        localctx = JavaParser.InterfaceDeclarationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 30, self.RULE_interfaceDeclaration)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 384
            self.match(JavaParser.INTERFACE)
            self.state = 385
            self.match(JavaParser.Identifier)
            self.state = 387
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==JavaParser.LT:
                self.state = 386
                self.typeParameters()


            self.state = 391
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==JavaParser.EXTENDS:
                self.state = 389
                self.match(JavaParser.EXTENDS)
                self.state = 390
                self.typeList()


            self.state = 393
            self.interfaceBody()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class TypeListContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def jType(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.JTypeContext)
            else:
                return self.getTypedRuleContext(JavaParser.JTypeContext,i)


        def COMMA(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.COMMA)
            else:
                return self.getToken(JavaParser.COMMA, i)

        def getRuleIndex(self):
            return JavaParser.RULE_typeList

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTypeList" ):
                listener.enterTypeList(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTypeList" ):
                listener.exitTypeList(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitTypeList" ):
                return visitor.visitTypeList(self)
            else:
                return visitor.visitChildren(self)




    def typeList(self):

        localctx = JavaParser.TypeListContext(self, self._ctx, self.state)
        self.enterRule(localctx, 32, self.RULE_typeList)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 395
            self.jType()
            self.state = 400
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==JavaParser.COMMA:
                self.state = 396
                self.match(JavaParser.COMMA)
                self.state = 397
                self.jType()
                self.state = 402
                self._errHandler.sync(self)
                _la = self._input.LA(1)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ClassBodyContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LBRACE(self):
            return self.getToken(JavaParser.LBRACE, 0)

        def RBRACE(self):
            return self.getToken(JavaParser.RBRACE, 0)

        def classBodyDeclaration(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.ClassBodyDeclarationContext)
            else:
                return self.getTypedRuleContext(JavaParser.ClassBodyDeclarationContext,i)


        def getRuleIndex(self):
            return JavaParser.RULE_classBody

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterClassBody" ):
                listener.enterClassBody(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitClassBody" ):
                listener.exitClassBody(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitClassBody" ):
                return visitor.visitClassBody(self)
            else:
                return visitor.visitChildren(self)




    def classBody(self):

        localctx = JavaParser.ClassBodyContext(self, self._ctx, self.state)
        self.enterRule(localctx, 34, self.RULE_classBody)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 403
            self.match(JavaParser.LBRACE)
            self.state = 407
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << JavaParser.ABSTRACT) | (1 << JavaParser.BOOLEAN) | (1 << JavaParser.BYTE) | (1 << JavaParser.CHAR) | (1 << JavaParser.CLASS) | (1 << JavaParser.DOUBLE) | (1 << JavaParser.ENUM) | (1 << JavaParser.FINAL) | (1 << JavaParser.FLOAT) | (1 << JavaParser.INT) | (1 << JavaParser.INTERFACE) | (1 << JavaParser.LONG) | (1 << JavaParser.NATIVE) | (1 << JavaParser.PRIVATE) | (1 << JavaParser.PROTECTED) | (1 << JavaParser.PUBLIC) | (1 << JavaParser.SHORT) | (1 << JavaParser.STATIC) | (1 << JavaParser.STRICTFP) | (1 << JavaParser.SYNCHRONIZED) | (1 << JavaParser.TRANSIENT) | (1 << JavaParser.VOID) | (1 << JavaParser.VOLATILE) | (1 << JavaParser.LBRACE))) != 0) or ((((_la - 65)) & ~0x3f) == 0 and ((1 << (_la - 65)) & ((1 << (JavaParser.SEMI - 65)) | (1 << (JavaParser.LT - 65)) | (1 << (JavaParser.Identifier - 65)) | (1 << (JavaParser.AT - 65)))) != 0):
                self.state = 404
                self.classBodyDeclaration()
                self.state = 409
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 410
            self.match(JavaParser.RBRACE)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class InterfaceBodyContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LBRACE(self):
            return self.getToken(JavaParser.LBRACE, 0)

        def RBRACE(self):
            return self.getToken(JavaParser.RBRACE, 0)

        def interfaceBodyDeclaration(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.InterfaceBodyDeclarationContext)
            else:
                return self.getTypedRuleContext(JavaParser.InterfaceBodyDeclarationContext,i)


        def getRuleIndex(self):
            return JavaParser.RULE_interfaceBody

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterInterfaceBody" ):
                listener.enterInterfaceBody(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitInterfaceBody" ):
                listener.exitInterfaceBody(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitInterfaceBody" ):
                return visitor.visitInterfaceBody(self)
            else:
                return visitor.visitChildren(self)




    def interfaceBody(self):

        localctx = JavaParser.InterfaceBodyContext(self, self._ctx, self.state)
        self.enterRule(localctx, 36, self.RULE_interfaceBody)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 412
            self.match(JavaParser.LBRACE)
            self.state = 416
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << JavaParser.ABSTRACT) | (1 << JavaParser.BOOLEAN) | (1 << JavaParser.BYTE) | (1 << JavaParser.CHAR) | (1 << JavaParser.CLASS) | (1 << JavaParser.DEFAULT) | (1 << JavaParser.DOUBLE) | (1 << JavaParser.ENUM) | (1 << JavaParser.FINAL) | (1 << JavaParser.FLOAT) | (1 << JavaParser.INT) | (1 << JavaParser.INTERFACE) | (1 << JavaParser.LONG) | (1 << JavaParser.NATIVE) | (1 << JavaParser.PRIVATE) | (1 << JavaParser.PROTECTED) | (1 << JavaParser.PUBLIC) | (1 << JavaParser.SHORT) | (1 << JavaParser.STATIC) | (1 << JavaParser.STRICTFP) | (1 << JavaParser.SYNCHRONIZED) | (1 << JavaParser.TRANSIENT) | (1 << JavaParser.VOID) | (1 << JavaParser.VOLATILE))) != 0) or ((((_la - 65)) & ~0x3f) == 0 and ((1 << (_la - 65)) & ((1 << (JavaParser.SEMI - 65)) | (1 << (JavaParser.LT - 65)) | (1 << (JavaParser.Identifier - 65)) | (1 << (JavaParser.AT - 65)))) != 0):
                self.state = 413
                self.interfaceBodyDeclaration()
                self.state = 418
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 419
            self.match(JavaParser.RBRACE)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ClassBodyDeclarationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def SEMI(self):
            return self.getToken(JavaParser.SEMI, 0)

        def block(self):
            return self.getTypedRuleContext(JavaParser.BlockContext,0)


        def STATIC(self):
            return self.getToken(JavaParser.STATIC, 0)

        def memberDeclaration(self):
            return self.getTypedRuleContext(JavaParser.MemberDeclarationContext,0)


        def modifier(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.ModifierContext)
            else:
                return self.getTypedRuleContext(JavaParser.ModifierContext,i)


        def getRuleIndex(self):
            return JavaParser.RULE_classBodyDeclaration

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterClassBodyDeclaration" ):
                listener.enterClassBodyDeclaration(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitClassBodyDeclaration" ):
                listener.exitClassBodyDeclaration(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitClassBodyDeclaration" ):
                return visitor.visitClassBodyDeclaration(self)
            else:
                return visitor.visitChildren(self)




    def classBodyDeclaration(self):

        localctx = JavaParser.ClassBodyDeclarationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 38, self.RULE_classBodyDeclaration)
        self._la = 0 # Token type
        try:
            self.state = 433
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,37,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 421
                self.match(JavaParser.SEMI)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 423
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==JavaParser.STATIC:
                    self.state = 422
                    self.match(JavaParser.STATIC)


                self.state = 425
                self.block()
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 429
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,36,self._ctx)
                while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                    if _alt==1:
                        self.state = 426
                        self.modifier() 
                    self.state = 431
                    self._errHandler.sync(self)
                    _alt = self._interp.adaptivePredict(self._input,36,self._ctx)

                self.state = 432
                self.memberDeclaration()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class MemberDeclarationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def methodDeclaration(self):
            return self.getTypedRuleContext(JavaParser.MethodDeclarationContext,0)


        def genericMethodDeclaration(self):
            return self.getTypedRuleContext(JavaParser.GenericMethodDeclarationContext,0)


        def fieldDeclaration(self):
            return self.getTypedRuleContext(JavaParser.FieldDeclarationContext,0)


        def constructorDeclaration(self):
            return self.getTypedRuleContext(JavaParser.ConstructorDeclarationContext,0)


        def genericConstructorDeclaration(self):
            return self.getTypedRuleContext(JavaParser.GenericConstructorDeclarationContext,0)


        def interfaceDeclaration(self):
            return self.getTypedRuleContext(JavaParser.InterfaceDeclarationContext,0)


        def annotationTypeDeclaration(self):
            return self.getTypedRuleContext(JavaParser.AnnotationTypeDeclarationContext,0)


        def classDeclaration(self):
            return self.getTypedRuleContext(JavaParser.ClassDeclarationContext,0)


        def enumDeclaration(self):
            return self.getTypedRuleContext(JavaParser.EnumDeclarationContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_memberDeclaration

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterMemberDeclaration" ):
                listener.enterMemberDeclaration(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitMemberDeclaration" ):
                listener.exitMemberDeclaration(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitMemberDeclaration" ):
                return visitor.visitMemberDeclaration(self)
            else:
                return visitor.visitChildren(self)




    def memberDeclaration(self):

        localctx = JavaParser.MemberDeclarationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 40, self.RULE_memberDeclaration)
        try:
            self.state = 444
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,38,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 435
                self.methodDeclaration()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 436
                self.genericMethodDeclaration()
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 437
                self.fieldDeclaration()
                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 438
                self.constructorDeclaration()
                pass

            elif la_ == 5:
                self.enterOuterAlt(localctx, 5)
                self.state = 439
                self.genericConstructorDeclaration()
                pass

            elif la_ == 6:
                self.enterOuterAlt(localctx, 6)
                self.state = 440
                self.interfaceDeclaration()
                pass

            elif la_ == 7:
                self.enterOuterAlt(localctx, 7)
                self.state = 441
                self.annotationTypeDeclaration()
                pass

            elif la_ == 8:
                self.enterOuterAlt(localctx, 8)
                self.state = 442
                self.classDeclaration()
                pass

            elif la_ == 9:
                self.enterOuterAlt(localctx, 9)
                self.state = 443
                self.enumDeclaration()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class MethodDeclarationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Identifier(self):
            return self.getToken(JavaParser.Identifier, 0)

        def formalParameters(self):
            return self.getTypedRuleContext(JavaParser.FormalParametersContext,0)


        def jType(self):
            return self.getTypedRuleContext(JavaParser.JTypeContext,0)


        def VOID(self):
            return self.getToken(JavaParser.VOID, 0)

        def methodBody(self):
            return self.getTypedRuleContext(JavaParser.MethodBodyContext,0)


        def SEMI(self):
            return self.getToken(JavaParser.SEMI, 0)

        def LBRACK(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.LBRACK)
            else:
                return self.getToken(JavaParser.LBRACK, i)

        def RBRACK(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.RBRACK)
            else:
                return self.getToken(JavaParser.RBRACK, i)

        def THROWS(self):
            return self.getToken(JavaParser.THROWS, 0)

        def qualifiedNameList(self):
            return self.getTypedRuleContext(JavaParser.QualifiedNameListContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_methodDeclaration

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterMethodDeclaration" ):
                listener.enterMethodDeclaration(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitMethodDeclaration" ):
                listener.exitMethodDeclaration(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitMethodDeclaration" ):
                return visitor.visitMethodDeclaration(self)
            else:
                return visitor.visitChildren(self)




    def methodDeclaration(self):

        localctx = JavaParser.MethodDeclarationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 42, self.RULE_methodDeclaration)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 448
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [JavaParser.BOOLEAN, JavaParser.BYTE, JavaParser.CHAR, JavaParser.DOUBLE, JavaParser.FLOAT, JavaParser.INT, JavaParser.LONG, JavaParser.SHORT, JavaParser.Identifier]:
                self.state = 446
                self.jType()
                pass
            elif token in [JavaParser.VOID]:
                self.state = 447
                self.match(JavaParser.VOID)
                pass
            else:
                raise NoViableAltException(self)

            self.state = 450
            self.match(JavaParser.Identifier)
            self.state = 451
            self.formalParameters()
            self.state = 456
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==JavaParser.LBRACK:
                self.state = 452
                self.match(JavaParser.LBRACK)
                self.state = 453
                self.match(JavaParser.RBRACK)
                self.state = 458
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 461
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==JavaParser.THROWS:
                self.state = 459
                self.match(JavaParser.THROWS)
                self.state = 460
                self.qualifiedNameList()


            self.state = 465
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [JavaParser.LBRACE]:
                self.state = 463
                self.methodBody()
                pass
            elif token in [JavaParser.SEMI]:
                self.state = 464
                self.match(JavaParser.SEMI)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class GenericMethodDeclarationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def typeParameters(self):
            return self.getTypedRuleContext(JavaParser.TypeParametersContext,0)


        def methodDeclaration(self):
            return self.getTypedRuleContext(JavaParser.MethodDeclarationContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_genericMethodDeclaration

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterGenericMethodDeclaration" ):
                listener.enterGenericMethodDeclaration(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitGenericMethodDeclaration" ):
                listener.exitGenericMethodDeclaration(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitGenericMethodDeclaration" ):
                return visitor.visitGenericMethodDeclaration(self)
            else:
                return visitor.visitChildren(self)




    def genericMethodDeclaration(self):

        localctx = JavaParser.GenericMethodDeclarationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 44, self.RULE_genericMethodDeclaration)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 467
            self.typeParameters()
            self.state = 468
            self.methodDeclaration()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ConstructorDeclarationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Identifier(self):
            return self.getToken(JavaParser.Identifier, 0)

        def formalParameters(self):
            return self.getTypedRuleContext(JavaParser.FormalParametersContext,0)


        def constructorBody(self):
            return self.getTypedRuleContext(JavaParser.ConstructorBodyContext,0)


        def THROWS(self):
            return self.getToken(JavaParser.THROWS, 0)

        def qualifiedNameList(self):
            return self.getTypedRuleContext(JavaParser.QualifiedNameListContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_constructorDeclaration

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterConstructorDeclaration" ):
                listener.enterConstructorDeclaration(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitConstructorDeclaration" ):
                listener.exitConstructorDeclaration(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitConstructorDeclaration" ):
                return visitor.visitConstructorDeclaration(self)
            else:
                return visitor.visitChildren(self)




    def constructorDeclaration(self):

        localctx = JavaParser.ConstructorDeclarationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 46, self.RULE_constructorDeclaration)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 470
            self.match(JavaParser.Identifier)
            self.state = 471
            self.formalParameters()
            self.state = 474
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==JavaParser.THROWS:
                self.state = 472
                self.match(JavaParser.THROWS)
                self.state = 473
                self.qualifiedNameList()


            self.state = 476
            self.constructorBody()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class GenericConstructorDeclarationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def typeParameters(self):
            return self.getTypedRuleContext(JavaParser.TypeParametersContext,0)


        def constructorDeclaration(self):
            return self.getTypedRuleContext(JavaParser.ConstructorDeclarationContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_genericConstructorDeclaration

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterGenericConstructorDeclaration" ):
                listener.enterGenericConstructorDeclaration(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitGenericConstructorDeclaration" ):
                listener.exitGenericConstructorDeclaration(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitGenericConstructorDeclaration" ):
                return visitor.visitGenericConstructorDeclaration(self)
            else:
                return visitor.visitChildren(self)




    def genericConstructorDeclaration(self):

        localctx = JavaParser.GenericConstructorDeclarationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 48, self.RULE_genericConstructorDeclaration)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 478
            self.typeParameters()
            self.state = 479
            self.constructorDeclaration()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class FieldDeclarationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def jType(self):
            return self.getTypedRuleContext(JavaParser.JTypeContext,0)


        def variableDeclarators(self):
            return self.getTypedRuleContext(JavaParser.VariableDeclaratorsContext,0)


        def SEMI(self):
            return self.getToken(JavaParser.SEMI, 0)

        def getRuleIndex(self):
            return JavaParser.RULE_fieldDeclaration

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFieldDeclaration" ):
                listener.enterFieldDeclaration(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFieldDeclaration" ):
                listener.exitFieldDeclaration(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitFieldDeclaration" ):
                return visitor.visitFieldDeclaration(self)
            else:
                return visitor.visitChildren(self)




    def fieldDeclaration(self):

        localctx = JavaParser.FieldDeclarationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 50, self.RULE_fieldDeclaration)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 481
            self.jType()
            self.state = 482
            self.variableDeclarators()
            self.state = 483
            self.match(JavaParser.SEMI)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class InterfaceBodyDeclarationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def interfaceMemberDeclaration(self):
            return self.getTypedRuleContext(JavaParser.InterfaceMemberDeclarationContext,0)


        def modifier(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.ModifierContext)
            else:
                return self.getTypedRuleContext(JavaParser.ModifierContext,i)


        def SEMI(self):
            return self.getToken(JavaParser.SEMI, 0)

        def getRuleIndex(self):
            return JavaParser.RULE_interfaceBodyDeclaration

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterInterfaceBodyDeclaration" ):
                listener.enterInterfaceBodyDeclaration(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitInterfaceBodyDeclaration" ):
                listener.exitInterfaceBodyDeclaration(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitInterfaceBodyDeclaration" ):
                return visitor.visitInterfaceBodyDeclaration(self)
            else:
                return visitor.visitChildren(self)




    def interfaceBodyDeclaration(self):

        localctx = JavaParser.InterfaceBodyDeclarationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 52, self.RULE_interfaceBodyDeclaration)
        try:
            self.state = 493
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [JavaParser.ABSTRACT, JavaParser.BOOLEAN, JavaParser.BYTE, JavaParser.CHAR, JavaParser.CLASS, JavaParser.DEFAULT, JavaParser.DOUBLE, JavaParser.ENUM, JavaParser.FINAL, JavaParser.FLOAT, JavaParser.INT, JavaParser.INTERFACE, JavaParser.LONG, JavaParser.NATIVE, JavaParser.PRIVATE, JavaParser.PROTECTED, JavaParser.PUBLIC, JavaParser.SHORT, JavaParser.STATIC, JavaParser.STRICTFP, JavaParser.SYNCHRONIZED, JavaParser.TRANSIENT, JavaParser.VOID, JavaParser.VOLATILE, JavaParser.LT, JavaParser.Identifier, JavaParser.AT]:
                self.enterOuterAlt(localctx, 1)
                self.state = 488
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,44,self._ctx)
                while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                    if _alt==1:
                        self.state = 485
                        self.modifier() 
                    self.state = 490
                    self._errHandler.sync(self)
                    _alt = self._interp.adaptivePredict(self._input,44,self._ctx)

                self.state = 491
                self.interfaceMemberDeclaration()
                pass
            elif token in [JavaParser.SEMI]:
                self.enterOuterAlt(localctx, 2)
                self.state = 492
                self.match(JavaParser.SEMI)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class InterfaceMemberDeclarationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def constDeclaration(self):
            return self.getTypedRuleContext(JavaParser.ConstDeclarationContext,0)


        def interfaceMethodDeclaration(self):
            return self.getTypedRuleContext(JavaParser.InterfaceMethodDeclarationContext,0)


        def genericInterfaceMethodDeclaration(self):
            return self.getTypedRuleContext(JavaParser.GenericInterfaceMethodDeclarationContext,0)


        def interfaceDeclaration(self):
            return self.getTypedRuleContext(JavaParser.InterfaceDeclarationContext,0)


        def annotationTypeDeclaration(self):
            return self.getTypedRuleContext(JavaParser.AnnotationTypeDeclarationContext,0)


        def classDeclaration(self):
            return self.getTypedRuleContext(JavaParser.ClassDeclarationContext,0)


        def enumDeclaration(self):
            return self.getTypedRuleContext(JavaParser.EnumDeclarationContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_interfaceMemberDeclaration

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterInterfaceMemberDeclaration" ):
                listener.enterInterfaceMemberDeclaration(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitInterfaceMemberDeclaration" ):
                listener.exitInterfaceMemberDeclaration(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitInterfaceMemberDeclaration" ):
                return visitor.visitInterfaceMemberDeclaration(self)
            else:
                return visitor.visitChildren(self)




    def interfaceMemberDeclaration(self):

        localctx = JavaParser.InterfaceMemberDeclarationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 54, self.RULE_interfaceMemberDeclaration)
        try:
            self.state = 502
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,46,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 495
                self.constDeclaration()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 496
                self.interfaceMethodDeclaration()
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 497
                self.genericInterfaceMethodDeclaration()
                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 498
                self.interfaceDeclaration()
                pass

            elif la_ == 5:
                self.enterOuterAlt(localctx, 5)
                self.state = 499
                self.annotationTypeDeclaration()
                pass

            elif la_ == 6:
                self.enterOuterAlt(localctx, 6)
                self.state = 500
                self.classDeclaration()
                pass

            elif la_ == 7:
                self.enterOuterAlt(localctx, 7)
                self.state = 501
                self.enumDeclaration()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ConstDeclarationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def jType(self):
            return self.getTypedRuleContext(JavaParser.JTypeContext,0)


        def constantDeclarator(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.ConstantDeclaratorContext)
            else:
                return self.getTypedRuleContext(JavaParser.ConstantDeclaratorContext,i)


        def SEMI(self):
            return self.getToken(JavaParser.SEMI, 0)

        def COMMA(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.COMMA)
            else:
                return self.getToken(JavaParser.COMMA, i)

        def getRuleIndex(self):
            return JavaParser.RULE_constDeclaration

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterConstDeclaration" ):
                listener.enterConstDeclaration(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitConstDeclaration" ):
                listener.exitConstDeclaration(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitConstDeclaration" ):
                return visitor.visitConstDeclaration(self)
            else:
                return visitor.visitChildren(self)




    def constDeclaration(self):

        localctx = JavaParser.ConstDeclarationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 56, self.RULE_constDeclaration)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 504
            self.jType()
            self.state = 505
            self.constantDeclarator()
            self.state = 510
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==JavaParser.COMMA:
                self.state = 506
                self.match(JavaParser.COMMA)
                self.state = 507
                self.constantDeclarator()
                self.state = 512
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 513
            self.match(JavaParser.SEMI)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ConstantDeclaratorContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Identifier(self):
            return self.getToken(JavaParser.Identifier, 0)

        def ASSIGN(self):
            return self.getToken(JavaParser.ASSIGN, 0)

        def variableInitializer(self):
            return self.getTypedRuleContext(JavaParser.VariableInitializerContext,0)


        def LBRACK(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.LBRACK)
            else:
                return self.getToken(JavaParser.LBRACK, i)

        def RBRACK(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.RBRACK)
            else:
                return self.getToken(JavaParser.RBRACK, i)

        def getRuleIndex(self):
            return JavaParser.RULE_constantDeclarator

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterConstantDeclarator" ):
                listener.enterConstantDeclarator(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitConstantDeclarator" ):
                listener.exitConstantDeclarator(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitConstantDeclarator" ):
                return visitor.visitConstantDeclarator(self)
            else:
                return visitor.visitChildren(self)




    def constantDeclarator(self):

        localctx = JavaParser.ConstantDeclaratorContext(self, self._ctx, self.state)
        self.enterRule(localctx, 58, self.RULE_constantDeclarator)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 515
            self.match(JavaParser.Identifier)
            self.state = 520
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==JavaParser.LBRACK:
                self.state = 516
                self.match(JavaParser.LBRACK)
                self.state = 517
                self.match(JavaParser.RBRACK)
                self.state = 522
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 523
            self.match(JavaParser.ASSIGN)
            self.state = 524
            self.variableInitializer()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class InterfaceMethodDeclarationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Identifier(self):
            return self.getToken(JavaParser.Identifier, 0)

        def formalParameters(self):
            return self.getTypedRuleContext(JavaParser.FormalParametersContext,0)


        def SEMI(self):
            return self.getToken(JavaParser.SEMI, 0)

        def jType(self):
            return self.getTypedRuleContext(JavaParser.JTypeContext,0)


        def VOID(self):
            return self.getToken(JavaParser.VOID, 0)

        def LBRACK(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.LBRACK)
            else:
                return self.getToken(JavaParser.LBRACK, i)

        def RBRACK(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.RBRACK)
            else:
                return self.getToken(JavaParser.RBRACK, i)

        def THROWS(self):
            return self.getToken(JavaParser.THROWS, 0)

        def qualifiedNameList(self):
            return self.getTypedRuleContext(JavaParser.QualifiedNameListContext,0)


        def methodDeclaration(self):
            return self.getTypedRuleContext(JavaParser.MethodDeclarationContext,0)


        def DEFAULT(self):
            return self.getToken(JavaParser.DEFAULT, 0)

        def STATIC(self):
            return self.getToken(JavaParser.STATIC, 0)

        def typeParameters(self):
            return self.getTypedRuleContext(JavaParser.TypeParametersContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_interfaceMethodDeclaration

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterInterfaceMethodDeclaration" ):
                listener.enterInterfaceMethodDeclaration(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitInterfaceMethodDeclaration" ):
                listener.exitInterfaceMethodDeclaration(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitInterfaceMethodDeclaration" ):
                return visitor.visitInterfaceMethodDeclaration(self)
            else:
                return visitor.visitChildren(self)




    def interfaceMethodDeclaration(self):

        localctx = JavaParser.InterfaceMethodDeclarationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 60, self.RULE_interfaceMethodDeclaration)
        self._la = 0 # Token type
        try:
            self.state = 550
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [JavaParser.BOOLEAN, JavaParser.BYTE, JavaParser.CHAR, JavaParser.DOUBLE, JavaParser.FLOAT, JavaParser.INT, JavaParser.LONG, JavaParser.SHORT, JavaParser.VOID, JavaParser.Identifier]:
                self.enterOuterAlt(localctx, 1)
                self.state = 528
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [JavaParser.BOOLEAN, JavaParser.BYTE, JavaParser.CHAR, JavaParser.DOUBLE, JavaParser.FLOAT, JavaParser.INT, JavaParser.LONG, JavaParser.SHORT, JavaParser.Identifier]:
                    self.state = 526
                    self.jType()
                    pass
                elif token in [JavaParser.VOID]:
                    self.state = 527
                    self.match(JavaParser.VOID)
                    pass
                else:
                    raise NoViableAltException(self)

                self.state = 530
                self.match(JavaParser.Identifier)
                self.state = 531
                self.formalParameters()
                self.state = 536
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==JavaParser.LBRACK:
                    self.state = 532
                    self.match(JavaParser.LBRACK)
                    self.state = 533
                    self.match(JavaParser.RBRACK)
                    self.state = 538
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                self.state = 541
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==JavaParser.THROWS:
                    self.state = 539
                    self.match(JavaParser.THROWS)
                    self.state = 540
                    self.qualifiedNameList()


                self.state = 543
                self.match(JavaParser.SEMI)
                pass
            elif token in [JavaParser.DEFAULT, JavaParser.STATIC]:
                self.enterOuterAlt(localctx, 2)
                self.state = 545
                _la = self._input.LA(1)
                if not(_la==JavaParser.DEFAULT or _la==JavaParser.STATIC):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                self.state = 547
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==JavaParser.LT:
                    self.state = 546
                    self.typeParameters()


                self.state = 549
                self.methodDeclaration()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class GenericInterfaceMethodDeclarationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def typeParameters(self):
            return self.getTypedRuleContext(JavaParser.TypeParametersContext,0)


        def interfaceMethodDeclaration(self):
            return self.getTypedRuleContext(JavaParser.InterfaceMethodDeclarationContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_genericInterfaceMethodDeclaration

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterGenericInterfaceMethodDeclaration" ):
                listener.enterGenericInterfaceMethodDeclaration(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitGenericInterfaceMethodDeclaration" ):
                listener.exitGenericInterfaceMethodDeclaration(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitGenericInterfaceMethodDeclaration" ):
                return visitor.visitGenericInterfaceMethodDeclaration(self)
            else:
                return visitor.visitChildren(self)




    def genericInterfaceMethodDeclaration(self):

        localctx = JavaParser.GenericInterfaceMethodDeclarationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 62, self.RULE_genericInterfaceMethodDeclaration)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 552
            self.typeParameters()
            self.state = 553
            self.interfaceMethodDeclaration()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class VariableDeclaratorsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def variableDeclarator(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.VariableDeclaratorContext)
            else:
                return self.getTypedRuleContext(JavaParser.VariableDeclaratorContext,i)


        def COMMA(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.COMMA)
            else:
                return self.getToken(JavaParser.COMMA, i)

        def getRuleIndex(self):
            return JavaParser.RULE_variableDeclarators

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterVariableDeclarators" ):
                listener.enterVariableDeclarators(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitVariableDeclarators" ):
                listener.exitVariableDeclarators(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitVariableDeclarators" ):
                return visitor.visitVariableDeclarators(self)
            else:
                return visitor.visitChildren(self)




    def variableDeclarators(self):

        localctx = JavaParser.VariableDeclaratorsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 64, self.RULE_variableDeclarators)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 555
            self.variableDeclarator()
            self.state = 560
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==JavaParser.COMMA:
                self.state = 556
                self.match(JavaParser.COMMA)
                self.state = 557
                self.variableDeclarator()
                self.state = 562
                self._errHandler.sync(self)
                _la = self._input.LA(1)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class VariableDeclaratorContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def variableDeclaratorId(self):
            return self.getTypedRuleContext(JavaParser.VariableDeclaratorIdContext,0)


        def ASSIGN(self):
            return self.getToken(JavaParser.ASSIGN, 0)

        def variableInitializer(self):
            return self.getTypedRuleContext(JavaParser.VariableInitializerContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_variableDeclarator

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterVariableDeclarator" ):
                listener.enterVariableDeclarator(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitVariableDeclarator" ):
                listener.exitVariableDeclarator(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitVariableDeclarator" ):
                return visitor.visitVariableDeclarator(self)
            else:
                return visitor.visitChildren(self)




    def variableDeclarator(self):

        localctx = JavaParser.VariableDeclaratorContext(self, self._ctx, self.state)
        self.enterRule(localctx, 66, self.RULE_variableDeclarator)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 563
            self.variableDeclaratorId()
            self.state = 566
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==JavaParser.ASSIGN:
                self.state = 564
                self.match(JavaParser.ASSIGN)
                self.state = 565
                self.variableInitializer()


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class VariableDeclaratorIdContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Identifier(self):
            return self.getToken(JavaParser.Identifier, 0)

        def LBRACK(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.LBRACK)
            else:
                return self.getToken(JavaParser.LBRACK, i)

        def RBRACK(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.RBRACK)
            else:
                return self.getToken(JavaParser.RBRACK, i)

        def getRuleIndex(self):
            return JavaParser.RULE_variableDeclaratorId

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterVariableDeclaratorId" ):
                listener.enterVariableDeclaratorId(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitVariableDeclaratorId" ):
                listener.exitVariableDeclaratorId(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitVariableDeclaratorId" ):
                return visitor.visitVariableDeclaratorId(self)
            else:
                return visitor.visitChildren(self)




    def variableDeclaratorId(self):

        localctx = JavaParser.VariableDeclaratorIdContext(self, self._ctx, self.state)
        self.enterRule(localctx, 68, self.RULE_variableDeclaratorId)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 568
            self.match(JavaParser.Identifier)
            self.state = 573
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==JavaParser.LBRACK:
                self.state = 569
                self.match(JavaParser.LBRACK)
                self.state = 570
                self.match(JavaParser.RBRACK)
                self.state = 575
                self._errHandler.sync(self)
                _la = self._input.LA(1)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class VariableInitializerContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def arrayInitializer(self):
            return self.getTypedRuleContext(JavaParser.ArrayInitializerContext,0)


        def expression(self):
            return self.getTypedRuleContext(JavaParser.ExpressionContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_variableInitializer

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterVariableInitializer" ):
                listener.enterVariableInitializer(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitVariableInitializer" ):
                listener.exitVariableInitializer(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitVariableInitializer" ):
                return visitor.visitVariableInitializer(self)
            else:
                return visitor.visitChildren(self)




    def variableInitializer(self):

        localctx = JavaParser.VariableInitializerContext(self, self._ctx, self.state)
        self.enterRule(localctx, 70, self.RULE_variableInitializer)
        try:
            self.state = 578
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [JavaParser.LBRACE]:
                self.enterOuterAlt(localctx, 1)
                self.state = 576
                self.arrayInitializer()
                pass
            elif token in [JavaParser.BOOLEAN, JavaParser.BYTE, JavaParser.CHAR, JavaParser.DOUBLE, JavaParser.FLOAT, JavaParser.INT, JavaParser.LONG, JavaParser.NEW, JavaParser.SHORT, JavaParser.SUPER, JavaParser.THIS, JavaParser.VOID, JavaParser.IntegerLiteral, JavaParser.FloatingPointLiteral, JavaParser.BooleanLiteral, JavaParser.CharacterLiteral, JavaParser.StringLiteral, JavaParser.NullLiteral, JavaParser.LPAREN, JavaParser.LT, JavaParser.BANG, JavaParser.TILDE, JavaParser.INC, JavaParser.DEC, JavaParser.ADD, JavaParser.SUB, JavaParser.Identifier]:
                self.enterOuterAlt(localctx, 2)
                self.state = 577
                self.expression(0)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ArrayInitializerContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LBRACE(self):
            return self.getToken(JavaParser.LBRACE, 0)

        def RBRACE(self):
            return self.getToken(JavaParser.RBRACE, 0)

        def variableInitializer(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.VariableInitializerContext)
            else:
                return self.getTypedRuleContext(JavaParser.VariableInitializerContext,i)


        def COMMA(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.COMMA)
            else:
                return self.getToken(JavaParser.COMMA, i)

        def getRuleIndex(self):
            return JavaParser.RULE_arrayInitializer

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterArrayInitializer" ):
                listener.enterArrayInitializer(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitArrayInitializer" ):
                listener.exitArrayInitializer(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitArrayInitializer" ):
                return visitor.visitArrayInitializer(self)
            else:
                return visitor.visitChildren(self)




    def arrayInitializer(self):

        localctx = JavaParser.ArrayInitializerContext(self, self._ctx, self.state)
        self.enterRule(localctx, 72, self.RULE_arrayInitializer)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 580
            self.match(JavaParser.LBRACE)
            self.state = 592
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << JavaParser.BOOLEAN) | (1 << JavaParser.BYTE) | (1 << JavaParser.CHAR) | (1 << JavaParser.DOUBLE) | (1 << JavaParser.FLOAT) | (1 << JavaParser.INT) | (1 << JavaParser.LONG) | (1 << JavaParser.NEW) | (1 << JavaParser.SHORT) | (1 << JavaParser.SUPER) | (1 << JavaParser.THIS) | (1 << JavaParser.VOID) | (1 << JavaParser.IntegerLiteral) | (1 << JavaParser.FloatingPointLiteral) | (1 << JavaParser.BooleanLiteral) | (1 << JavaParser.CharacterLiteral) | (1 << JavaParser.StringLiteral) | (1 << JavaParser.NullLiteral) | (1 << JavaParser.LPAREN) | (1 << JavaParser.LBRACE))) != 0) or ((((_la - 70)) & ~0x3f) == 0 and ((1 << (_la - 70)) & ((1 << (JavaParser.LT - 70)) | (1 << (JavaParser.BANG - 70)) | (1 << (JavaParser.TILDE - 70)) | (1 << (JavaParser.INC - 70)) | (1 << (JavaParser.DEC - 70)) | (1 << (JavaParser.ADD - 70)) | (1 << (JavaParser.SUB - 70)) | (1 << (JavaParser.Identifier - 70)))) != 0):
                self.state = 581
                self.variableInitializer()
                self.state = 586
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,58,self._ctx)
                while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                    if _alt==1:
                        self.state = 582
                        self.match(JavaParser.COMMA)
                        self.state = 583
                        self.variableInitializer() 
                    self.state = 588
                    self._errHandler.sync(self)
                    _alt = self._interp.adaptivePredict(self._input,58,self._ctx)

                self.state = 590
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==JavaParser.COMMA:
                    self.state = 589
                    self.match(JavaParser.COMMA)




            self.state = 594
            self.match(JavaParser.RBRACE)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class EnumConstantNameContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Identifier(self):
            return self.getToken(JavaParser.Identifier, 0)

        def getRuleIndex(self):
            return JavaParser.RULE_enumConstantName

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterEnumConstantName" ):
                listener.enterEnumConstantName(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitEnumConstantName" ):
                listener.exitEnumConstantName(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitEnumConstantName" ):
                return visitor.visitEnumConstantName(self)
            else:
                return visitor.visitChildren(self)




    def enumConstantName(self):

        localctx = JavaParser.EnumConstantNameContext(self, self._ctx, self.state)
        self.enterRule(localctx, 74, self.RULE_enumConstantName)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 596
            self.match(JavaParser.Identifier)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class JTypeContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def classOrInterfaceType(self):
            return self.getTypedRuleContext(JavaParser.ClassOrInterfaceTypeContext,0)


        def LBRACK(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.LBRACK)
            else:
                return self.getToken(JavaParser.LBRACK, i)

        def RBRACK(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.RBRACK)
            else:
                return self.getToken(JavaParser.RBRACK, i)

        def primitiveType(self):
            return self.getTypedRuleContext(JavaParser.PrimitiveTypeContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_jType

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterJType" ):
                listener.enterJType(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitJType" ):
                listener.exitJType(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitJType" ):
                return visitor.visitJType(self)
            else:
                return visitor.visitChildren(self)




    def jType(self):

        localctx = JavaParser.JTypeContext(self, self._ctx, self.state)
        self.enterRule(localctx, 76, self.RULE_jType)
        try:
            self.state = 614
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [JavaParser.Identifier]:
                self.enterOuterAlt(localctx, 1)
                self.state = 598
                self.classOrInterfaceType()
                self.state = 603
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,61,self._ctx)
                while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                    if _alt==1:
                        self.state = 599
                        self.match(JavaParser.LBRACK)
                        self.state = 600
                        self.match(JavaParser.RBRACK) 
                    self.state = 605
                    self._errHandler.sync(self)
                    _alt = self._interp.adaptivePredict(self._input,61,self._ctx)

                pass
            elif token in [JavaParser.BOOLEAN, JavaParser.BYTE, JavaParser.CHAR, JavaParser.DOUBLE, JavaParser.FLOAT, JavaParser.INT, JavaParser.LONG, JavaParser.SHORT]:
                self.enterOuterAlt(localctx, 2)
                self.state = 606
                self.primitiveType()
                self.state = 611
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,62,self._ctx)
                while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                    if _alt==1:
                        self.state = 607
                        self.match(JavaParser.LBRACK)
                        self.state = 608
                        self.match(JavaParser.RBRACK) 
                    self.state = 613
                    self._errHandler.sync(self)
                    _alt = self._interp.adaptivePredict(self._input,62,self._ctx)

                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ClassOrInterfaceTypeContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Identifier(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.Identifier)
            else:
                return self.getToken(JavaParser.Identifier, i)

        def typeArguments(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.TypeArgumentsContext)
            else:
                return self.getTypedRuleContext(JavaParser.TypeArgumentsContext,i)


        def DOT(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.DOT)
            else:
                return self.getToken(JavaParser.DOT, i)

        def getRuleIndex(self):
            return JavaParser.RULE_classOrInterfaceType

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterClassOrInterfaceType" ):
                listener.enterClassOrInterfaceType(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitClassOrInterfaceType" ):
                listener.exitClassOrInterfaceType(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitClassOrInterfaceType" ):
                return visitor.visitClassOrInterfaceType(self)
            else:
                return visitor.visitChildren(self)




    def classOrInterfaceType(self):

        localctx = JavaParser.ClassOrInterfaceTypeContext(self, self._ctx, self.state)
        self.enterRule(localctx, 78, self.RULE_classOrInterfaceType)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 616
            self.match(JavaParser.Identifier)
            self.state = 618
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,64,self._ctx)
            if la_ == 1:
                self.state = 617
                self.typeArguments()


            self.state = 627
            self._errHandler.sync(self)
            _alt = self._interp.adaptivePredict(self._input,66,self._ctx)
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt==1:
                    self.state = 620
                    self.match(JavaParser.DOT)
                    self.state = 621
                    self.match(JavaParser.Identifier)
                    self.state = 623
                    self._errHandler.sync(self)
                    la_ = self._interp.adaptivePredict(self._input,65,self._ctx)
                    if la_ == 1:
                        self.state = 622
                        self.typeArguments()

             
                self.state = 629
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,66,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class PrimitiveTypeContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def BOOLEAN(self):
            return self.getToken(JavaParser.BOOLEAN, 0)

        def CHAR(self):
            return self.getToken(JavaParser.CHAR, 0)

        def BYTE(self):
            return self.getToken(JavaParser.BYTE, 0)

        def SHORT(self):
            return self.getToken(JavaParser.SHORT, 0)

        def INT(self):
            return self.getToken(JavaParser.INT, 0)

        def LONG(self):
            return self.getToken(JavaParser.LONG, 0)

        def FLOAT(self):
            return self.getToken(JavaParser.FLOAT, 0)

        def DOUBLE(self):
            return self.getToken(JavaParser.DOUBLE, 0)

        def getRuleIndex(self):
            return JavaParser.RULE_primitiveType

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPrimitiveType" ):
                listener.enterPrimitiveType(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPrimitiveType" ):
                listener.exitPrimitiveType(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitPrimitiveType" ):
                return visitor.visitPrimitiveType(self)
            else:
                return visitor.visitChildren(self)




    def primitiveType(self):

        localctx = JavaParser.PrimitiveTypeContext(self, self._ctx, self.state)
        self.enterRule(localctx, 80, self.RULE_primitiveType)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 630
            _la = self._input.LA(1)
            if not((((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << JavaParser.BOOLEAN) | (1 << JavaParser.BYTE) | (1 << JavaParser.CHAR) | (1 << JavaParser.DOUBLE) | (1 << JavaParser.FLOAT) | (1 << JavaParser.INT) | (1 << JavaParser.LONG) | (1 << JavaParser.SHORT))) != 0)):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class TypeArgumentsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LT(self):
            return self.getToken(JavaParser.LT, 0)

        def typeArgumentAnnotation(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.TypeArgumentAnnotationContext)
            else:
                return self.getTypedRuleContext(JavaParser.TypeArgumentAnnotationContext,i)


        def GT(self):
            return self.getToken(JavaParser.GT, 0)

        def COMMA(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.COMMA)
            else:
                return self.getToken(JavaParser.COMMA, i)

        def getRuleIndex(self):
            return JavaParser.RULE_typeArguments

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTypeArguments" ):
                listener.enterTypeArguments(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTypeArguments" ):
                listener.exitTypeArguments(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitTypeArguments" ):
                return visitor.visitTypeArguments(self)
            else:
                return visitor.visitChildren(self)




    def typeArguments(self):

        localctx = JavaParser.TypeArgumentsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 82, self.RULE_typeArguments)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 632
            self.match(JavaParser.LT)
            self.state = 633
            self.typeArgumentAnnotation()
            self.state = 638
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==JavaParser.COMMA:
                self.state = 634
                self.match(JavaParser.COMMA)
                self.state = 635
                self.typeArgumentAnnotation()
                self.state = 640
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 641
            self.match(JavaParser.GT)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class TypeArgumentAnnotationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def typeArgument(self):
            return self.getTypedRuleContext(JavaParser.TypeArgumentContext,0)


        def annotation(self):
            return self.getTypedRuleContext(JavaParser.AnnotationContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_typeArgumentAnnotation

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTypeArgumentAnnotation" ):
                listener.enterTypeArgumentAnnotation(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTypeArgumentAnnotation" ):
                listener.exitTypeArgumentAnnotation(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitTypeArgumentAnnotation" ):
                return visitor.visitTypeArgumentAnnotation(self)
            else:
                return visitor.visitChildren(self)




    def typeArgumentAnnotation(self):

        localctx = JavaParser.TypeArgumentAnnotationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 84, self.RULE_typeArgumentAnnotation)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 644
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==JavaParser.AT:
                self.state = 643
                self.annotation()


            self.state = 646
            self.typeArgument()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class TypeArgumentContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def jType(self):
            return self.getTypedRuleContext(JavaParser.JTypeContext,0)


        def QUESTION(self):
            return self.getToken(JavaParser.QUESTION, 0)

        def EXTENDS(self):
            return self.getToken(JavaParser.EXTENDS, 0)

        def SUPER(self):
            return self.getToken(JavaParser.SUPER, 0)

        def getRuleIndex(self):
            return JavaParser.RULE_typeArgument

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTypeArgument" ):
                listener.enterTypeArgument(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTypeArgument" ):
                listener.exitTypeArgument(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitTypeArgument" ):
                return visitor.visitTypeArgument(self)
            else:
                return visitor.visitChildren(self)




    def typeArgument(self):

        localctx = JavaParser.TypeArgumentContext(self, self._ctx, self.state)
        self.enterRule(localctx, 86, self.RULE_typeArgument)
        self._la = 0 # Token type
        try:
            self.state = 654
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [JavaParser.BOOLEAN, JavaParser.BYTE, JavaParser.CHAR, JavaParser.DOUBLE, JavaParser.FLOAT, JavaParser.INT, JavaParser.LONG, JavaParser.SHORT, JavaParser.Identifier]:
                self.enterOuterAlt(localctx, 1)
                self.state = 648
                self.jType()
                pass
            elif token in [JavaParser.QUESTION]:
                self.enterOuterAlt(localctx, 2)
                self.state = 649
                self.match(JavaParser.QUESTION)
                self.state = 652
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==JavaParser.EXTENDS or _la==JavaParser.SUPER:
                    self.state = 650
                    _la = self._input.LA(1)
                    if not(_la==JavaParser.EXTENDS or _la==JavaParser.SUPER):
                        self._errHandler.recoverInline(self)
                    else:
                        self._errHandler.reportMatch(self)
                        self.consume()
                    self.state = 651
                    self.jType()


                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class QualifiedNameListContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def qualifiedName(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.QualifiedNameContext)
            else:
                return self.getTypedRuleContext(JavaParser.QualifiedNameContext,i)


        def COMMA(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.COMMA)
            else:
                return self.getToken(JavaParser.COMMA, i)

        def getRuleIndex(self):
            return JavaParser.RULE_qualifiedNameList

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterQualifiedNameList" ):
                listener.enterQualifiedNameList(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitQualifiedNameList" ):
                listener.exitQualifiedNameList(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitQualifiedNameList" ):
                return visitor.visitQualifiedNameList(self)
            else:
                return visitor.visitChildren(self)




    def qualifiedNameList(self):

        localctx = JavaParser.QualifiedNameListContext(self, self._ctx, self.state)
        self.enterRule(localctx, 88, self.RULE_qualifiedNameList)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 656
            self.qualifiedName()
            self.state = 661
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==JavaParser.COMMA:
                self.state = 657
                self.match(JavaParser.COMMA)
                self.state = 658
                self.qualifiedName()
                self.state = 663
                self._errHandler.sync(self)
                _la = self._input.LA(1)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class FormalParametersContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LPAREN(self):
            return self.getToken(JavaParser.LPAREN, 0)

        def RPAREN(self):
            return self.getToken(JavaParser.RPAREN, 0)

        def formalParameterList(self):
            return self.getTypedRuleContext(JavaParser.FormalParameterListContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_formalParameters

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFormalParameters" ):
                listener.enterFormalParameters(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFormalParameters" ):
                listener.exitFormalParameters(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitFormalParameters" ):
                return visitor.visitFormalParameters(self)
            else:
                return visitor.visitChildren(self)




    def formalParameters(self):

        localctx = JavaParser.FormalParametersContext(self, self._ctx, self.state)
        self.enterRule(localctx, 90, self.RULE_formalParameters)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 664
            self.match(JavaParser.LPAREN)
            self.state = 666
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << JavaParser.BOOLEAN) | (1 << JavaParser.BYTE) | (1 << JavaParser.CHAR) | (1 << JavaParser.DOUBLE) | (1 << JavaParser.FINAL) | (1 << JavaParser.FLOAT) | (1 << JavaParser.INT) | (1 << JavaParser.LONG) | (1 << JavaParser.SHORT))) != 0) or _la==JavaParser.Identifier or _la==JavaParser.AT:
                self.state = 665
                self.formalParameterList()


            self.state = 668
            self.match(JavaParser.RPAREN)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class FormalParameterListContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def formalParameter(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.FormalParameterContext)
            else:
                return self.getTypedRuleContext(JavaParser.FormalParameterContext,i)


        def COMMA(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.COMMA)
            else:
                return self.getToken(JavaParser.COMMA, i)

        def lastFormalParameter(self):
            return self.getTypedRuleContext(JavaParser.LastFormalParameterContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_formalParameterList

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFormalParameterList" ):
                listener.enterFormalParameterList(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFormalParameterList" ):
                listener.exitFormalParameterList(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitFormalParameterList" ):
                return visitor.visitFormalParameterList(self)
            else:
                return visitor.visitChildren(self)




    def formalParameterList(self):

        localctx = JavaParser.FormalParameterListContext(self, self._ctx, self.state)
        self.enterRule(localctx, 92, self.RULE_formalParameterList)
        self._la = 0 # Token type
        try:
            self.state = 683
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,75,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 670
                self.formalParameter()
                self.state = 675
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,73,self._ctx)
                while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                    if _alt==1:
                        self.state = 671
                        self.match(JavaParser.COMMA)
                        self.state = 672
                        self.formalParameter() 
                    self.state = 677
                    self._errHandler.sync(self)
                    _alt = self._interp.adaptivePredict(self._input,73,self._ctx)

                self.state = 680
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==JavaParser.COMMA:
                    self.state = 678
                    self.match(JavaParser.COMMA)
                    self.state = 679
                    self.lastFormalParameter()


                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 682
                self.lastFormalParameter()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class FormalParameterContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def jType(self):
            return self.getTypedRuleContext(JavaParser.JTypeContext,0)


        def variableDeclaratorId(self):
            return self.getTypedRuleContext(JavaParser.VariableDeclaratorIdContext,0)


        def variableModifier(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.VariableModifierContext)
            else:
                return self.getTypedRuleContext(JavaParser.VariableModifierContext,i)


        def getRuleIndex(self):
            return JavaParser.RULE_formalParameter

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFormalParameter" ):
                listener.enterFormalParameter(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFormalParameter" ):
                listener.exitFormalParameter(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitFormalParameter" ):
                return visitor.visitFormalParameter(self)
            else:
                return visitor.visitChildren(self)




    def formalParameter(self):

        localctx = JavaParser.FormalParameterContext(self, self._ctx, self.state)
        self.enterRule(localctx, 94, self.RULE_formalParameter)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 688
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==JavaParser.FINAL or _la==JavaParser.AT:
                self.state = 685
                self.variableModifier()
                self.state = 690
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 691
            self.jType()
            self.state = 692
            self.variableDeclaratorId()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class LastFormalParameterContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def jType(self):
            return self.getTypedRuleContext(JavaParser.JTypeContext,0)


        def ELLIPSIS(self):
            return self.getToken(JavaParser.ELLIPSIS, 0)

        def variableDeclaratorId(self):
            return self.getTypedRuleContext(JavaParser.VariableDeclaratorIdContext,0)


        def variableModifier(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.VariableModifierContext)
            else:
                return self.getTypedRuleContext(JavaParser.VariableModifierContext,i)


        def getRuleIndex(self):
            return JavaParser.RULE_lastFormalParameter

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterLastFormalParameter" ):
                listener.enterLastFormalParameter(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitLastFormalParameter" ):
                listener.exitLastFormalParameter(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitLastFormalParameter" ):
                return visitor.visitLastFormalParameter(self)
            else:
                return visitor.visitChildren(self)




    def lastFormalParameter(self):

        localctx = JavaParser.LastFormalParameterContext(self, self._ctx, self.state)
        self.enterRule(localctx, 96, self.RULE_lastFormalParameter)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 697
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==JavaParser.FINAL or _la==JavaParser.AT:
                self.state = 694
                self.variableModifier()
                self.state = 699
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 700
            self.jType()
            self.state = 701
            self.match(JavaParser.ELLIPSIS)
            self.state = 702
            self.variableDeclaratorId()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class MethodBodyContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def block(self):
            return self.getTypedRuleContext(JavaParser.BlockContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_methodBody

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterMethodBody" ):
                listener.enterMethodBody(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitMethodBody" ):
                listener.exitMethodBody(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitMethodBody" ):
                return visitor.visitMethodBody(self)
            else:
                return visitor.visitChildren(self)




    def methodBody(self):

        localctx = JavaParser.MethodBodyContext(self, self._ctx, self.state)
        self.enterRule(localctx, 98, self.RULE_methodBody)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 704
            self.block()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ConstructorBodyContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def block(self):
            return self.getTypedRuleContext(JavaParser.BlockContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_constructorBody

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterConstructorBody" ):
                listener.enterConstructorBody(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitConstructorBody" ):
                listener.exitConstructorBody(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitConstructorBody" ):
                return visitor.visitConstructorBody(self)
            else:
                return visitor.visitChildren(self)




    def constructorBody(self):

        localctx = JavaParser.ConstructorBodyContext(self, self._ctx, self.state)
        self.enterRule(localctx, 100, self.RULE_constructorBody)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 706
            self.block()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class QualifiedNameContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Identifier(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.Identifier)
            else:
                return self.getToken(JavaParser.Identifier, i)

        def DOT(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.DOT)
            else:
                return self.getToken(JavaParser.DOT, i)

        def getRuleIndex(self):
            return JavaParser.RULE_qualifiedName

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterQualifiedName" ):
                listener.enterQualifiedName(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitQualifiedName" ):
                listener.exitQualifiedName(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitQualifiedName" ):
                return visitor.visitQualifiedName(self)
            else:
                return visitor.visitChildren(self)




    def qualifiedName(self):

        localctx = JavaParser.QualifiedNameContext(self, self._ctx, self.state)
        self.enterRule(localctx, 102, self.RULE_qualifiedName)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 708
            self.match(JavaParser.Identifier)
            self.state = 713
            self._errHandler.sync(self)
            _alt = self._interp.adaptivePredict(self._input,78,self._ctx)
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt==1:
                    self.state = 709
                    self.match(JavaParser.DOT)
                    self.state = 710
                    self.match(JavaParser.Identifier) 
                self.state = 715
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,78,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class LiteralContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def IntegerLiteral(self):
            return self.getToken(JavaParser.IntegerLiteral, 0)

        def FloatingPointLiteral(self):
            return self.getToken(JavaParser.FloatingPointLiteral, 0)

        def CharacterLiteral(self):
            return self.getToken(JavaParser.CharacterLiteral, 0)

        def StringLiteral(self):
            return self.getToken(JavaParser.StringLiteral, 0)

        def BooleanLiteral(self):
            return self.getToken(JavaParser.BooleanLiteral, 0)

        def NullLiteral(self):
            return self.getToken(JavaParser.NullLiteral, 0)

        def getRuleIndex(self):
            return JavaParser.RULE_literal

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterLiteral" ):
                listener.enterLiteral(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitLiteral" ):
                listener.exitLiteral(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitLiteral" ):
                return visitor.visitLiteral(self)
            else:
                return visitor.visitChildren(self)




    def literal(self):

        localctx = JavaParser.LiteralContext(self, self._ctx, self.state)
        self.enterRule(localctx, 104, self.RULE_literal)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 716
            _la = self._input.LA(1)
            if not((((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << JavaParser.IntegerLiteral) | (1 << JavaParser.FloatingPointLiteral) | (1 << JavaParser.BooleanLiteral) | (1 << JavaParser.CharacterLiteral) | (1 << JavaParser.StringLiteral) | (1 << JavaParser.NullLiteral))) != 0)):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class AnnotationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def AT(self):
            return self.getToken(JavaParser.AT, 0)

        def annotationName(self):
            return self.getTypedRuleContext(JavaParser.AnnotationNameContext,0)


        def LPAREN(self):
            return self.getToken(JavaParser.LPAREN, 0)

        def RPAREN(self):
            return self.getToken(JavaParser.RPAREN, 0)

        def elementValuePairs(self):
            return self.getTypedRuleContext(JavaParser.ElementValuePairsContext,0)


        def elementValue(self):
            return self.getTypedRuleContext(JavaParser.ElementValueContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_annotation

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAnnotation" ):
                listener.enterAnnotation(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAnnotation" ):
                listener.exitAnnotation(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitAnnotation" ):
                return visitor.visitAnnotation(self)
            else:
                return visitor.visitChildren(self)




    def annotation(self):

        localctx = JavaParser.AnnotationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 106, self.RULE_annotation)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 718
            self.match(JavaParser.AT)
            self.state = 719
            self.annotationName()
            self.state = 726
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==JavaParser.LPAREN:
                self.state = 720
                self.match(JavaParser.LPAREN)
                self.state = 723
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,79,self._ctx)
                if la_ == 1:
                    self.state = 721
                    self.elementValuePairs()

                elif la_ == 2:
                    self.state = 722
                    self.elementValue()


                self.state = 725
                self.match(JavaParser.RPAREN)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class AnnotationNameContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def qualifiedName(self):
            return self.getTypedRuleContext(JavaParser.QualifiedNameContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_annotationName

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAnnotationName" ):
                listener.enterAnnotationName(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAnnotationName" ):
                listener.exitAnnotationName(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitAnnotationName" ):
                return visitor.visitAnnotationName(self)
            else:
                return visitor.visitChildren(self)




    def annotationName(self):

        localctx = JavaParser.AnnotationNameContext(self, self._ctx, self.state)
        self.enterRule(localctx, 108, self.RULE_annotationName)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 728
            self.qualifiedName()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ElementValuePairsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def elementValuePair(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.ElementValuePairContext)
            else:
                return self.getTypedRuleContext(JavaParser.ElementValuePairContext,i)


        def COMMA(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.COMMA)
            else:
                return self.getToken(JavaParser.COMMA, i)

        def getRuleIndex(self):
            return JavaParser.RULE_elementValuePairs

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterElementValuePairs" ):
                listener.enterElementValuePairs(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitElementValuePairs" ):
                listener.exitElementValuePairs(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitElementValuePairs" ):
                return visitor.visitElementValuePairs(self)
            else:
                return visitor.visitChildren(self)




    def elementValuePairs(self):

        localctx = JavaParser.ElementValuePairsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 110, self.RULE_elementValuePairs)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 730
            self.elementValuePair()
            self.state = 735
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==JavaParser.COMMA:
                self.state = 731
                self.match(JavaParser.COMMA)
                self.state = 732
                self.elementValuePair()
                self.state = 737
                self._errHandler.sync(self)
                _la = self._input.LA(1)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ElementValuePairContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Identifier(self):
            return self.getToken(JavaParser.Identifier, 0)

        def ASSIGN(self):
            return self.getToken(JavaParser.ASSIGN, 0)

        def elementValue(self):
            return self.getTypedRuleContext(JavaParser.ElementValueContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_elementValuePair

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterElementValuePair" ):
                listener.enterElementValuePair(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitElementValuePair" ):
                listener.exitElementValuePair(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitElementValuePair" ):
                return visitor.visitElementValuePair(self)
            else:
                return visitor.visitChildren(self)




    def elementValuePair(self):

        localctx = JavaParser.ElementValuePairContext(self, self._ctx, self.state)
        self.enterRule(localctx, 112, self.RULE_elementValuePair)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 738
            self.match(JavaParser.Identifier)
            self.state = 739
            self.match(JavaParser.ASSIGN)
            self.state = 740
            self.elementValue()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ElementValueContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def expression(self):
            return self.getTypedRuleContext(JavaParser.ExpressionContext,0)


        def annotation(self):
            return self.getTypedRuleContext(JavaParser.AnnotationContext,0)


        def elementValueArrayInitializer(self):
            return self.getTypedRuleContext(JavaParser.ElementValueArrayInitializerContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_elementValue

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterElementValue" ):
                listener.enterElementValue(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitElementValue" ):
                listener.exitElementValue(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitElementValue" ):
                return visitor.visitElementValue(self)
            else:
                return visitor.visitChildren(self)




    def elementValue(self):

        localctx = JavaParser.ElementValueContext(self, self._ctx, self.state)
        self.enterRule(localctx, 114, self.RULE_elementValue)
        try:
            self.state = 745
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [JavaParser.BOOLEAN, JavaParser.BYTE, JavaParser.CHAR, JavaParser.DOUBLE, JavaParser.FLOAT, JavaParser.INT, JavaParser.LONG, JavaParser.NEW, JavaParser.SHORT, JavaParser.SUPER, JavaParser.THIS, JavaParser.VOID, JavaParser.IntegerLiteral, JavaParser.FloatingPointLiteral, JavaParser.BooleanLiteral, JavaParser.CharacterLiteral, JavaParser.StringLiteral, JavaParser.NullLiteral, JavaParser.LPAREN, JavaParser.LT, JavaParser.BANG, JavaParser.TILDE, JavaParser.INC, JavaParser.DEC, JavaParser.ADD, JavaParser.SUB, JavaParser.Identifier]:
                self.enterOuterAlt(localctx, 1)
                self.state = 742
                self.expression(0)
                pass
            elif token in [JavaParser.AT]:
                self.enterOuterAlt(localctx, 2)
                self.state = 743
                self.annotation()
                pass
            elif token in [JavaParser.LBRACE]:
                self.enterOuterAlt(localctx, 3)
                self.state = 744
                self.elementValueArrayInitializer()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ElementValueArrayInitializerContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LBRACE(self):
            return self.getToken(JavaParser.LBRACE, 0)

        def RBRACE(self):
            return self.getToken(JavaParser.RBRACE, 0)

        def elementValue(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.ElementValueContext)
            else:
                return self.getTypedRuleContext(JavaParser.ElementValueContext,i)


        def COMMA(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.COMMA)
            else:
                return self.getToken(JavaParser.COMMA, i)

        def getRuleIndex(self):
            return JavaParser.RULE_elementValueArrayInitializer

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterElementValueArrayInitializer" ):
                listener.enterElementValueArrayInitializer(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitElementValueArrayInitializer" ):
                listener.exitElementValueArrayInitializer(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitElementValueArrayInitializer" ):
                return visitor.visitElementValueArrayInitializer(self)
            else:
                return visitor.visitChildren(self)




    def elementValueArrayInitializer(self):

        localctx = JavaParser.ElementValueArrayInitializerContext(self, self._ctx, self.state)
        self.enterRule(localctx, 116, self.RULE_elementValueArrayInitializer)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 747
            self.match(JavaParser.LBRACE)
            self.state = 756
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << JavaParser.BOOLEAN) | (1 << JavaParser.BYTE) | (1 << JavaParser.CHAR) | (1 << JavaParser.DOUBLE) | (1 << JavaParser.FLOAT) | (1 << JavaParser.INT) | (1 << JavaParser.LONG) | (1 << JavaParser.NEW) | (1 << JavaParser.SHORT) | (1 << JavaParser.SUPER) | (1 << JavaParser.THIS) | (1 << JavaParser.VOID) | (1 << JavaParser.IntegerLiteral) | (1 << JavaParser.FloatingPointLiteral) | (1 << JavaParser.BooleanLiteral) | (1 << JavaParser.CharacterLiteral) | (1 << JavaParser.StringLiteral) | (1 << JavaParser.NullLiteral) | (1 << JavaParser.LPAREN) | (1 << JavaParser.LBRACE))) != 0) or ((((_la - 70)) & ~0x3f) == 0 and ((1 << (_la - 70)) & ((1 << (JavaParser.LT - 70)) | (1 << (JavaParser.BANG - 70)) | (1 << (JavaParser.TILDE - 70)) | (1 << (JavaParser.INC - 70)) | (1 << (JavaParser.DEC - 70)) | (1 << (JavaParser.ADD - 70)) | (1 << (JavaParser.SUB - 70)) | (1 << (JavaParser.Identifier - 70)) | (1 << (JavaParser.AT - 70)))) != 0):
                self.state = 748
                self.elementValue()
                self.state = 753
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,83,self._ctx)
                while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                    if _alt==1:
                        self.state = 749
                        self.match(JavaParser.COMMA)
                        self.state = 750
                        self.elementValue() 
                    self.state = 755
                    self._errHandler.sync(self)
                    _alt = self._interp.adaptivePredict(self._input,83,self._ctx)



            self.state = 759
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==JavaParser.COMMA:
                self.state = 758
                self.match(JavaParser.COMMA)


            self.state = 761
            self.match(JavaParser.RBRACE)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class AnnotationTypeDeclarationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def AT(self):
            return self.getToken(JavaParser.AT, 0)

        def INTERFACE(self):
            return self.getToken(JavaParser.INTERFACE, 0)

        def Identifier(self):
            return self.getToken(JavaParser.Identifier, 0)

        def annotationTypeBody(self):
            return self.getTypedRuleContext(JavaParser.AnnotationTypeBodyContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_annotationTypeDeclaration

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAnnotationTypeDeclaration" ):
                listener.enterAnnotationTypeDeclaration(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAnnotationTypeDeclaration" ):
                listener.exitAnnotationTypeDeclaration(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitAnnotationTypeDeclaration" ):
                return visitor.visitAnnotationTypeDeclaration(self)
            else:
                return visitor.visitChildren(self)




    def annotationTypeDeclaration(self):

        localctx = JavaParser.AnnotationTypeDeclarationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 118, self.RULE_annotationTypeDeclaration)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 763
            self.match(JavaParser.AT)
            self.state = 764
            self.match(JavaParser.INTERFACE)
            self.state = 765
            self.match(JavaParser.Identifier)
            self.state = 766
            self.annotationTypeBody()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class AnnotationTypeBodyContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LBRACE(self):
            return self.getToken(JavaParser.LBRACE, 0)

        def RBRACE(self):
            return self.getToken(JavaParser.RBRACE, 0)

        def annotationTypeElementDeclaration(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.AnnotationTypeElementDeclarationContext)
            else:
                return self.getTypedRuleContext(JavaParser.AnnotationTypeElementDeclarationContext,i)


        def getRuleIndex(self):
            return JavaParser.RULE_annotationTypeBody

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAnnotationTypeBody" ):
                listener.enterAnnotationTypeBody(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAnnotationTypeBody" ):
                listener.exitAnnotationTypeBody(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitAnnotationTypeBody" ):
                return visitor.visitAnnotationTypeBody(self)
            else:
                return visitor.visitChildren(self)




    def annotationTypeBody(self):

        localctx = JavaParser.AnnotationTypeBodyContext(self, self._ctx, self.state)
        self.enterRule(localctx, 120, self.RULE_annotationTypeBody)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 768
            self.match(JavaParser.LBRACE)
            self.state = 772
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << JavaParser.ABSTRACT) | (1 << JavaParser.BOOLEAN) | (1 << JavaParser.BYTE) | (1 << JavaParser.CHAR) | (1 << JavaParser.CLASS) | (1 << JavaParser.DOUBLE) | (1 << JavaParser.ENUM) | (1 << JavaParser.FINAL) | (1 << JavaParser.FLOAT) | (1 << JavaParser.INT) | (1 << JavaParser.INTERFACE) | (1 << JavaParser.LONG) | (1 << JavaParser.NATIVE) | (1 << JavaParser.PRIVATE) | (1 << JavaParser.PROTECTED) | (1 << JavaParser.PUBLIC) | (1 << JavaParser.SHORT) | (1 << JavaParser.STATIC) | (1 << JavaParser.STRICTFP) | (1 << JavaParser.SYNCHRONIZED) | (1 << JavaParser.TRANSIENT) | (1 << JavaParser.VOLATILE))) != 0) or ((((_la - 65)) & ~0x3f) == 0 and ((1 << (_la - 65)) & ((1 << (JavaParser.SEMI - 65)) | (1 << (JavaParser.Identifier - 65)) | (1 << (JavaParser.AT - 65)))) != 0):
                self.state = 769
                self.annotationTypeElementDeclaration()
                self.state = 774
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 775
            self.match(JavaParser.RBRACE)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class AnnotationTypeElementDeclarationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def annotationTypeElementRest(self):
            return self.getTypedRuleContext(JavaParser.AnnotationTypeElementRestContext,0)


        def modifier(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.ModifierContext)
            else:
                return self.getTypedRuleContext(JavaParser.ModifierContext,i)


        def SEMI(self):
            return self.getToken(JavaParser.SEMI, 0)

        def getRuleIndex(self):
            return JavaParser.RULE_annotationTypeElementDeclaration

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAnnotationTypeElementDeclaration" ):
                listener.enterAnnotationTypeElementDeclaration(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAnnotationTypeElementDeclaration" ):
                listener.exitAnnotationTypeElementDeclaration(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitAnnotationTypeElementDeclaration" ):
                return visitor.visitAnnotationTypeElementDeclaration(self)
            else:
                return visitor.visitChildren(self)




    def annotationTypeElementDeclaration(self):

        localctx = JavaParser.AnnotationTypeElementDeclarationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 122, self.RULE_annotationTypeElementDeclaration)
        try:
            self.state = 785
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [JavaParser.ABSTRACT, JavaParser.BOOLEAN, JavaParser.BYTE, JavaParser.CHAR, JavaParser.CLASS, JavaParser.DOUBLE, JavaParser.ENUM, JavaParser.FINAL, JavaParser.FLOAT, JavaParser.INT, JavaParser.INTERFACE, JavaParser.LONG, JavaParser.NATIVE, JavaParser.PRIVATE, JavaParser.PROTECTED, JavaParser.PUBLIC, JavaParser.SHORT, JavaParser.STATIC, JavaParser.STRICTFP, JavaParser.SYNCHRONIZED, JavaParser.TRANSIENT, JavaParser.VOLATILE, JavaParser.Identifier, JavaParser.AT]:
                self.enterOuterAlt(localctx, 1)
                self.state = 780
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,87,self._ctx)
                while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                    if _alt==1:
                        self.state = 777
                        self.modifier() 
                    self.state = 782
                    self._errHandler.sync(self)
                    _alt = self._interp.adaptivePredict(self._input,87,self._ctx)

                self.state = 783
                self.annotationTypeElementRest()
                pass
            elif token in [JavaParser.SEMI]:
                self.enterOuterAlt(localctx, 2)
                self.state = 784
                self.match(JavaParser.SEMI)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class AnnotationTypeElementRestContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def jType(self):
            return self.getTypedRuleContext(JavaParser.JTypeContext,0)


        def annotationMethodOrConstantRest(self):
            return self.getTypedRuleContext(JavaParser.AnnotationMethodOrConstantRestContext,0)


        def SEMI(self):
            return self.getToken(JavaParser.SEMI, 0)

        def classDeclaration(self):
            return self.getTypedRuleContext(JavaParser.ClassDeclarationContext,0)


        def interfaceDeclaration(self):
            return self.getTypedRuleContext(JavaParser.InterfaceDeclarationContext,0)


        def enumDeclaration(self):
            return self.getTypedRuleContext(JavaParser.EnumDeclarationContext,0)


        def annotationTypeDeclaration(self):
            return self.getTypedRuleContext(JavaParser.AnnotationTypeDeclarationContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_annotationTypeElementRest

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAnnotationTypeElementRest" ):
                listener.enterAnnotationTypeElementRest(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAnnotationTypeElementRest" ):
                listener.exitAnnotationTypeElementRest(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitAnnotationTypeElementRest" ):
                return visitor.visitAnnotationTypeElementRest(self)
            else:
                return visitor.visitChildren(self)




    def annotationTypeElementRest(self):

        localctx = JavaParser.AnnotationTypeElementRestContext(self, self._ctx, self.state)
        self.enterRule(localctx, 124, self.RULE_annotationTypeElementRest)
        try:
            self.state = 807
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [JavaParser.BOOLEAN, JavaParser.BYTE, JavaParser.CHAR, JavaParser.DOUBLE, JavaParser.FLOAT, JavaParser.INT, JavaParser.LONG, JavaParser.SHORT, JavaParser.Identifier]:
                self.enterOuterAlt(localctx, 1)
                self.state = 787
                self.jType()
                self.state = 788
                self.annotationMethodOrConstantRest()
                self.state = 789
                self.match(JavaParser.SEMI)
                pass
            elif token in [JavaParser.CLASS]:
                self.enterOuterAlt(localctx, 2)
                self.state = 791
                self.classDeclaration()
                self.state = 793
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,89,self._ctx)
                if la_ == 1:
                    self.state = 792
                    self.match(JavaParser.SEMI)


                pass
            elif token in [JavaParser.INTERFACE]:
                self.enterOuterAlt(localctx, 3)
                self.state = 795
                self.interfaceDeclaration()
                self.state = 797
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,90,self._ctx)
                if la_ == 1:
                    self.state = 796
                    self.match(JavaParser.SEMI)


                pass
            elif token in [JavaParser.ENUM]:
                self.enterOuterAlt(localctx, 4)
                self.state = 799
                self.enumDeclaration()
                self.state = 801
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,91,self._ctx)
                if la_ == 1:
                    self.state = 800
                    self.match(JavaParser.SEMI)


                pass
            elif token in [JavaParser.AT]:
                self.enterOuterAlt(localctx, 5)
                self.state = 803
                self.annotationTypeDeclaration()
                self.state = 805
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,92,self._ctx)
                if la_ == 1:
                    self.state = 804
                    self.match(JavaParser.SEMI)


                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class AnnotationMethodOrConstantRestContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def annotationMethodRest(self):
            return self.getTypedRuleContext(JavaParser.AnnotationMethodRestContext,0)


        def annotationConstantRest(self):
            return self.getTypedRuleContext(JavaParser.AnnotationConstantRestContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_annotationMethodOrConstantRest

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAnnotationMethodOrConstantRest" ):
                listener.enterAnnotationMethodOrConstantRest(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAnnotationMethodOrConstantRest" ):
                listener.exitAnnotationMethodOrConstantRest(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitAnnotationMethodOrConstantRest" ):
                return visitor.visitAnnotationMethodOrConstantRest(self)
            else:
                return visitor.visitChildren(self)




    def annotationMethodOrConstantRest(self):

        localctx = JavaParser.AnnotationMethodOrConstantRestContext(self, self._ctx, self.state)
        self.enterRule(localctx, 126, self.RULE_annotationMethodOrConstantRest)
        try:
            self.state = 811
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,94,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 809
                self.annotationMethodRest()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 810
                self.annotationConstantRest()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class AnnotationMethodRestContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Identifier(self):
            return self.getToken(JavaParser.Identifier, 0)

        def LPAREN(self):
            return self.getToken(JavaParser.LPAREN, 0)

        def RPAREN(self):
            return self.getToken(JavaParser.RPAREN, 0)

        def defaultValue(self):
            return self.getTypedRuleContext(JavaParser.DefaultValueContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_annotationMethodRest

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAnnotationMethodRest" ):
                listener.enterAnnotationMethodRest(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAnnotationMethodRest" ):
                listener.exitAnnotationMethodRest(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitAnnotationMethodRest" ):
                return visitor.visitAnnotationMethodRest(self)
            else:
                return visitor.visitChildren(self)




    def annotationMethodRest(self):

        localctx = JavaParser.AnnotationMethodRestContext(self, self._ctx, self.state)
        self.enterRule(localctx, 128, self.RULE_annotationMethodRest)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 813
            self.match(JavaParser.Identifier)
            self.state = 814
            self.match(JavaParser.LPAREN)
            self.state = 815
            self.match(JavaParser.RPAREN)
            self.state = 817
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==JavaParser.DEFAULT:
                self.state = 816
                self.defaultValue()


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class AnnotationConstantRestContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def variableDeclarators(self):
            return self.getTypedRuleContext(JavaParser.VariableDeclaratorsContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_annotationConstantRest

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAnnotationConstantRest" ):
                listener.enterAnnotationConstantRest(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAnnotationConstantRest" ):
                listener.exitAnnotationConstantRest(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitAnnotationConstantRest" ):
                return visitor.visitAnnotationConstantRest(self)
            else:
                return visitor.visitChildren(self)




    def annotationConstantRest(self):

        localctx = JavaParser.AnnotationConstantRestContext(self, self._ctx, self.state)
        self.enterRule(localctx, 130, self.RULE_annotationConstantRest)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 819
            self.variableDeclarators()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class DefaultValueContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def DEFAULT(self):
            return self.getToken(JavaParser.DEFAULT, 0)

        def elementValue(self):
            return self.getTypedRuleContext(JavaParser.ElementValueContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_defaultValue

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDefaultValue" ):
                listener.enterDefaultValue(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDefaultValue" ):
                listener.exitDefaultValue(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDefaultValue" ):
                return visitor.visitDefaultValue(self)
            else:
                return visitor.visitChildren(self)




    def defaultValue(self):

        localctx = JavaParser.DefaultValueContext(self, self._ctx, self.state)
        self.enterRule(localctx, 132, self.RULE_defaultValue)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 821
            self.match(JavaParser.DEFAULT)
            self.state = 822
            self.elementValue()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class BlockContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LBRACE(self):
            return self.getToken(JavaParser.LBRACE, 0)

        def RBRACE(self):
            return self.getToken(JavaParser.RBRACE, 0)

        def blockStatement(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.BlockStatementContext)
            else:
                return self.getTypedRuleContext(JavaParser.BlockStatementContext,i)


        def getRuleIndex(self):
            return JavaParser.RULE_block

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBlock" ):
                listener.enterBlock(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBlock" ):
                listener.exitBlock(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitBlock" ):
                return visitor.visitBlock(self)
            else:
                return visitor.visitChildren(self)




    def block(self):

        localctx = JavaParser.BlockContext(self, self._ctx, self.state)
        self.enterRule(localctx, 134, self.RULE_block)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 824
            self.match(JavaParser.LBRACE)
            self.state = 828
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << JavaParser.ABSTRACT) | (1 << JavaParser.ASSERT) | (1 << JavaParser.BOOLEAN) | (1 << JavaParser.BREAK) | (1 << JavaParser.BYTE) | (1 << JavaParser.CHAR) | (1 << JavaParser.CLASS) | (1 << JavaParser.CONTINUE) | (1 << JavaParser.DO) | (1 << JavaParser.DOUBLE) | (1 << JavaParser.ENUM) | (1 << JavaParser.FINAL) | (1 << JavaParser.FLOAT) | (1 << JavaParser.FOR) | (1 << JavaParser.IF) | (1 << JavaParser.INT) | (1 << JavaParser.INTERFACE) | (1 << JavaParser.LONG) | (1 << JavaParser.NEW) | (1 << JavaParser.PRIVATE) | (1 << JavaParser.PROTECTED) | (1 << JavaParser.PUBLIC) | (1 << JavaParser.RETURN) | (1 << JavaParser.SHORT) | (1 << JavaParser.STATIC) | (1 << JavaParser.STRICTFP) | (1 << JavaParser.SUPER) | (1 << JavaParser.SWITCH) | (1 << JavaParser.SYNCHRONIZED) | (1 << JavaParser.THIS) | (1 << JavaParser.THROW) | (1 << JavaParser.TRY) | (1 << JavaParser.VOID) | (1 << JavaParser.WHILE) | (1 << JavaParser.IntegerLiteral) | (1 << JavaParser.FloatingPointLiteral) | (1 << JavaParser.BooleanLiteral) | (1 << JavaParser.CharacterLiteral) | (1 << JavaParser.StringLiteral) | (1 << JavaParser.NullLiteral) | (1 << JavaParser.LPAREN) | (1 << JavaParser.LBRACE))) != 0) or ((((_la - 65)) & ~0x3f) == 0 and ((1 << (_la - 65)) & ((1 << (JavaParser.SEMI - 65)) | (1 << (JavaParser.LT - 65)) | (1 << (JavaParser.BANG - 65)) | (1 << (JavaParser.TILDE - 65)) | (1 << (JavaParser.INC - 65)) | (1 << (JavaParser.DEC - 65)) | (1 << (JavaParser.ADD - 65)) | (1 << (JavaParser.SUB - 65)) | (1 << (JavaParser.Identifier - 65)) | (1 << (JavaParser.AT - 65)))) != 0):
                self.state = 825
                self.blockStatement()
                self.state = 830
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 831
            self.match(JavaParser.RBRACE)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class BlockStatementContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def localVariableDeclarationStatement(self):
            return self.getTypedRuleContext(JavaParser.LocalVariableDeclarationStatementContext,0)


        def statement(self):
            return self.getTypedRuleContext(JavaParser.StatementContext,0)


        def typeDeclaration(self):
            return self.getTypedRuleContext(JavaParser.TypeDeclarationContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_blockStatement

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBlockStatement" ):
                listener.enterBlockStatement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBlockStatement" ):
                listener.exitBlockStatement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitBlockStatement" ):
                return visitor.visitBlockStatement(self)
            else:
                return visitor.visitChildren(self)




    def blockStatement(self):

        localctx = JavaParser.BlockStatementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 136, self.RULE_blockStatement)
        try:
            self.state = 836
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,97,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 833
                self.localVariableDeclarationStatement()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 834
                self.statement()
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 835
                self.typeDeclaration()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class LocalVariableDeclarationStatementContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def localVariableDeclaration(self):
            return self.getTypedRuleContext(JavaParser.LocalVariableDeclarationContext,0)


        def SEMI(self):
            return self.getToken(JavaParser.SEMI, 0)

        def getRuleIndex(self):
            return JavaParser.RULE_localVariableDeclarationStatement

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterLocalVariableDeclarationStatement" ):
                listener.enterLocalVariableDeclarationStatement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitLocalVariableDeclarationStatement" ):
                listener.exitLocalVariableDeclarationStatement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitLocalVariableDeclarationStatement" ):
                return visitor.visitLocalVariableDeclarationStatement(self)
            else:
                return visitor.visitChildren(self)




    def localVariableDeclarationStatement(self):

        localctx = JavaParser.LocalVariableDeclarationStatementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 138, self.RULE_localVariableDeclarationStatement)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 838
            self.localVariableDeclaration()
            self.state = 839
            self.match(JavaParser.SEMI)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class LocalVariableDeclarationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def jType(self):
            return self.getTypedRuleContext(JavaParser.JTypeContext,0)


        def variableDeclarators(self):
            return self.getTypedRuleContext(JavaParser.VariableDeclaratorsContext,0)


        def variableModifier(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.VariableModifierContext)
            else:
                return self.getTypedRuleContext(JavaParser.VariableModifierContext,i)


        def getRuleIndex(self):
            return JavaParser.RULE_localVariableDeclaration

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterLocalVariableDeclaration" ):
                listener.enterLocalVariableDeclaration(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitLocalVariableDeclaration" ):
                listener.exitLocalVariableDeclaration(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitLocalVariableDeclaration" ):
                return visitor.visitLocalVariableDeclaration(self)
            else:
                return visitor.visitChildren(self)




    def localVariableDeclaration(self):

        localctx = JavaParser.LocalVariableDeclarationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 140, self.RULE_localVariableDeclaration)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 844
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==JavaParser.FINAL or _la==JavaParser.AT:
                self.state = 841
                self.variableModifier()
                self.state = 846
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 847
            self.jType()
            self.state = 848
            self.variableDeclarators()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class StatementContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def block(self):
            return self.getTypedRuleContext(JavaParser.BlockContext,0)


        def ASSERT(self):
            return self.getToken(JavaParser.ASSERT, 0)

        def expression(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.ExpressionContext)
            else:
                return self.getTypedRuleContext(JavaParser.ExpressionContext,i)


        def SEMI(self):
            return self.getToken(JavaParser.SEMI, 0)

        def COLON(self):
            return self.getToken(JavaParser.COLON, 0)

        def IF(self):
            return self.getToken(JavaParser.IF, 0)

        def parExpression(self):
            return self.getTypedRuleContext(JavaParser.ParExpressionContext,0)


        def statement(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.StatementContext)
            else:
                return self.getTypedRuleContext(JavaParser.StatementContext,i)


        def ELSE(self):
            return self.getToken(JavaParser.ELSE, 0)

        def FOR(self):
            return self.getToken(JavaParser.FOR, 0)

        def LPAREN(self):
            return self.getToken(JavaParser.LPAREN, 0)

        def forControl(self):
            return self.getTypedRuleContext(JavaParser.ForControlContext,0)


        def RPAREN(self):
            return self.getToken(JavaParser.RPAREN, 0)

        def WHILE(self):
            return self.getToken(JavaParser.WHILE, 0)

        def DO(self):
            return self.getToken(JavaParser.DO, 0)

        def TRY(self):
            return self.getToken(JavaParser.TRY, 0)

        def finallyBlock(self):
            return self.getTypedRuleContext(JavaParser.FinallyBlockContext,0)


        def catchClause(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.CatchClauseContext)
            else:
                return self.getTypedRuleContext(JavaParser.CatchClauseContext,i)


        def resourceSpecification(self):
            return self.getTypedRuleContext(JavaParser.ResourceSpecificationContext,0)


        def SWITCH(self):
            return self.getToken(JavaParser.SWITCH, 0)

        def LBRACE(self):
            return self.getToken(JavaParser.LBRACE, 0)

        def RBRACE(self):
            return self.getToken(JavaParser.RBRACE, 0)

        def switchBlockStatementGroup(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.SwitchBlockStatementGroupContext)
            else:
                return self.getTypedRuleContext(JavaParser.SwitchBlockStatementGroupContext,i)


        def switchLabel(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.SwitchLabelContext)
            else:
                return self.getTypedRuleContext(JavaParser.SwitchLabelContext,i)


        def SYNCHRONIZED(self):
            return self.getToken(JavaParser.SYNCHRONIZED, 0)

        def RETURN(self):
            return self.getToken(JavaParser.RETURN, 0)

        def THROW(self):
            return self.getToken(JavaParser.THROW, 0)

        def BREAK(self):
            return self.getToken(JavaParser.BREAK, 0)

        def Identifier(self):
            return self.getToken(JavaParser.Identifier, 0)

        def CONTINUE(self):
            return self.getToken(JavaParser.CONTINUE, 0)

        def statementExpression(self):
            return self.getTypedRuleContext(JavaParser.StatementExpressionContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_statement

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterStatement" ):
                listener.enterStatement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitStatement" ):
                listener.exitStatement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitStatement" ):
                return visitor.visitStatement(self)
            else:
                return visitor.visitChildren(self)




    def statement(self):

        localctx = JavaParser.StatementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 142, self.RULE_statement)
        self._la = 0 # Token type
        try:
            self.state = 954
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,111,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 850
                self.block()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 851
                self.match(JavaParser.ASSERT)
                self.state = 852
                self.expression(0)
                self.state = 855
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==JavaParser.COLON:
                    self.state = 853
                    self.match(JavaParser.COLON)
                    self.state = 854
                    self.expression(0)


                self.state = 857
                self.match(JavaParser.SEMI)
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 859
                self.match(JavaParser.IF)
                self.state = 860
                self.parExpression()
                self.state = 861
                self.statement()
                self.state = 864
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,100,self._ctx)
                if la_ == 1:
                    self.state = 862
                    self.match(JavaParser.ELSE)
                    self.state = 863
                    self.statement()


                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 866
                self.match(JavaParser.FOR)
                self.state = 867
                self.match(JavaParser.LPAREN)
                self.state = 868
                self.forControl()
                self.state = 869
                self.match(JavaParser.RPAREN)
                self.state = 870
                self.statement()
                pass

            elif la_ == 5:
                self.enterOuterAlt(localctx, 5)
                self.state = 872
                self.match(JavaParser.WHILE)
                self.state = 873
                self.parExpression()
                self.state = 874
                self.statement()
                pass

            elif la_ == 6:
                self.enterOuterAlt(localctx, 6)
                self.state = 876
                self.match(JavaParser.DO)
                self.state = 877
                self.statement()
                self.state = 878
                self.match(JavaParser.WHILE)
                self.state = 879
                self.parExpression()
                self.state = 880
                self.match(JavaParser.SEMI)
                pass

            elif la_ == 7:
                self.enterOuterAlt(localctx, 7)
                self.state = 882
                self.match(JavaParser.TRY)
                self.state = 883
                self.block()
                self.state = 893
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [JavaParser.CATCH]:
                    self.state = 885 
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)
                    while True:
                        self.state = 884
                        self.catchClause()
                        self.state = 887 
                        self._errHandler.sync(self)
                        _la = self._input.LA(1)
                        if not (_la==JavaParser.CATCH):
                            break

                    self.state = 890
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)
                    if _la==JavaParser.FINALLY:
                        self.state = 889
                        self.finallyBlock()


                    pass
                elif token in [JavaParser.FINALLY]:
                    self.state = 892
                    self.finallyBlock()
                    pass
                else:
                    raise NoViableAltException(self)

                pass

            elif la_ == 8:
                self.enterOuterAlt(localctx, 8)
                self.state = 895
                self.match(JavaParser.TRY)
                self.state = 896
                self.resourceSpecification()
                self.state = 897
                self.block()
                self.state = 901
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==JavaParser.CATCH:
                    self.state = 898
                    self.catchClause()
                    self.state = 903
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                self.state = 905
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==JavaParser.FINALLY:
                    self.state = 904
                    self.finallyBlock()


                pass

            elif la_ == 9:
                self.enterOuterAlt(localctx, 9)
                self.state = 907
                self.match(JavaParser.SWITCH)
                self.state = 908
                self.parExpression()
                self.state = 909
                self.match(JavaParser.LBRACE)
                self.state = 913
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,106,self._ctx)
                while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                    if _alt==1:
                        self.state = 910
                        self.switchBlockStatementGroup() 
                    self.state = 915
                    self._errHandler.sync(self)
                    _alt = self._interp.adaptivePredict(self._input,106,self._ctx)

                self.state = 919
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==JavaParser.CASE or _la==JavaParser.DEFAULT:
                    self.state = 916
                    self.switchLabel()
                    self.state = 921
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                self.state = 922
                self.match(JavaParser.RBRACE)
                pass

            elif la_ == 10:
                self.enterOuterAlt(localctx, 10)
                self.state = 924
                self.match(JavaParser.SYNCHRONIZED)
                self.state = 925
                self.parExpression()
                self.state = 926
                self.block()
                pass

            elif la_ == 11:
                self.enterOuterAlt(localctx, 11)
                self.state = 928
                self.match(JavaParser.RETURN)
                self.state = 930
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << JavaParser.BOOLEAN) | (1 << JavaParser.BYTE) | (1 << JavaParser.CHAR) | (1 << JavaParser.DOUBLE) | (1 << JavaParser.FLOAT) | (1 << JavaParser.INT) | (1 << JavaParser.LONG) | (1 << JavaParser.NEW) | (1 << JavaParser.SHORT) | (1 << JavaParser.SUPER) | (1 << JavaParser.THIS) | (1 << JavaParser.VOID) | (1 << JavaParser.IntegerLiteral) | (1 << JavaParser.FloatingPointLiteral) | (1 << JavaParser.BooleanLiteral) | (1 << JavaParser.CharacterLiteral) | (1 << JavaParser.StringLiteral) | (1 << JavaParser.NullLiteral) | (1 << JavaParser.LPAREN))) != 0) or ((((_la - 70)) & ~0x3f) == 0 and ((1 << (_la - 70)) & ((1 << (JavaParser.LT - 70)) | (1 << (JavaParser.BANG - 70)) | (1 << (JavaParser.TILDE - 70)) | (1 << (JavaParser.INC - 70)) | (1 << (JavaParser.DEC - 70)) | (1 << (JavaParser.ADD - 70)) | (1 << (JavaParser.SUB - 70)) | (1 << (JavaParser.Identifier - 70)))) != 0):
                    self.state = 929
                    self.expression(0)


                self.state = 932
                self.match(JavaParser.SEMI)
                pass

            elif la_ == 12:
                self.enterOuterAlt(localctx, 12)
                self.state = 933
                self.match(JavaParser.THROW)
                self.state = 934
                self.expression(0)
                self.state = 935
                self.match(JavaParser.SEMI)
                pass

            elif la_ == 13:
                self.enterOuterAlt(localctx, 13)
                self.state = 937
                self.match(JavaParser.BREAK)
                self.state = 939
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==JavaParser.Identifier:
                    self.state = 938
                    self.match(JavaParser.Identifier)


                self.state = 941
                self.match(JavaParser.SEMI)
                pass

            elif la_ == 14:
                self.enterOuterAlt(localctx, 14)
                self.state = 942
                self.match(JavaParser.CONTINUE)
                self.state = 944
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==JavaParser.Identifier:
                    self.state = 943
                    self.match(JavaParser.Identifier)


                self.state = 946
                self.match(JavaParser.SEMI)
                pass

            elif la_ == 15:
                self.enterOuterAlt(localctx, 15)
                self.state = 947
                self.match(JavaParser.SEMI)
                pass

            elif la_ == 16:
                self.enterOuterAlt(localctx, 16)
                self.state = 948
                self.statementExpression()
                self.state = 949
                self.match(JavaParser.SEMI)
                pass

            elif la_ == 17:
                self.enterOuterAlt(localctx, 17)
                self.state = 951
                self.match(JavaParser.Identifier)
                self.state = 952
                self.match(JavaParser.COLON)
                self.state = 953
                self.statement()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class CatchClauseContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def CATCH(self):
            return self.getToken(JavaParser.CATCH, 0)

        def LPAREN(self):
            return self.getToken(JavaParser.LPAREN, 0)

        def catchType(self):
            return self.getTypedRuleContext(JavaParser.CatchTypeContext,0)


        def Identifier(self):
            return self.getToken(JavaParser.Identifier, 0)

        def RPAREN(self):
            return self.getToken(JavaParser.RPAREN, 0)

        def block(self):
            return self.getTypedRuleContext(JavaParser.BlockContext,0)


        def variableModifier(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.VariableModifierContext)
            else:
                return self.getTypedRuleContext(JavaParser.VariableModifierContext,i)


        def getRuleIndex(self):
            return JavaParser.RULE_catchClause

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCatchClause" ):
                listener.enterCatchClause(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCatchClause" ):
                listener.exitCatchClause(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitCatchClause" ):
                return visitor.visitCatchClause(self)
            else:
                return visitor.visitChildren(self)




    def catchClause(self):

        localctx = JavaParser.CatchClauseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 144, self.RULE_catchClause)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 956
            self.match(JavaParser.CATCH)
            self.state = 957
            self.match(JavaParser.LPAREN)
            self.state = 961
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==JavaParser.FINAL or _la==JavaParser.AT:
                self.state = 958
                self.variableModifier()
                self.state = 963
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 964
            self.catchType()
            self.state = 965
            self.match(JavaParser.Identifier)
            self.state = 966
            self.match(JavaParser.RPAREN)
            self.state = 967
            self.block()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class CatchTypeContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def qualifiedName(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.QualifiedNameContext)
            else:
                return self.getTypedRuleContext(JavaParser.QualifiedNameContext,i)


        def BITOR(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.BITOR)
            else:
                return self.getToken(JavaParser.BITOR, i)

        def getRuleIndex(self):
            return JavaParser.RULE_catchType

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCatchType" ):
                listener.enterCatchType(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCatchType" ):
                listener.exitCatchType(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitCatchType" ):
                return visitor.visitCatchType(self)
            else:
                return visitor.visitChildren(self)




    def catchType(self):

        localctx = JavaParser.CatchTypeContext(self, self._ctx, self.state)
        self.enterRule(localctx, 146, self.RULE_catchType)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 969
            self.qualifiedName()
            self.state = 974
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==JavaParser.BITOR:
                self.state = 970
                self.match(JavaParser.BITOR)
                self.state = 971
                self.qualifiedName()
                self.state = 976
                self._errHandler.sync(self)
                _la = self._input.LA(1)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class FinallyBlockContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def FINALLY(self):
            return self.getToken(JavaParser.FINALLY, 0)

        def block(self):
            return self.getTypedRuleContext(JavaParser.BlockContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_finallyBlock

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFinallyBlock" ):
                listener.enterFinallyBlock(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFinallyBlock" ):
                listener.exitFinallyBlock(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitFinallyBlock" ):
                return visitor.visitFinallyBlock(self)
            else:
                return visitor.visitChildren(self)




    def finallyBlock(self):

        localctx = JavaParser.FinallyBlockContext(self, self._ctx, self.state)
        self.enterRule(localctx, 148, self.RULE_finallyBlock)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 977
            self.match(JavaParser.FINALLY)
            self.state = 978
            self.block()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ResourceSpecificationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LPAREN(self):
            return self.getToken(JavaParser.LPAREN, 0)

        def resources(self):
            return self.getTypedRuleContext(JavaParser.ResourcesContext,0)


        def RPAREN(self):
            return self.getToken(JavaParser.RPAREN, 0)

        def SEMI(self):
            return self.getToken(JavaParser.SEMI, 0)

        def getRuleIndex(self):
            return JavaParser.RULE_resourceSpecification

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterResourceSpecification" ):
                listener.enterResourceSpecification(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitResourceSpecification" ):
                listener.exitResourceSpecification(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitResourceSpecification" ):
                return visitor.visitResourceSpecification(self)
            else:
                return visitor.visitChildren(self)




    def resourceSpecification(self):

        localctx = JavaParser.ResourceSpecificationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 150, self.RULE_resourceSpecification)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 980
            self.match(JavaParser.LPAREN)
            self.state = 981
            self.resources()
            self.state = 983
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==JavaParser.SEMI:
                self.state = 982
                self.match(JavaParser.SEMI)


            self.state = 985
            self.match(JavaParser.RPAREN)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ResourcesContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def resource(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.ResourceContext)
            else:
                return self.getTypedRuleContext(JavaParser.ResourceContext,i)


        def SEMI(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.SEMI)
            else:
                return self.getToken(JavaParser.SEMI, i)

        def getRuleIndex(self):
            return JavaParser.RULE_resources

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterResources" ):
                listener.enterResources(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitResources" ):
                listener.exitResources(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitResources" ):
                return visitor.visitResources(self)
            else:
                return visitor.visitChildren(self)




    def resources(self):

        localctx = JavaParser.ResourcesContext(self, self._ctx, self.state)
        self.enterRule(localctx, 152, self.RULE_resources)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 987
            self.resource()
            self.state = 992
            self._errHandler.sync(self)
            _alt = self._interp.adaptivePredict(self._input,115,self._ctx)
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt==1:
                    self.state = 988
                    self.match(JavaParser.SEMI)
                    self.state = 989
                    self.resource() 
                self.state = 994
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,115,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ResourceContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def classOrInterfaceType(self):
            return self.getTypedRuleContext(JavaParser.ClassOrInterfaceTypeContext,0)


        def variableDeclaratorId(self):
            return self.getTypedRuleContext(JavaParser.VariableDeclaratorIdContext,0)


        def ASSIGN(self):
            return self.getToken(JavaParser.ASSIGN, 0)

        def expression(self):
            return self.getTypedRuleContext(JavaParser.ExpressionContext,0)


        def variableModifier(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.VariableModifierContext)
            else:
                return self.getTypedRuleContext(JavaParser.VariableModifierContext,i)


        def getRuleIndex(self):
            return JavaParser.RULE_resource

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterResource" ):
                listener.enterResource(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitResource" ):
                listener.exitResource(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitResource" ):
                return visitor.visitResource(self)
            else:
                return visitor.visitChildren(self)




    def resource(self):

        localctx = JavaParser.ResourceContext(self, self._ctx, self.state)
        self.enterRule(localctx, 154, self.RULE_resource)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 998
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==JavaParser.FINAL or _la==JavaParser.AT:
                self.state = 995
                self.variableModifier()
                self.state = 1000
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 1001
            self.classOrInterfaceType()
            self.state = 1002
            self.variableDeclaratorId()
            self.state = 1003
            self.match(JavaParser.ASSIGN)
            self.state = 1004
            self.expression(0)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class SwitchBlockStatementGroupContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def switchLabel(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.SwitchLabelContext)
            else:
                return self.getTypedRuleContext(JavaParser.SwitchLabelContext,i)


        def blockStatement(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.BlockStatementContext)
            else:
                return self.getTypedRuleContext(JavaParser.BlockStatementContext,i)


        def getRuleIndex(self):
            return JavaParser.RULE_switchBlockStatementGroup

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSwitchBlockStatementGroup" ):
                listener.enterSwitchBlockStatementGroup(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSwitchBlockStatementGroup" ):
                listener.exitSwitchBlockStatementGroup(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSwitchBlockStatementGroup" ):
                return visitor.visitSwitchBlockStatementGroup(self)
            else:
                return visitor.visitChildren(self)




    def switchBlockStatementGroup(self):

        localctx = JavaParser.SwitchBlockStatementGroupContext(self, self._ctx, self.state)
        self.enterRule(localctx, 156, self.RULE_switchBlockStatementGroup)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1007 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 1006
                self.switchLabel()
                self.state = 1009 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not (_la==JavaParser.CASE or _la==JavaParser.DEFAULT):
                    break

            self.state = 1012 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 1011
                self.blockStatement()
                self.state = 1014 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not ((((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << JavaParser.ABSTRACT) | (1 << JavaParser.ASSERT) | (1 << JavaParser.BOOLEAN) | (1 << JavaParser.BREAK) | (1 << JavaParser.BYTE) | (1 << JavaParser.CHAR) | (1 << JavaParser.CLASS) | (1 << JavaParser.CONTINUE) | (1 << JavaParser.DO) | (1 << JavaParser.DOUBLE) | (1 << JavaParser.ENUM) | (1 << JavaParser.FINAL) | (1 << JavaParser.FLOAT) | (1 << JavaParser.FOR) | (1 << JavaParser.IF) | (1 << JavaParser.INT) | (1 << JavaParser.INTERFACE) | (1 << JavaParser.LONG) | (1 << JavaParser.NEW) | (1 << JavaParser.PRIVATE) | (1 << JavaParser.PROTECTED) | (1 << JavaParser.PUBLIC) | (1 << JavaParser.RETURN) | (1 << JavaParser.SHORT) | (1 << JavaParser.STATIC) | (1 << JavaParser.STRICTFP) | (1 << JavaParser.SUPER) | (1 << JavaParser.SWITCH) | (1 << JavaParser.SYNCHRONIZED) | (1 << JavaParser.THIS) | (1 << JavaParser.THROW) | (1 << JavaParser.TRY) | (1 << JavaParser.VOID) | (1 << JavaParser.WHILE) | (1 << JavaParser.IntegerLiteral) | (1 << JavaParser.FloatingPointLiteral) | (1 << JavaParser.BooleanLiteral) | (1 << JavaParser.CharacterLiteral) | (1 << JavaParser.StringLiteral) | (1 << JavaParser.NullLiteral) | (1 << JavaParser.LPAREN) | (1 << JavaParser.LBRACE))) != 0) or ((((_la - 65)) & ~0x3f) == 0 and ((1 << (_la - 65)) & ((1 << (JavaParser.SEMI - 65)) | (1 << (JavaParser.LT - 65)) | (1 << (JavaParser.BANG - 65)) | (1 << (JavaParser.TILDE - 65)) | (1 << (JavaParser.INC - 65)) | (1 << (JavaParser.DEC - 65)) | (1 << (JavaParser.ADD - 65)) | (1 << (JavaParser.SUB - 65)) | (1 << (JavaParser.Identifier - 65)) | (1 << (JavaParser.AT - 65)))) != 0)):
                    break

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class SwitchLabelContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def CASE(self):
            return self.getToken(JavaParser.CASE, 0)

        def constantExpression(self):
            return self.getTypedRuleContext(JavaParser.ConstantExpressionContext,0)


        def COLON(self):
            return self.getToken(JavaParser.COLON, 0)

        def enumConstantName(self):
            return self.getTypedRuleContext(JavaParser.EnumConstantNameContext,0)


        def DEFAULT(self):
            return self.getToken(JavaParser.DEFAULT, 0)

        def getRuleIndex(self):
            return JavaParser.RULE_switchLabel

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSwitchLabel" ):
                listener.enterSwitchLabel(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSwitchLabel" ):
                listener.exitSwitchLabel(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSwitchLabel" ):
                return visitor.visitSwitchLabel(self)
            else:
                return visitor.visitChildren(self)




    def switchLabel(self):

        localctx = JavaParser.SwitchLabelContext(self, self._ctx, self.state)
        self.enterRule(localctx, 158, self.RULE_switchLabel)
        try:
            self.state = 1026
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,119,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 1016
                self.match(JavaParser.CASE)
                self.state = 1017
                self.constantExpression()
                self.state = 1018
                self.match(JavaParser.COLON)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 1020
                self.match(JavaParser.CASE)
                self.state = 1021
                self.enumConstantName()
                self.state = 1022
                self.match(JavaParser.COLON)
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 1024
                self.match(JavaParser.DEFAULT)
                self.state = 1025
                self.match(JavaParser.COLON)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ForControlContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def enhancedForControl(self):
            return self.getTypedRuleContext(JavaParser.EnhancedForControlContext,0)


        def SEMI(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.SEMI)
            else:
                return self.getToken(JavaParser.SEMI, i)

        def forInit(self):
            return self.getTypedRuleContext(JavaParser.ForInitContext,0)


        def expression(self):
            return self.getTypedRuleContext(JavaParser.ExpressionContext,0)


        def forUpdate(self):
            return self.getTypedRuleContext(JavaParser.ForUpdateContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_forControl

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterForControl" ):
                listener.enterForControl(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitForControl" ):
                listener.exitForControl(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitForControl" ):
                return visitor.visitForControl(self)
            else:
                return visitor.visitChildren(self)




    def forControl(self):

        localctx = JavaParser.ForControlContext(self, self._ctx, self.state)
        self.enterRule(localctx, 160, self.RULE_forControl)
        self._la = 0 # Token type
        try:
            self.state = 1040
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,123,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 1028
                self.enhancedForControl()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 1030
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << JavaParser.BOOLEAN) | (1 << JavaParser.BYTE) | (1 << JavaParser.CHAR) | (1 << JavaParser.DOUBLE) | (1 << JavaParser.FINAL) | (1 << JavaParser.FLOAT) | (1 << JavaParser.INT) | (1 << JavaParser.LONG) | (1 << JavaParser.NEW) | (1 << JavaParser.SHORT) | (1 << JavaParser.SUPER) | (1 << JavaParser.THIS) | (1 << JavaParser.VOID) | (1 << JavaParser.IntegerLiteral) | (1 << JavaParser.FloatingPointLiteral) | (1 << JavaParser.BooleanLiteral) | (1 << JavaParser.CharacterLiteral) | (1 << JavaParser.StringLiteral) | (1 << JavaParser.NullLiteral) | (1 << JavaParser.LPAREN))) != 0) or ((((_la - 70)) & ~0x3f) == 0 and ((1 << (_la - 70)) & ((1 << (JavaParser.LT - 70)) | (1 << (JavaParser.BANG - 70)) | (1 << (JavaParser.TILDE - 70)) | (1 << (JavaParser.INC - 70)) | (1 << (JavaParser.DEC - 70)) | (1 << (JavaParser.ADD - 70)) | (1 << (JavaParser.SUB - 70)) | (1 << (JavaParser.Identifier - 70)) | (1 << (JavaParser.AT - 70)))) != 0):
                    self.state = 1029
                    self.forInit()


                self.state = 1032
                self.match(JavaParser.SEMI)
                self.state = 1034
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << JavaParser.BOOLEAN) | (1 << JavaParser.BYTE) | (1 << JavaParser.CHAR) | (1 << JavaParser.DOUBLE) | (1 << JavaParser.FLOAT) | (1 << JavaParser.INT) | (1 << JavaParser.LONG) | (1 << JavaParser.NEW) | (1 << JavaParser.SHORT) | (1 << JavaParser.SUPER) | (1 << JavaParser.THIS) | (1 << JavaParser.VOID) | (1 << JavaParser.IntegerLiteral) | (1 << JavaParser.FloatingPointLiteral) | (1 << JavaParser.BooleanLiteral) | (1 << JavaParser.CharacterLiteral) | (1 << JavaParser.StringLiteral) | (1 << JavaParser.NullLiteral) | (1 << JavaParser.LPAREN))) != 0) or ((((_la - 70)) & ~0x3f) == 0 and ((1 << (_la - 70)) & ((1 << (JavaParser.LT - 70)) | (1 << (JavaParser.BANG - 70)) | (1 << (JavaParser.TILDE - 70)) | (1 << (JavaParser.INC - 70)) | (1 << (JavaParser.DEC - 70)) | (1 << (JavaParser.ADD - 70)) | (1 << (JavaParser.SUB - 70)) | (1 << (JavaParser.Identifier - 70)))) != 0):
                    self.state = 1033
                    self.expression(0)


                self.state = 1036
                self.match(JavaParser.SEMI)
                self.state = 1038
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << JavaParser.BOOLEAN) | (1 << JavaParser.BYTE) | (1 << JavaParser.CHAR) | (1 << JavaParser.DOUBLE) | (1 << JavaParser.FLOAT) | (1 << JavaParser.INT) | (1 << JavaParser.LONG) | (1 << JavaParser.NEW) | (1 << JavaParser.SHORT) | (1 << JavaParser.SUPER) | (1 << JavaParser.THIS) | (1 << JavaParser.VOID) | (1 << JavaParser.IntegerLiteral) | (1 << JavaParser.FloatingPointLiteral) | (1 << JavaParser.BooleanLiteral) | (1 << JavaParser.CharacterLiteral) | (1 << JavaParser.StringLiteral) | (1 << JavaParser.NullLiteral) | (1 << JavaParser.LPAREN))) != 0) or ((((_la - 70)) & ~0x3f) == 0 and ((1 << (_la - 70)) & ((1 << (JavaParser.LT - 70)) | (1 << (JavaParser.BANG - 70)) | (1 << (JavaParser.TILDE - 70)) | (1 << (JavaParser.INC - 70)) | (1 << (JavaParser.DEC - 70)) | (1 << (JavaParser.ADD - 70)) | (1 << (JavaParser.SUB - 70)) | (1 << (JavaParser.Identifier - 70)))) != 0):
                    self.state = 1037
                    self.forUpdate()


                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ForInitContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def localVariableDeclaration(self):
            return self.getTypedRuleContext(JavaParser.LocalVariableDeclarationContext,0)


        def expressionList(self):
            return self.getTypedRuleContext(JavaParser.ExpressionListContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_forInit

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterForInit" ):
                listener.enterForInit(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitForInit" ):
                listener.exitForInit(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitForInit" ):
                return visitor.visitForInit(self)
            else:
                return visitor.visitChildren(self)




    def forInit(self):

        localctx = JavaParser.ForInitContext(self, self._ctx, self.state)
        self.enterRule(localctx, 162, self.RULE_forInit)
        try:
            self.state = 1044
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,124,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 1042
                self.localVariableDeclaration()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 1043
                self.expressionList()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class EnhancedForControlContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def jType(self):
            return self.getTypedRuleContext(JavaParser.JTypeContext,0)


        def variableDeclaratorId(self):
            return self.getTypedRuleContext(JavaParser.VariableDeclaratorIdContext,0)


        def COLON(self):
            return self.getToken(JavaParser.COLON, 0)

        def expression(self):
            return self.getTypedRuleContext(JavaParser.ExpressionContext,0)


        def variableModifier(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.VariableModifierContext)
            else:
                return self.getTypedRuleContext(JavaParser.VariableModifierContext,i)


        def getRuleIndex(self):
            return JavaParser.RULE_enhancedForControl

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterEnhancedForControl" ):
                listener.enterEnhancedForControl(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitEnhancedForControl" ):
                listener.exitEnhancedForControl(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitEnhancedForControl" ):
                return visitor.visitEnhancedForControl(self)
            else:
                return visitor.visitChildren(self)




    def enhancedForControl(self):

        localctx = JavaParser.EnhancedForControlContext(self, self._ctx, self.state)
        self.enterRule(localctx, 164, self.RULE_enhancedForControl)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1049
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==JavaParser.FINAL or _la==JavaParser.AT:
                self.state = 1046
                self.variableModifier()
                self.state = 1051
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 1052
            self.jType()
            self.state = 1053
            self.variableDeclaratorId()
            self.state = 1054
            self.match(JavaParser.COLON)
            self.state = 1055
            self.expression(0)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ForUpdateContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def expressionList(self):
            return self.getTypedRuleContext(JavaParser.ExpressionListContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_forUpdate

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterForUpdate" ):
                listener.enterForUpdate(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitForUpdate" ):
                listener.exitForUpdate(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitForUpdate" ):
                return visitor.visitForUpdate(self)
            else:
                return visitor.visitChildren(self)




    def forUpdate(self):

        localctx = JavaParser.ForUpdateContext(self, self._ctx, self.state)
        self.enterRule(localctx, 166, self.RULE_forUpdate)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1057
            self.expressionList()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ParExpressionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LPAREN(self):
            return self.getToken(JavaParser.LPAREN, 0)

        def expression(self):
            return self.getTypedRuleContext(JavaParser.ExpressionContext,0)


        def RPAREN(self):
            return self.getToken(JavaParser.RPAREN, 0)

        def getRuleIndex(self):
            return JavaParser.RULE_parExpression

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterParExpression" ):
                listener.enterParExpression(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitParExpression" ):
                listener.exitParExpression(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitParExpression" ):
                return visitor.visitParExpression(self)
            else:
                return visitor.visitChildren(self)




    def parExpression(self):

        localctx = JavaParser.ParExpressionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 168, self.RULE_parExpression)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1059
            self.match(JavaParser.LPAREN)
            self.state = 1060
            self.expression(0)
            self.state = 1061
            self.match(JavaParser.RPAREN)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ExpressionListContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def expression(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.ExpressionContext)
            else:
                return self.getTypedRuleContext(JavaParser.ExpressionContext,i)


        def COMMA(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.COMMA)
            else:
                return self.getToken(JavaParser.COMMA, i)

        def getRuleIndex(self):
            return JavaParser.RULE_expressionList

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterExpressionList" ):
                listener.enterExpressionList(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitExpressionList" ):
                listener.exitExpressionList(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitExpressionList" ):
                return visitor.visitExpressionList(self)
            else:
                return visitor.visitChildren(self)




    def expressionList(self):

        localctx = JavaParser.ExpressionListContext(self, self._ctx, self.state)
        self.enterRule(localctx, 170, self.RULE_expressionList)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1063
            self.expression(0)
            self.state = 1068
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==JavaParser.COMMA:
                self.state = 1064
                self.match(JavaParser.COMMA)
                self.state = 1065
                self.expression(0)
                self.state = 1070
                self._errHandler.sync(self)
                _la = self._input.LA(1)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class StatementExpressionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def expression(self):
            return self.getTypedRuleContext(JavaParser.ExpressionContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_statementExpression

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterStatementExpression" ):
                listener.enterStatementExpression(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitStatementExpression" ):
                listener.exitStatementExpression(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitStatementExpression" ):
                return visitor.visitStatementExpression(self)
            else:
                return visitor.visitChildren(self)




    def statementExpression(self):

        localctx = JavaParser.StatementExpressionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 172, self.RULE_statementExpression)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1071
            self.expression(0)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ConstantExpressionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def expression(self):
            return self.getTypedRuleContext(JavaParser.ExpressionContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_constantExpression

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterConstantExpression" ):
                listener.enterConstantExpression(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitConstantExpression" ):
                listener.exitConstantExpression(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitConstantExpression" ):
                return visitor.visitConstantExpression(self)
            else:
                return visitor.visitChildren(self)




    def constantExpression(self):

        localctx = JavaParser.ConstantExpressionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 174, self.RULE_constantExpression)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1073
            self.expression(0)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class LambdaExpressionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def lambdaParameters(self):
            return self.getTypedRuleContext(JavaParser.LambdaParametersContext,0)


        def lambdaBody(self):
            return self.getTypedRuleContext(JavaParser.LambdaBodyContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_lambdaExpression

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterLambdaExpression" ):
                listener.enterLambdaExpression(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitLambdaExpression" ):
                listener.exitLambdaExpression(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitLambdaExpression" ):
                return visitor.visitLambdaExpression(self)
            else:
                return visitor.visitChildren(self)




    def lambdaExpression(self):

        localctx = JavaParser.LambdaExpressionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 176, self.RULE_lambdaExpression)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1075
            self.lambdaParameters()
            self.state = 1076
            self.match(JavaParser.T__0)
            self.state = 1077
            self.lambdaBody()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class LambdaParametersContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Identifier(self):
            return self.getToken(JavaParser.Identifier, 0)

        def LPAREN(self):
            return self.getToken(JavaParser.LPAREN, 0)

        def RPAREN(self):
            return self.getToken(JavaParser.RPAREN, 0)

        def formalParameterList(self):
            return self.getTypedRuleContext(JavaParser.FormalParameterListContext,0)


        def inferredFormalParameterList(self):
            return self.getTypedRuleContext(JavaParser.InferredFormalParameterListContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_lambdaParameters

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterLambdaParameters" ):
                listener.enterLambdaParameters(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitLambdaParameters" ):
                listener.exitLambdaParameters(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitLambdaParameters" ):
                return visitor.visitLambdaParameters(self)
            else:
                return visitor.visitChildren(self)




    def lambdaParameters(self):

        localctx = JavaParser.LambdaParametersContext(self, self._ctx, self.state)
        self.enterRule(localctx, 178, self.RULE_lambdaParameters)
        self._la = 0 # Token type
        try:
            self.state = 1089
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,128,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 1079
                self.match(JavaParser.Identifier)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 1080
                self.match(JavaParser.LPAREN)
                self.state = 1082
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << JavaParser.BOOLEAN) | (1 << JavaParser.BYTE) | (1 << JavaParser.CHAR) | (1 << JavaParser.DOUBLE) | (1 << JavaParser.FINAL) | (1 << JavaParser.FLOAT) | (1 << JavaParser.INT) | (1 << JavaParser.LONG) | (1 << JavaParser.SHORT))) != 0) or _la==JavaParser.Identifier or _la==JavaParser.AT:
                    self.state = 1081
                    self.formalParameterList()


                self.state = 1084
                self.match(JavaParser.RPAREN)
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 1085
                self.match(JavaParser.LPAREN)
                self.state = 1086
                self.inferredFormalParameterList()
                self.state = 1087
                self.match(JavaParser.RPAREN)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class InferredFormalParameterListContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Identifier(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.Identifier)
            else:
                return self.getToken(JavaParser.Identifier, i)

        def COMMA(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.COMMA)
            else:
                return self.getToken(JavaParser.COMMA, i)

        def getRuleIndex(self):
            return JavaParser.RULE_inferredFormalParameterList

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterInferredFormalParameterList" ):
                listener.enterInferredFormalParameterList(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitInferredFormalParameterList" ):
                listener.exitInferredFormalParameterList(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitInferredFormalParameterList" ):
                return visitor.visitInferredFormalParameterList(self)
            else:
                return visitor.visitChildren(self)




    def inferredFormalParameterList(self):

        localctx = JavaParser.InferredFormalParameterListContext(self, self._ctx, self.state)
        self.enterRule(localctx, 180, self.RULE_inferredFormalParameterList)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1091
            self.match(JavaParser.Identifier)
            self.state = 1096
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==JavaParser.COMMA:
                self.state = 1092
                self.match(JavaParser.COMMA)
                self.state = 1093
                self.match(JavaParser.Identifier)
                self.state = 1098
                self._errHandler.sync(self)
                _la = self._input.LA(1)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class LambdaBodyContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def expression(self):
            return self.getTypedRuleContext(JavaParser.ExpressionContext,0)


        def block(self):
            return self.getTypedRuleContext(JavaParser.BlockContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_lambdaBody

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterLambdaBody" ):
                listener.enterLambdaBody(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitLambdaBody" ):
                listener.exitLambdaBody(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitLambdaBody" ):
                return visitor.visitLambdaBody(self)
            else:
                return visitor.visitChildren(self)




    def lambdaBody(self):

        localctx = JavaParser.LambdaBodyContext(self, self._ctx, self.state)
        self.enterRule(localctx, 182, self.RULE_lambdaBody)
        try:
            self.state = 1101
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [JavaParser.BOOLEAN, JavaParser.BYTE, JavaParser.CHAR, JavaParser.DOUBLE, JavaParser.FLOAT, JavaParser.INT, JavaParser.LONG, JavaParser.NEW, JavaParser.SHORT, JavaParser.SUPER, JavaParser.THIS, JavaParser.VOID, JavaParser.IntegerLiteral, JavaParser.FloatingPointLiteral, JavaParser.BooleanLiteral, JavaParser.CharacterLiteral, JavaParser.StringLiteral, JavaParser.NullLiteral, JavaParser.LPAREN, JavaParser.LT, JavaParser.BANG, JavaParser.TILDE, JavaParser.INC, JavaParser.DEC, JavaParser.ADD, JavaParser.SUB, JavaParser.Identifier]:
                self.enterOuterAlt(localctx, 1)
                self.state = 1099
                self.expression(0)
                pass
            elif token in [JavaParser.LBRACE]:
                self.enterOuterAlt(localctx, 2)
                self.state = 1100
                self.block()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ExpressionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def primary(self):
            return self.getTypedRuleContext(JavaParser.PrimaryContext,0)


        def NEW(self):
            return self.getToken(JavaParser.NEW, 0)

        def creator(self):
            return self.getTypedRuleContext(JavaParser.CreatorContext,0)


        def LPAREN(self):
            return self.getToken(JavaParser.LPAREN, 0)

        def jType(self):
            return self.getTypedRuleContext(JavaParser.JTypeContext,0)


        def RPAREN(self):
            return self.getToken(JavaParser.RPAREN, 0)

        def expression(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.ExpressionContext)
            else:
                return self.getTypedRuleContext(JavaParser.ExpressionContext,i)


        def ADD(self):
            return self.getToken(JavaParser.ADD, 0)

        def SUB(self):
            return self.getToken(JavaParser.SUB, 0)

        def INC(self):
            return self.getToken(JavaParser.INC, 0)

        def DEC(self):
            return self.getToken(JavaParser.DEC, 0)

        def TILDE(self):
            return self.getToken(JavaParser.TILDE, 0)

        def BANG(self):
            return self.getToken(JavaParser.BANG, 0)

        def lambdaExpression(self):
            return self.getTypedRuleContext(JavaParser.LambdaExpressionContext,0)


        def MUL(self):
            return self.getToken(JavaParser.MUL, 0)

        def DIV(self):
            return self.getToken(JavaParser.DIV, 0)

        def MOD(self):
            return self.getToken(JavaParser.MOD, 0)

        def LT(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.LT)
            else:
                return self.getToken(JavaParser.LT, i)

        def GT(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.GT)
            else:
                return self.getToken(JavaParser.GT, i)

        def LE(self):
            return self.getToken(JavaParser.LE, 0)

        def GE(self):
            return self.getToken(JavaParser.GE, 0)

        def EQUAL(self):
            return self.getToken(JavaParser.EQUAL, 0)

        def NOTEQUAL(self):
            return self.getToken(JavaParser.NOTEQUAL, 0)

        def BITAND(self):
            return self.getToken(JavaParser.BITAND, 0)

        def CARET(self):
            return self.getToken(JavaParser.CARET, 0)

        def BITOR(self):
            return self.getToken(JavaParser.BITOR, 0)

        def AND(self):
            return self.getToken(JavaParser.AND, 0)

        def OR(self):
            return self.getToken(JavaParser.OR, 0)

        def QUESTION(self):
            return self.getToken(JavaParser.QUESTION, 0)

        def COLON(self):
            return self.getToken(JavaParser.COLON, 0)

        def ASSIGN(self):
            return self.getToken(JavaParser.ASSIGN, 0)

        def ADD_ASSIGN(self):
            return self.getToken(JavaParser.ADD_ASSIGN, 0)

        def SUB_ASSIGN(self):
            return self.getToken(JavaParser.SUB_ASSIGN, 0)

        def MUL_ASSIGN(self):
            return self.getToken(JavaParser.MUL_ASSIGN, 0)

        def DIV_ASSIGN(self):
            return self.getToken(JavaParser.DIV_ASSIGN, 0)

        def AND_ASSIGN(self):
            return self.getToken(JavaParser.AND_ASSIGN, 0)

        def OR_ASSIGN(self):
            return self.getToken(JavaParser.OR_ASSIGN, 0)

        def XOR_ASSIGN(self):
            return self.getToken(JavaParser.XOR_ASSIGN, 0)

        def RSHIFT_ASSIGN(self):
            return self.getToken(JavaParser.RSHIFT_ASSIGN, 0)

        def URSHIFT_ASSIGN(self):
            return self.getToken(JavaParser.URSHIFT_ASSIGN, 0)

        def LSHIFT_ASSIGN(self):
            return self.getToken(JavaParser.LSHIFT_ASSIGN, 0)

        def MOD_ASSIGN(self):
            return self.getToken(JavaParser.MOD_ASSIGN, 0)

        def DOT(self):
            return self.getToken(JavaParser.DOT, 0)

        def Identifier(self):
            return self.getToken(JavaParser.Identifier, 0)

        def THIS(self):
            return self.getToken(JavaParser.THIS, 0)

        def innerCreator(self):
            return self.getTypedRuleContext(JavaParser.InnerCreatorContext,0)


        def nonWildcardTypeArguments(self):
            return self.getTypedRuleContext(JavaParser.NonWildcardTypeArgumentsContext,0)


        def SUPER(self):
            return self.getToken(JavaParser.SUPER, 0)

        def superSuffix(self):
            return self.getTypedRuleContext(JavaParser.SuperSuffixContext,0)


        def explicitGenericInvocation(self):
            return self.getTypedRuleContext(JavaParser.ExplicitGenericInvocationContext,0)


        def LBRACK(self):
            return self.getToken(JavaParser.LBRACK, 0)

        def RBRACK(self):
            return self.getToken(JavaParser.RBRACK, 0)

        def expressionList(self):
            return self.getTypedRuleContext(JavaParser.ExpressionListContext,0)


        def INSTANCEOF(self):
            return self.getToken(JavaParser.INSTANCEOF, 0)

        def typeArguments(self):
            return self.getTypedRuleContext(JavaParser.TypeArgumentsContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_expression

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterExpression" ):
                listener.enterExpression(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitExpression" ):
                listener.exitExpression(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitExpression" ):
                return visitor.visitExpression(self)
            else:
                return visitor.visitChildren(self)



    def expression(self, _p:int=0):
        _parentctx = self._ctx
        _parentState = self.state
        localctx = JavaParser.ExpressionContext(self, self._ctx, _parentState)
        _prevctx = localctx
        _startState = 184
        self.enterRecursionRule(localctx, 184, self.RULE_expression, _p)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1117
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,131,self._ctx)
            if la_ == 1:
                self.state = 1104
                self.primary()
                pass

            elif la_ == 2:
                self.state = 1105
                self.match(JavaParser.NEW)
                self.state = 1106
                self.creator()
                pass

            elif la_ == 3:
                self.state = 1107
                self.match(JavaParser.LPAREN)
                self.state = 1108
                self.jType()
                self.state = 1109
                self.match(JavaParser.RPAREN)
                self.state = 1110
                self.expression(21)
                pass

            elif la_ == 4:
                self.state = 1112
                _la = self._input.LA(1)
                if not(((((_la - 81)) & ~0x3f) == 0 and ((1 << (_la - 81)) & ((1 << (JavaParser.INC - 81)) | (1 << (JavaParser.DEC - 81)) | (1 << (JavaParser.ADD - 81)) | (1 << (JavaParser.SUB - 81)))) != 0)):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                self.state = 1113
                self.expression(19)
                pass

            elif la_ == 5:
                self.state = 1114
                _la = self._input.LA(1)
                if not(_la==JavaParser.BANG or _la==JavaParser.TILDE):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                self.state = 1115
                self.expression(18)
                pass

            elif la_ == 6:
                self.state = 1116
                self.lambdaExpression()
                pass


            self._ctx.stop = self._input.LT(-1)
            self.state = 1224
            self._errHandler.sync(self)
            _alt = self._interp.adaptivePredict(self._input,139,self._ctx)
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt==1:
                    if self._parseListeners is not None:
                        self.triggerExitRuleEvent()
                    _prevctx = localctx
                    self.state = 1222
                    self._errHandler.sync(self)
                    la_ = self._interp.adaptivePredict(self._input,138,self._ctx)
                    if la_ == 1:
                        localctx = JavaParser.ExpressionContext(self, _parentctx, _parentState)
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 1119
                        if not self.precpred(self._ctx, 17):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 17)")
                        self.state = 1120
                        _la = self._input.LA(1)
                        if not(((((_la - 85)) & ~0x3f) == 0 and ((1 << (_la - 85)) & ((1 << (JavaParser.MUL - 85)) | (1 << (JavaParser.DIV - 85)) | (1 << (JavaParser.MOD - 85)))) != 0)):
                            self._errHandler.recoverInline(self)
                        else:
                            self._errHandler.reportMatch(self)
                            self.consume()
                        self.state = 1121
                        self.expression(18)
                        pass

                    elif la_ == 2:
                        localctx = JavaParser.ExpressionContext(self, _parentctx, _parentState)
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 1122
                        if not self.precpred(self._ctx, 16):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 16)")
                        self.state = 1123
                        _la = self._input.LA(1)
                        if not(_la==JavaParser.ADD or _la==JavaParser.SUB):
                            self._errHandler.recoverInline(self)
                        else:
                            self._errHandler.reportMatch(self)
                            self.consume()
                        self.state = 1124
                        self.expression(17)
                        pass

                    elif la_ == 3:
                        localctx = JavaParser.ExpressionContext(self, _parentctx, _parentState)
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 1125
                        if not self.precpred(self._ctx, 15):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 15)")
                        self.state = 1133
                        self._errHandler.sync(self)
                        la_ = self._interp.adaptivePredict(self._input,132,self._ctx)
                        if la_ == 1:
                            self.state = 1126
                            self.match(JavaParser.LT)
                            self.state = 1127
                            self.match(JavaParser.LT)
                            pass

                        elif la_ == 2:
                            self.state = 1128
                            self.match(JavaParser.GT)
                            self.state = 1129
                            self.match(JavaParser.GT)
                            self.state = 1130
                            self.match(JavaParser.GT)
                            pass

                        elif la_ == 3:
                            self.state = 1131
                            self.match(JavaParser.GT)
                            self.state = 1132
                            self.match(JavaParser.GT)
                            pass


                        self.state = 1135
                        self.expression(16)
                        pass

                    elif la_ == 4:
                        localctx = JavaParser.ExpressionContext(self, _parentctx, _parentState)
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 1136
                        if not self.precpred(self._ctx, 14):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 14)")
                        self.state = 1137
                        _la = self._input.LA(1)
                        if not(((((_la - 69)) & ~0x3f) == 0 and ((1 << (_la - 69)) & ((1 << (JavaParser.GT - 69)) | (1 << (JavaParser.LT - 69)) | (1 << (JavaParser.LE - 69)) | (1 << (JavaParser.GE - 69)))) != 0)):
                            self._errHandler.recoverInline(self)
                        else:
                            self._errHandler.reportMatch(self)
                            self.consume()
                        self.state = 1138
                        self.expression(15)
                        pass

                    elif la_ == 5:
                        localctx = JavaParser.ExpressionContext(self, _parentctx, _parentState)
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 1139
                        if not self.precpred(self._ctx, 12):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 12)")
                        self.state = 1140
                        _la = self._input.LA(1)
                        if not(_la==JavaParser.EQUAL or _la==JavaParser.NOTEQUAL):
                            self._errHandler.recoverInline(self)
                        else:
                            self._errHandler.reportMatch(self)
                            self.consume()
                        self.state = 1141
                        self.expression(13)
                        pass

                    elif la_ == 6:
                        localctx = JavaParser.ExpressionContext(self, _parentctx, _parentState)
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 1142
                        if not self.precpred(self._ctx, 11):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 11)")
                        self.state = 1143
                        self.match(JavaParser.BITAND)
                        self.state = 1144
                        self.expression(12)
                        pass

                    elif la_ == 7:
                        localctx = JavaParser.ExpressionContext(self, _parentctx, _parentState)
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 1145
                        if not self.precpred(self._ctx, 10):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 10)")
                        self.state = 1146
                        self.match(JavaParser.CARET)
                        self.state = 1147
                        self.expression(11)
                        pass

                    elif la_ == 8:
                        localctx = JavaParser.ExpressionContext(self, _parentctx, _parentState)
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 1148
                        if not self.precpred(self._ctx, 9):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 9)")
                        self.state = 1149
                        self.match(JavaParser.BITOR)
                        self.state = 1150
                        self.expression(10)
                        pass

                    elif la_ == 9:
                        localctx = JavaParser.ExpressionContext(self, _parentctx, _parentState)
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 1151
                        if not self.precpred(self._ctx, 8):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 8)")
                        self.state = 1152
                        self.match(JavaParser.AND)
                        self.state = 1153
                        self.expression(9)
                        pass

                    elif la_ == 10:
                        localctx = JavaParser.ExpressionContext(self, _parentctx, _parentState)
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 1154
                        if not self.precpred(self._ctx, 7):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 7)")
                        self.state = 1155
                        self.match(JavaParser.OR)
                        self.state = 1156
                        self.expression(8)
                        pass

                    elif la_ == 11:
                        localctx = JavaParser.ExpressionContext(self, _parentctx, _parentState)
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 1157
                        if not self.precpred(self._ctx, 6):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 6)")
                        self.state = 1158
                        self.match(JavaParser.QUESTION)
                        self.state = 1159
                        self.expression(0)
                        self.state = 1160
                        self.match(JavaParser.COLON)
                        self.state = 1161
                        self.expression(7)
                        pass

                    elif la_ == 12:
                        localctx = JavaParser.ExpressionContext(self, _parentctx, _parentState)
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 1163
                        if not self.precpred(self._ctx, 1):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 1)")
                        self.state = 1164
                        _la = self._input.LA(1)
                        if not(((((_la - 68)) & ~0x3f) == 0 and ((1 << (_la - 68)) & ((1 << (JavaParser.ASSIGN - 68)) | (1 << (JavaParser.ADD_ASSIGN - 68)) | (1 << (JavaParser.SUB_ASSIGN - 68)) | (1 << (JavaParser.MUL_ASSIGN - 68)) | (1 << (JavaParser.DIV_ASSIGN - 68)) | (1 << (JavaParser.AND_ASSIGN - 68)) | (1 << (JavaParser.OR_ASSIGN - 68)) | (1 << (JavaParser.XOR_ASSIGN - 68)) | (1 << (JavaParser.MOD_ASSIGN - 68)) | (1 << (JavaParser.LSHIFT_ASSIGN - 68)) | (1 << (JavaParser.RSHIFT_ASSIGN - 68)) | (1 << (JavaParser.URSHIFT_ASSIGN - 68)))) != 0)):
                            self._errHandler.recoverInline(self)
                        else:
                            self._errHandler.reportMatch(self)
                            self.consume()
                        self.state = 1165
                        self.expression(1)
                        pass

                    elif la_ == 13:
                        localctx = JavaParser.ExpressionContext(self, _parentctx, _parentState)
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 1166
                        if not self.precpred(self._ctx, 29):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 29)")
                        self.state = 1167
                        self.match(JavaParser.DOT)
                        self.state = 1168
                        self.match(JavaParser.Identifier)
                        pass

                    elif la_ == 14:
                        localctx = JavaParser.ExpressionContext(self, _parentctx, _parentState)
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 1169
                        if not self.precpred(self._ctx, 28):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 28)")
                        self.state = 1170
                        self.match(JavaParser.DOT)
                        self.state = 1171
                        self.match(JavaParser.THIS)
                        pass

                    elif la_ == 15:
                        localctx = JavaParser.ExpressionContext(self, _parentctx, _parentState)
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 1172
                        if not self.precpred(self._ctx, 27):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 27)")
                        self.state = 1173
                        self.match(JavaParser.DOT)
                        self.state = 1174
                        self.match(JavaParser.NEW)
                        self.state = 1176
                        self._errHandler.sync(self)
                        _la = self._input.LA(1)
                        if _la==JavaParser.LT:
                            self.state = 1175
                            self.nonWildcardTypeArguments()


                        self.state = 1178
                        self.innerCreator()
                        pass

                    elif la_ == 16:
                        localctx = JavaParser.ExpressionContext(self, _parentctx, _parentState)
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 1179
                        if not self.precpred(self._ctx, 26):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 26)")
                        self.state = 1180
                        self.match(JavaParser.DOT)
                        self.state = 1181
                        self.match(JavaParser.SUPER)
                        self.state = 1182
                        self.superSuffix()
                        pass

                    elif la_ == 17:
                        localctx = JavaParser.ExpressionContext(self, _parentctx, _parentState)
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 1183
                        if not self.precpred(self._ctx, 25):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 25)")
                        self.state = 1184
                        self.match(JavaParser.DOT)
                        self.state = 1185
                        self.explicitGenericInvocation()
                        pass

                    elif la_ == 18:
                        localctx = JavaParser.ExpressionContext(self, _parentctx, _parentState)
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 1186
                        if not self.precpred(self._ctx, 24):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 24)")
                        self.state = 1187
                        self.match(JavaParser.LBRACK)
                        self.state = 1188
                        self.expression(0)
                        self.state = 1189
                        self.match(JavaParser.RBRACK)
                        pass

                    elif la_ == 19:
                        localctx = JavaParser.ExpressionContext(self, _parentctx, _parentState)
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 1191
                        if not self.precpred(self._ctx, 23):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 23)")
                        self.state = 1192
                        self.match(JavaParser.LPAREN)
                        self.state = 1194
                        self._errHandler.sync(self)
                        _la = self._input.LA(1)
                        if (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << JavaParser.BOOLEAN) | (1 << JavaParser.BYTE) | (1 << JavaParser.CHAR) | (1 << JavaParser.DOUBLE) | (1 << JavaParser.FLOAT) | (1 << JavaParser.INT) | (1 << JavaParser.LONG) | (1 << JavaParser.NEW) | (1 << JavaParser.SHORT) | (1 << JavaParser.SUPER) | (1 << JavaParser.THIS) | (1 << JavaParser.VOID) | (1 << JavaParser.IntegerLiteral) | (1 << JavaParser.FloatingPointLiteral) | (1 << JavaParser.BooleanLiteral) | (1 << JavaParser.CharacterLiteral) | (1 << JavaParser.StringLiteral) | (1 << JavaParser.NullLiteral) | (1 << JavaParser.LPAREN))) != 0) or ((((_la - 70)) & ~0x3f) == 0 and ((1 << (_la - 70)) & ((1 << (JavaParser.LT - 70)) | (1 << (JavaParser.BANG - 70)) | (1 << (JavaParser.TILDE - 70)) | (1 << (JavaParser.INC - 70)) | (1 << (JavaParser.DEC - 70)) | (1 << (JavaParser.ADD - 70)) | (1 << (JavaParser.SUB - 70)) | (1 << (JavaParser.Identifier - 70)))) != 0):
                            self.state = 1193
                            self.expressionList()


                        self.state = 1196
                        self.match(JavaParser.RPAREN)
                        pass

                    elif la_ == 20:
                        localctx = JavaParser.ExpressionContext(self, _parentctx, _parentState)
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 1197
                        if not self.precpred(self._ctx, 20):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 20)")
                        self.state = 1198
                        _la = self._input.LA(1)
                        if not(_la==JavaParser.INC or _la==JavaParser.DEC):
                            self._errHandler.recoverInline(self)
                        else:
                            self._errHandler.reportMatch(self)
                            self.consume()
                        pass

                    elif la_ == 21:
                        localctx = JavaParser.ExpressionContext(self, _parentctx, _parentState)
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 1199
                        if not self.precpred(self._ctx, 13):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 13)")
                        self.state = 1200
                        self.match(JavaParser.INSTANCEOF)
                        self.state = 1201
                        self.jType()
                        pass

                    elif la_ == 22:
                        localctx = JavaParser.ExpressionContext(self, _parentctx, _parentState)
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 1202
                        if not self.precpred(self._ctx, 4):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 4)")
                        self.state = 1203
                        self.match(JavaParser.T__1)
                        self.state = 1205
                        self._errHandler.sync(self)
                        _la = self._input.LA(1)
                        if _la==JavaParser.LT:
                            self.state = 1204
                            self.typeArguments()


                        self.state = 1207
                        self.match(JavaParser.Identifier)
                        pass

                    elif la_ == 23:
                        localctx = JavaParser.ExpressionContext(self, _parentctx, _parentState)
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 1208
                        if not self.precpred(self._ctx, 3):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 3)")
                        self.state = 1209
                        self.match(JavaParser.T__1)
                        self.state = 1211
                        self._errHandler.sync(self)
                        _la = self._input.LA(1)
                        if _la==JavaParser.LT:
                            self.state = 1210
                            self.typeArguments()


                        self.state = 1213
                        self.match(JavaParser.NEW)
                        pass

                    elif la_ == 24:
                        localctx = JavaParser.ExpressionContext(self, _parentctx, _parentState)
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 1214
                        if not self.precpred(self._ctx, 2):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 2)")
                        self.state = 1215
                        self.match(JavaParser.LBRACK)
                        self.state = 1216
                        self.match(JavaParser.RBRACK)
                        self.state = 1217
                        self.match(JavaParser.T__1)
                        self.state = 1219
                        self._errHandler.sync(self)
                        _la = self._input.LA(1)
                        if _la==JavaParser.LT:
                            self.state = 1218
                            self.typeArguments()


                        self.state = 1221
                        self.match(JavaParser.NEW)
                        pass

             
                self.state = 1226
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,139,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.unrollRecursionContexts(_parentctx)
        return localctx


    class PrimaryContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LPAREN(self):
            return self.getToken(JavaParser.LPAREN, 0)

        def expression(self):
            return self.getTypedRuleContext(JavaParser.ExpressionContext,0)


        def RPAREN(self):
            return self.getToken(JavaParser.RPAREN, 0)

        def THIS(self):
            return self.getToken(JavaParser.THIS, 0)

        def SUPER(self):
            return self.getToken(JavaParser.SUPER, 0)

        def literal(self):
            return self.getTypedRuleContext(JavaParser.LiteralContext,0)


        def Identifier(self):
            return self.getToken(JavaParser.Identifier, 0)

        def jType(self):
            return self.getTypedRuleContext(JavaParser.JTypeContext,0)


        def DOT(self):
            return self.getToken(JavaParser.DOT, 0)

        def CLASS(self):
            return self.getToken(JavaParser.CLASS, 0)

        def VOID(self):
            return self.getToken(JavaParser.VOID, 0)

        def nonWildcardTypeArguments(self):
            return self.getTypedRuleContext(JavaParser.NonWildcardTypeArgumentsContext,0)


        def explicitGenericInvocationSuffix(self):
            return self.getTypedRuleContext(JavaParser.ExplicitGenericInvocationSuffixContext,0)


        def arguments(self):
            return self.getTypedRuleContext(JavaParser.ArgumentsContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_primary

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPrimary" ):
                listener.enterPrimary(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPrimary" ):
                listener.exitPrimary(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitPrimary" ):
                return visitor.visitPrimary(self)
            else:
                return visitor.visitChildren(self)




    def primary(self):

        localctx = JavaParser.PrimaryContext(self, self._ctx, self.state)
        self.enterRule(localctx, 186, self.RULE_primary)
        try:
            self.state = 1248
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,141,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 1227
                self.match(JavaParser.LPAREN)
                self.state = 1228
                self.expression(0)
                self.state = 1229
                self.match(JavaParser.RPAREN)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 1231
                self.match(JavaParser.THIS)
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 1232
                self.match(JavaParser.SUPER)
                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 1233
                self.literal()
                pass

            elif la_ == 5:
                self.enterOuterAlt(localctx, 5)
                self.state = 1234
                self.match(JavaParser.Identifier)
                pass

            elif la_ == 6:
                self.enterOuterAlt(localctx, 6)
                self.state = 1235
                self.jType()
                self.state = 1236
                self.match(JavaParser.DOT)
                self.state = 1237
                self.match(JavaParser.CLASS)
                pass

            elif la_ == 7:
                self.enterOuterAlt(localctx, 7)
                self.state = 1239
                self.match(JavaParser.VOID)
                self.state = 1240
                self.match(JavaParser.DOT)
                self.state = 1241
                self.match(JavaParser.CLASS)
                pass

            elif la_ == 8:
                self.enterOuterAlt(localctx, 8)
                self.state = 1242
                self.nonWildcardTypeArguments()
                self.state = 1246
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [JavaParser.SUPER, JavaParser.Identifier]:
                    self.state = 1243
                    self.explicitGenericInvocationSuffix()
                    pass
                elif token in [JavaParser.THIS]:
                    self.state = 1244
                    self.match(JavaParser.THIS)
                    self.state = 1245
                    self.arguments()
                    pass
                else:
                    raise NoViableAltException(self)

                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class CreatorContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def nonWildcardTypeArguments(self):
            return self.getTypedRuleContext(JavaParser.NonWildcardTypeArgumentsContext,0)


        def createdName(self):
            return self.getTypedRuleContext(JavaParser.CreatedNameContext,0)


        def classCreatorRest(self):
            return self.getTypedRuleContext(JavaParser.ClassCreatorRestContext,0)


        def arrayCreatorRest(self):
            return self.getTypedRuleContext(JavaParser.ArrayCreatorRestContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_creator

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCreator" ):
                listener.enterCreator(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCreator" ):
                listener.exitCreator(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitCreator" ):
                return visitor.visitCreator(self)
            else:
                return visitor.visitChildren(self)




    def creator(self):

        localctx = JavaParser.CreatorContext(self, self._ctx, self.state)
        self.enterRule(localctx, 188, self.RULE_creator)
        try:
            self.state = 1259
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [JavaParser.LT]:
                self.enterOuterAlt(localctx, 1)
                self.state = 1250
                self.nonWildcardTypeArguments()
                self.state = 1251
                self.createdName()
                self.state = 1252
                self.classCreatorRest()
                pass
            elif token in [JavaParser.BOOLEAN, JavaParser.BYTE, JavaParser.CHAR, JavaParser.DOUBLE, JavaParser.FLOAT, JavaParser.INT, JavaParser.LONG, JavaParser.SHORT, JavaParser.Identifier]:
                self.enterOuterAlt(localctx, 2)
                self.state = 1254
                self.createdName()
                self.state = 1257
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [JavaParser.LBRACK]:
                    self.state = 1255
                    self.arrayCreatorRest()
                    pass
                elif token in [JavaParser.LPAREN]:
                    self.state = 1256
                    self.classCreatorRest()
                    pass
                else:
                    raise NoViableAltException(self)

                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class CreatedNameContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Identifier(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.Identifier)
            else:
                return self.getToken(JavaParser.Identifier, i)

        def typeArgumentsOrDiamond(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.TypeArgumentsOrDiamondContext)
            else:
                return self.getTypedRuleContext(JavaParser.TypeArgumentsOrDiamondContext,i)


        def DOT(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.DOT)
            else:
                return self.getToken(JavaParser.DOT, i)

        def primitiveType(self):
            return self.getTypedRuleContext(JavaParser.PrimitiveTypeContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_createdName

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCreatedName" ):
                listener.enterCreatedName(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCreatedName" ):
                listener.exitCreatedName(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitCreatedName" ):
                return visitor.visitCreatedName(self)
            else:
                return visitor.visitChildren(self)




    def createdName(self):

        localctx = JavaParser.CreatedNameContext(self, self._ctx, self.state)
        self.enterRule(localctx, 190, self.RULE_createdName)
        self._la = 0 # Token type
        try:
            self.state = 1276
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [JavaParser.Identifier]:
                self.enterOuterAlt(localctx, 1)
                self.state = 1261
                self.match(JavaParser.Identifier)
                self.state = 1263
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==JavaParser.LT:
                    self.state = 1262
                    self.typeArgumentsOrDiamond()


                self.state = 1272
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==JavaParser.DOT:
                    self.state = 1265
                    self.match(JavaParser.DOT)
                    self.state = 1266
                    self.match(JavaParser.Identifier)
                    self.state = 1268
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)
                    if _la==JavaParser.LT:
                        self.state = 1267
                        self.typeArgumentsOrDiamond()


                    self.state = 1274
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                pass
            elif token in [JavaParser.BOOLEAN, JavaParser.BYTE, JavaParser.CHAR, JavaParser.DOUBLE, JavaParser.FLOAT, JavaParser.INT, JavaParser.LONG, JavaParser.SHORT]:
                self.enterOuterAlt(localctx, 2)
                self.state = 1275
                self.primitiveType()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class InnerCreatorContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Identifier(self):
            return self.getToken(JavaParser.Identifier, 0)

        def classCreatorRest(self):
            return self.getTypedRuleContext(JavaParser.ClassCreatorRestContext,0)


        def nonWildcardTypeArgumentsOrDiamond(self):
            return self.getTypedRuleContext(JavaParser.NonWildcardTypeArgumentsOrDiamondContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_innerCreator

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterInnerCreator" ):
                listener.enterInnerCreator(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitInnerCreator" ):
                listener.exitInnerCreator(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitInnerCreator" ):
                return visitor.visitInnerCreator(self)
            else:
                return visitor.visitChildren(self)




    def innerCreator(self):

        localctx = JavaParser.InnerCreatorContext(self, self._ctx, self.state)
        self.enterRule(localctx, 192, self.RULE_innerCreator)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1278
            self.match(JavaParser.Identifier)
            self.state = 1280
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==JavaParser.LT:
                self.state = 1279
                self.nonWildcardTypeArgumentsOrDiamond()


            self.state = 1282
            self.classCreatorRest()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ArrayCreatorRestContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LBRACK(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.LBRACK)
            else:
                return self.getToken(JavaParser.LBRACK, i)

        def RBRACK(self, i:int=None):
            if i is None:
                return self.getTokens(JavaParser.RBRACK)
            else:
                return self.getToken(JavaParser.RBRACK, i)

        def arrayInitializer(self):
            return self.getTypedRuleContext(JavaParser.ArrayInitializerContext,0)


        def expression(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(JavaParser.ExpressionContext)
            else:
                return self.getTypedRuleContext(JavaParser.ExpressionContext,i)


        def getRuleIndex(self):
            return JavaParser.RULE_arrayCreatorRest

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterArrayCreatorRest" ):
                listener.enterArrayCreatorRest(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitArrayCreatorRest" ):
                listener.exitArrayCreatorRest(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitArrayCreatorRest" ):
                return visitor.visitArrayCreatorRest(self)
            else:
                return visitor.visitChildren(self)




    def arrayCreatorRest(self):

        localctx = JavaParser.ArrayCreatorRestContext(self, self._ctx, self.state)
        self.enterRule(localctx, 194, self.RULE_arrayCreatorRest)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1284
            self.match(JavaParser.LBRACK)
            self.state = 1312
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [JavaParser.RBRACK]:
                self.state = 1285
                self.match(JavaParser.RBRACK)
                self.state = 1290
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==JavaParser.LBRACK:
                    self.state = 1286
                    self.match(JavaParser.LBRACK)
                    self.state = 1287
                    self.match(JavaParser.RBRACK)
                    self.state = 1292
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                self.state = 1293
                self.arrayInitializer()
                pass
            elif token in [JavaParser.BOOLEAN, JavaParser.BYTE, JavaParser.CHAR, JavaParser.DOUBLE, JavaParser.FLOAT, JavaParser.INT, JavaParser.LONG, JavaParser.NEW, JavaParser.SHORT, JavaParser.SUPER, JavaParser.THIS, JavaParser.VOID, JavaParser.IntegerLiteral, JavaParser.FloatingPointLiteral, JavaParser.BooleanLiteral, JavaParser.CharacterLiteral, JavaParser.StringLiteral, JavaParser.NullLiteral, JavaParser.LPAREN, JavaParser.LT, JavaParser.BANG, JavaParser.TILDE, JavaParser.INC, JavaParser.DEC, JavaParser.ADD, JavaParser.SUB, JavaParser.Identifier]:
                self.state = 1294
                self.expression(0)
                self.state = 1295
                self.match(JavaParser.RBRACK)
                self.state = 1302
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,150,self._ctx)
                while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                    if _alt==1:
                        self.state = 1296
                        self.match(JavaParser.LBRACK)
                        self.state = 1297
                        self.expression(0)
                        self.state = 1298
                        self.match(JavaParser.RBRACK) 
                    self.state = 1304
                    self._errHandler.sync(self)
                    _alt = self._interp.adaptivePredict(self._input,150,self._ctx)

                self.state = 1309
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,151,self._ctx)
                while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                    if _alt==1:
                        self.state = 1305
                        self.match(JavaParser.LBRACK)
                        self.state = 1306
                        self.match(JavaParser.RBRACK) 
                    self.state = 1311
                    self._errHandler.sync(self)
                    _alt = self._interp.adaptivePredict(self._input,151,self._ctx)

                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ClassCreatorRestContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def arguments(self):
            return self.getTypedRuleContext(JavaParser.ArgumentsContext,0)


        def classBody(self):
            return self.getTypedRuleContext(JavaParser.ClassBodyContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_classCreatorRest

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterClassCreatorRest" ):
                listener.enterClassCreatorRest(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitClassCreatorRest" ):
                listener.exitClassCreatorRest(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitClassCreatorRest" ):
                return visitor.visitClassCreatorRest(self)
            else:
                return visitor.visitChildren(self)




    def classCreatorRest(self):

        localctx = JavaParser.ClassCreatorRestContext(self, self._ctx, self.state)
        self.enterRule(localctx, 196, self.RULE_classCreatorRest)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1314
            self.arguments()
            self.state = 1316
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,153,self._ctx)
            if la_ == 1:
                self.state = 1315
                self.classBody()


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ExplicitGenericInvocationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def nonWildcardTypeArguments(self):
            return self.getTypedRuleContext(JavaParser.NonWildcardTypeArgumentsContext,0)


        def explicitGenericInvocationSuffix(self):
            return self.getTypedRuleContext(JavaParser.ExplicitGenericInvocationSuffixContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_explicitGenericInvocation

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterExplicitGenericInvocation" ):
                listener.enterExplicitGenericInvocation(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitExplicitGenericInvocation" ):
                listener.exitExplicitGenericInvocation(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitExplicitGenericInvocation" ):
                return visitor.visitExplicitGenericInvocation(self)
            else:
                return visitor.visitChildren(self)




    def explicitGenericInvocation(self):

        localctx = JavaParser.ExplicitGenericInvocationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 198, self.RULE_explicitGenericInvocation)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1318
            self.nonWildcardTypeArguments()
            self.state = 1319
            self.explicitGenericInvocationSuffix()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class NonWildcardTypeArgumentsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LT(self):
            return self.getToken(JavaParser.LT, 0)

        def typeList(self):
            return self.getTypedRuleContext(JavaParser.TypeListContext,0)


        def GT(self):
            return self.getToken(JavaParser.GT, 0)

        def getRuleIndex(self):
            return JavaParser.RULE_nonWildcardTypeArguments

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterNonWildcardTypeArguments" ):
                listener.enterNonWildcardTypeArguments(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitNonWildcardTypeArguments" ):
                listener.exitNonWildcardTypeArguments(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitNonWildcardTypeArguments" ):
                return visitor.visitNonWildcardTypeArguments(self)
            else:
                return visitor.visitChildren(self)




    def nonWildcardTypeArguments(self):

        localctx = JavaParser.NonWildcardTypeArgumentsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 200, self.RULE_nonWildcardTypeArguments)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1321
            self.match(JavaParser.LT)
            self.state = 1322
            self.typeList()
            self.state = 1323
            self.match(JavaParser.GT)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class TypeArgumentsOrDiamondContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LT(self):
            return self.getToken(JavaParser.LT, 0)

        def GT(self):
            return self.getToken(JavaParser.GT, 0)

        def typeArguments(self):
            return self.getTypedRuleContext(JavaParser.TypeArgumentsContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_typeArgumentsOrDiamond

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTypeArgumentsOrDiamond" ):
                listener.enterTypeArgumentsOrDiamond(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTypeArgumentsOrDiamond" ):
                listener.exitTypeArgumentsOrDiamond(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitTypeArgumentsOrDiamond" ):
                return visitor.visitTypeArgumentsOrDiamond(self)
            else:
                return visitor.visitChildren(self)




    def typeArgumentsOrDiamond(self):

        localctx = JavaParser.TypeArgumentsOrDiamondContext(self, self._ctx, self.state)
        self.enterRule(localctx, 202, self.RULE_typeArgumentsOrDiamond)
        try:
            self.state = 1328
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,154,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 1325
                self.match(JavaParser.LT)
                self.state = 1326
                self.match(JavaParser.GT)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 1327
                self.typeArguments()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class NonWildcardTypeArgumentsOrDiamondContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LT(self):
            return self.getToken(JavaParser.LT, 0)

        def GT(self):
            return self.getToken(JavaParser.GT, 0)

        def nonWildcardTypeArguments(self):
            return self.getTypedRuleContext(JavaParser.NonWildcardTypeArgumentsContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_nonWildcardTypeArgumentsOrDiamond

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterNonWildcardTypeArgumentsOrDiamond" ):
                listener.enterNonWildcardTypeArgumentsOrDiamond(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitNonWildcardTypeArgumentsOrDiamond" ):
                listener.exitNonWildcardTypeArgumentsOrDiamond(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitNonWildcardTypeArgumentsOrDiamond" ):
                return visitor.visitNonWildcardTypeArgumentsOrDiamond(self)
            else:
                return visitor.visitChildren(self)




    def nonWildcardTypeArgumentsOrDiamond(self):

        localctx = JavaParser.NonWildcardTypeArgumentsOrDiamondContext(self, self._ctx, self.state)
        self.enterRule(localctx, 204, self.RULE_nonWildcardTypeArgumentsOrDiamond)
        try:
            self.state = 1333
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,155,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 1330
                self.match(JavaParser.LT)
                self.state = 1331
                self.match(JavaParser.GT)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 1332
                self.nonWildcardTypeArguments()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class SuperSuffixContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def arguments(self):
            return self.getTypedRuleContext(JavaParser.ArgumentsContext,0)


        def DOT(self):
            return self.getToken(JavaParser.DOT, 0)

        def Identifier(self):
            return self.getToken(JavaParser.Identifier, 0)

        def getRuleIndex(self):
            return JavaParser.RULE_superSuffix

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSuperSuffix" ):
                listener.enterSuperSuffix(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSuperSuffix" ):
                listener.exitSuperSuffix(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSuperSuffix" ):
                return visitor.visitSuperSuffix(self)
            else:
                return visitor.visitChildren(self)




    def superSuffix(self):

        localctx = JavaParser.SuperSuffixContext(self, self._ctx, self.state)
        self.enterRule(localctx, 206, self.RULE_superSuffix)
        try:
            self.state = 1341
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [JavaParser.LPAREN]:
                self.enterOuterAlt(localctx, 1)
                self.state = 1335
                self.arguments()
                pass
            elif token in [JavaParser.DOT]:
                self.enterOuterAlt(localctx, 2)
                self.state = 1336
                self.match(JavaParser.DOT)
                self.state = 1337
                self.match(JavaParser.Identifier)
                self.state = 1339
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,156,self._ctx)
                if la_ == 1:
                    self.state = 1338
                    self.arguments()


                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ExplicitGenericInvocationSuffixContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def SUPER(self):
            return self.getToken(JavaParser.SUPER, 0)

        def superSuffix(self):
            return self.getTypedRuleContext(JavaParser.SuperSuffixContext,0)


        def Identifier(self):
            return self.getToken(JavaParser.Identifier, 0)

        def arguments(self):
            return self.getTypedRuleContext(JavaParser.ArgumentsContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_explicitGenericInvocationSuffix

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterExplicitGenericInvocationSuffix" ):
                listener.enterExplicitGenericInvocationSuffix(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitExplicitGenericInvocationSuffix" ):
                listener.exitExplicitGenericInvocationSuffix(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitExplicitGenericInvocationSuffix" ):
                return visitor.visitExplicitGenericInvocationSuffix(self)
            else:
                return visitor.visitChildren(self)




    def explicitGenericInvocationSuffix(self):

        localctx = JavaParser.ExplicitGenericInvocationSuffixContext(self, self._ctx, self.state)
        self.enterRule(localctx, 208, self.RULE_explicitGenericInvocationSuffix)
        try:
            self.state = 1347
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [JavaParser.SUPER]:
                self.enterOuterAlt(localctx, 1)
                self.state = 1343
                self.match(JavaParser.SUPER)
                self.state = 1344
                self.superSuffix()
                pass
            elif token in [JavaParser.Identifier]:
                self.enterOuterAlt(localctx, 2)
                self.state = 1345
                self.match(JavaParser.Identifier)
                self.state = 1346
                self.arguments()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ArgumentsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LPAREN(self):
            return self.getToken(JavaParser.LPAREN, 0)

        def RPAREN(self):
            return self.getToken(JavaParser.RPAREN, 0)

        def expressionList(self):
            return self.getTypedRuleContext(JavaParser.ExpressionListContext,0)


        def getRuleIndex(self):
            return JavaParser.RULE_arguments

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterArguments" ):
                listener.enterArguments(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitArguments" ):
                listener.exitArguments(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitArguments" ):
                return visitor.visitArguments(self)
            else:
                return visitor.visitChildren(self)




    def arguments(self):

        localctx = JavaParser.ArgumentsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 210, self.RULE_arguments)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1349
            self.match(JavaParser.LPAREN)
            self.state = 1351
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << JavaParser.BOOLEAN) | (1 << JavaParser.BYTE) | (1 << JavaParser.CHAR) | (1 << JavaParser.DOUBLE) | (1 << JavaParser.FLOAT) | (1 << JavaParser.INT) | (1 << JavaParser.LONG) | (1 << JavaParser.NEW) | (1 << JavaParser.SHORT) | (1 << JavaParser.SUPER) | (1 << JavaParser.THIS) | (1 << JavaParser.VOID) | (1 << JavaParser.IntegerLiteral) | (1 << JavaParser.FloatingPointLiteral) | (1 << JavaParser.BooleanLiteral) | (1 << JavaParser.CharacterLiteral) | (1 << JavaParser.StringLiteral) | (1 << JavaParser.NullLiteral) | (1 << JavaParser.LPAREN))) != 0) or ((((_la - 70)) & ~0x3f) == 0 and ((1 << (_la - 70)) & ((1 << (JavaParser.LT - 70)) | (1 << (JavaParser.BANG - 70)) | (1 << (JavaParser.TILDE - 70)) | (1 << (JavaParser.INC - 70)) | (1 << (JavaParser.DEC - 70)) | (1 << (JavaParser.ADD - 70)) | (1 << (JavaParser.SUB - 70)) | (1 << (JavaParser.Identifier - 70)))) != 0):
                self.state = 1350
                self.expressionList()


            self.state = 1353
            self.match(JavaParser.RPAREN)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx



    def sempred(self, localctx:RuleContext, ruleIndex:int, predIndex:int):
        if self._predicates == None:
            self._predicates = dict()
        self._predicates[92] = self.expression_sempred
        pred = self._predicates.get(ruleIndex, None)
        if pred is None:
            raise Exception("No predicate with index:" + str(ruleIndex))
        else:
            return pred(localctx, predIndex)

    def expression_sempred(self, localctx:ExpressionContext, predIndex:int):
            if predIndex == 0:
                return self.precpred(self._ctx, 17)
         

            if predIndex == 1:
                return self.precpred(self._ctx, 16)
         

            if predIndex == 2:
                return self.precpred(self._ctx, 15)
         

            if predIndex == 3:
                return self.precpred(self._ctx, 14)
         

            if predIndex == 4:
                return self.precpred(self._ctx, 12)
         

            if predIndex == 5:
                return self.precpred(self._ctx, 11)
         

            if predIndex == 6:
                return self.precpred(self._ctx, 10)
         

            if predIndex == 7:
                return self.precpred(self._ctx, 9)
         

            if predIndex == 8:
                return self.precpred(self._ctx, 8)
         

            if predIndex == 9:
                return self.precpred(self._ctx, 7)
         

            if predIndex == 10:
                return self.precpred(self._ctx, 6)
         

            if predIndex == 11:
                return self.precpred(self._ctx, 1)
         

            if predIndex == 12:
                return self.precpred(self._ctx, 29)
         

            if predIndex == 13:
                return self.precpred(self._ctx, 28)
         

            if predIndex == 14:
                return self.precpred(self._ctx, 27)
         

            if predIndex == 15:
                return self.precpred(self._ctx, 26)
         

            if predIndex == 16:
                return self.precpred(self._ctx, 25)
         

            if predIndex == 17:
                return self.precpred(self._ctx, 24)
         

            if predIndex == 18:
                return self.precpred(self._ctx, 23)
         

            if predIndex == 19:
                return self.precpred(self._ctx, 20)
         

            if predIndex == 20:
                return self.precpred(self._ctx, 13)
         

            if predIndex == 21:
                return self.precpred(self._ctx, 4)
         

            if predIndex == 22:
                return self.precpred(self._ctx, 3)
         

            if predIndex == 23:
                return self.precpred(self._ctx, 2)
         




